#Surface net solar radiation, clear sky
'Surface net solar radiation, clear sky' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 210 ;
}
#Surface net thermal radiation, clear sky
'Surface net thermal radiation, clear sky' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 211 ;
}
#Eastward sea water velocity
'Eastward sea water velocity' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 131 ;
}
#Northward sea water velocity
'Northward sea water velocity' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 132 ;
}
#Sea-ice thickness
'Sea-ice thickness' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 98 ;
}
#Sea surface height
'Sea surface height' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 145 ;
}
#100 metre U wind component
'100 metre U wind component' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 246 ;
}
#100 metre V wind component
'100 metre V wind component' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 247 ;
}
#100 metre wind speed
'100 metre wind speed' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 249 ;
}
#0 degrees C isothermal level (atm)
'0 degrees C isothermal level (atm)' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 24 ;
}
#Depth of 20C isotherm
'Depth of 20C isotherm' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 163 ;
}
#Average salinity in the upper 300m
'Average salinity in the upper 300m' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 175 ;
}
#Total precipitation of at least 1 mm
'Total precipitation of at least 1 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 60 ;
}
#Total precipitation of at least 5 mm
'Total precipitation of at least 5 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 61 ;
}
#Total precipitation of at least 40 mm
'Total precipitation of at least 40 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 82 ;
}
#Total precipitation of at least 60 mm
'Total precipitation of at least 60 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 83 ;
}
#Total precipitation of at least 80 mm
'Total precipitation of at least 80 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 84 ;
}
#Total precipitation of at least 150 mm
'Total precipitation of at least 150 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 86 ;
}
#Total precipitation of at least 200 mm
'Total precipitation of at least 200 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 87 ;
}
#Total precipitation of at least 300 mm
'Total precipitation of at least 300 mm' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 88 ;
}
#Total column cloud liquid water
'Total column cloud liquid water' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 78 ;
}
#Total column cloud ice water
'Total column cloud ice water' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 79 ;
}
#Top net solar radiation
'Top net solar radiation' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 178 ;
}
#Temperature of snow layer
'Temperature of snow layer' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 238 ;
}
#Sea-ice cover
'Sea-ice cover' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 31 ;
}
#Snow density
'Snow density' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 33 ;
}
#Sea surface temperature
'Sea surface temperature' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 34 ;
}
#Surface solar radiation downwards
'Surface solar radiation downwards' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 169 ;
}
#Surface thermal radiation downwards
'Surface thermal radiation downwards' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 175 ;
}
#Eastward turbulent surface stress
'Eastward turbulent surface stress' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 180 ;
}
#Northward turbulent surface stress
'Northward turbulent surface stress' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 181 ;
}
#Surface runoff
'Surface runoff' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 8 ;
}
#Direct solar radiation
'Direct solar radiation' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 47 ;
}
#Lake total layer temperature
'Lake total layer temperature' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 11 ;
}
#Lake mix-layer temperature
'Lake mix-layer temperature' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 8 ;
}
#Lake mix-layer depth
'Lake mix-layer depth' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 9 ;
}
#Lake bottom temperature
'Lake bottom temperature' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 10 ;
}
#Lake shape factor
'Lake shape factor' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 12 ;
}
#Lake ice surface temperature
'Lake ice surface temperature' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 13 ;
}
#Lake ice total depth
'Lake ice total depth' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 14 ;
}
#Lake total depth
'Lake total depth' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 7 ;
}
