# Automatically generated by ./create_def.pl, do not edit
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 subCentre = 102 ;
	 is_s2s = 1 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 is_s2s = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 subCentre = 102 ;
	}
#Pressure (S) (not reduced)
'Pressure (S) (not reduced)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Pressure
'Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#Pressure Reduced to MSL
'Pressure Reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#Pressure Tendency (S)
'Pressure Tendency (S)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Geopotential (S)
'Geopotential (S)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Geopotential (full lev)
'Geopotential (full lev)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Geopotential
'Geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Geometric Height of the earths surface above sea level
'Geometric Height of the earths surface above sea level' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Geometric Height of the layer limits above sea level(NN)
'Geometric Height of the layer limits above sea level(NN)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Total Column Integrated Ozone
'Total Column Integrated Ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Temperature (G)
'Temperature (G)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Climat. temperature, 2m Temperature
'Climat. temperature, 2m Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfGeneratingProcess = 9 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Temperature
'Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Max 2m Temperature (i)
'Max 2m Temperature (i)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Min 2m Temperature (i)
'Min 2m Temperature (i)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2m Dew Point Temperature (AV)
'2m Dew Point Temperature (AV)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Radar spectra (1)
'Radar spectra (1)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Wave spectra (1)
'Wave spectra (1)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Wave spectra (2)
'Wave spectra (2)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Wave spectra (3)
'Wave spectra (3)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Wind Direction (DD_10M)
'Wind Direction (DD_10M)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#Wind Direction (DD)
'Wind Direction (DD)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Wind speed (SP_10M)
'Wind speed (SP_10M)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Wind speed (SP)
'Wind speed (SP)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#U component of wind
'U component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#U component of wind
'U component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#V component of wind
'V component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#V component of wind
'V component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Vertical Velocity (Pressure) ( omega=dp/dt )
'Vertical Velocity (Pressure) ( omega=dp/dt )' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Vertical Velocity (Geometric) (w)
'Vertical Velocity (Geometric) (w)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}
#Specific Humidity (S)
'Specific Humidity (S)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Specific Humidity (2m)
'Specific Humidity (2m)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}
#Specific Humidity
'Specific Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2m Relative Humidity
'2m Relative Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Relative Humidity
'Relative Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Total column integrated water vapour
'Total column integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Evaporation (s)
'Evaporation (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total Column-Integrated Cloud Ice
'Total Column-Integrated Cloud Ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total Precipitation rate (S)
'Total Precipitation rate (S)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large-Scale Precipitation rate
'Large-Scale Precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective Precipitation rate
'Convective Precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}
#Snow Depth
'Snow Depth' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total Cloud Cover
'Total Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective Cloud Cover
'Convective Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	}
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 100 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	}
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 100 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	}
#Total Column-Integrated Cloud Water
'Total Column-Integrated Cloud Water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective Snowfall rate water equivalent (s)
'Convective Snowfall rate water equivalent (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large-Scale snowfall rate water equivalent (s)
'Large-Scale snowfall rate water equivalent (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Land Cover (1=land, 0=sea)
'Land Cover (1=land, 0=sea)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface Roughness length Surface Roughness
'Surface Roughness length Surface Roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Albedo (in short-wave)
'Albedo (in short-wave)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Albedo (in short-wave)
'Albedo (in short-wave)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil Temperature  ( 36 cm depth, vv=0h)
'Soil Temperature  ( 36 cm depth, vv=0h)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 36 ;
	}
#Soil Temperature (41 cm depth)
'Soil Temperature (41 cm depth)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 41 ;
	}
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 9 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	}
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	}
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 190 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	}
#Column-integrated Soil Moisture (1) 0 -10 cm
'Column-integrated Soil Moisture (1) 0 -10 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	}
#Column-integrated Soil Moisture (2) 10-100cm
'Column-integrated Soil Moisture (2) 10-100cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	}
#Plant cover
'Plant cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Water Runoff (10-100)
'Water Runoff (10-100)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	}
#Water Runoff (10-190)
'Water Runoff (10-190)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 190 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	}
#Water Runoff (s)
'Water Runoff (s)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	}
#Sea Ice Cover ( 0= free, 1=cover)
'Sea Ice Cover ( 0= free, 1=cover)' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#sea Ice Thickness
'sea Ice Thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Direction of wind waves
'Direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Significant height of wind waves
'Significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Mean period of wind waves
'Mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Direction of swell waves
'Direction of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Significant height of swell waves
'Significant height of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Mean period of swell waves
'Mean period of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Net short wave radiation flux (m) (at the surface)
'Net short wave radiation flux (m) (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Net long wave radiation flux (m) (at the surface)
'Net long wave radiation flux (m) (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Net short wave radiation flux (m) (on the model top)
'Net short wave radiation flux (m) (on the model top)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 0 ;
	}
#Net long wave radiation flux (m) (on the model top)
'Net long wave radiation flux (m) (on the model top)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 0 ;
	}
#Latent Heat Net Flux (m)
'Latent Heat Net Flux (m)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sensible Heat Net Flux (m)
'Sensible Heat Net Flux (m)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Photosynthetically active radiation (m) (at the surface)
'Photosynthetically active radiation (m) (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Photosynthetically active radiation
'Photosynthetically active radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Solar radiation heating rate
'Solar radiation heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Thermal radiation heating rate
'Thermal radiation heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Latent heat flux from bare soil
'Latent heat flux from bare soil' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Latent heat flux from plants
'Latent heat flux from plants' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfFirstFixedSurface = 106 ;
	}
#Sunshine
'Sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Stomatal Resistance
'Stomatal Resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Cloud cover
'Cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Non-Convective Cloud Cover, grid scale
'Non-Convective Cloud Cover, grid scale' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Cloud Mixing Ratio
'Cloud Mixing Ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Cloud Ice Mixing Ratio
'Cloud Ice Mixing Ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 82 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Rain mixing ratio
'Rain mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Snow mixing ratio
'Snow mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Total column integrated rain
'Total column integrated rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}
#Total column integrated snow
'Total column integrated snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}
#Grauple
'Grauple' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Total column integrated grauple
'Total column integrated grauple' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	}
#Total Column integrated water (all components incl. precipitation)
'Total Column integrated water (all components incl. precipitation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#vertical integral of divergence of total water content (s)
'vertical integral of divergence of total water content (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#subgrid scale cloud water
'subgrid scale cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#subgridscale cloud ice
'subgridscale cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#cloud base above msl, shallow convection
'cloud base above msl, shallow convection' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 2 ;
	}
#cloud top above msl, shallow convection
'cloud top above msl, shallow convection' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 3 ;
	}
#specific cloud water content, convective cloud
'specific cloud water content, convective cloud' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Height of Convective Cloud Base (i)
'Height of Convective Cloud Base (i)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 2 ;
	}
#Height of Convective Cloud Top (i)
'Height of Convective Cloud Top (i)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 3 ;
	}
#base index (vertical level) of main convective cloud (i)
'base index (vertical level) of main convective cloud (i)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#top index (vertical level) of main convective cloud (i)
'top index (vertical level) of main convective cloud (i)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Temperature tendency due to convection
'Temperature tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Specific humitiy tendency due to convection
'Specific humitiy tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#zonal wind tendency due to convection
'zonal wind tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#meridional wind tendency due to convection
'meridional wind tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#height of top of dry convection
'height of top of dry convection' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#height of 0 degree celsius level code 0,3,6 ?
'height of 0 degree celsius level code 0,3,6 ?' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 4 ;
	}
#Height of snow fall limit
'Height of snow fall limit' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	}
#Tendency of specific cloud liquid water content due to conversion
'Tendency of specific cloud liquid water content due to conversion' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#tendency of  specific cloud ice content due to convection
'tendency of  specific cloud ice content due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Specific content of precipitation particles (needed for water loadin)g
'Specific content of precipitation particles (needed for water loadin)g' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Large scale rain rate
'Large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale snowfall rate water equivalent
'Large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale rain rate (s)
'Large scale rain rate (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective rain rate
'Convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective snowfall rate water equivalent
'Convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective rain rate (s)
'Convective rain rate (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#rain amount, grid-scale plus convective
'rain amount, grid-scale plus convective' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#snow amount, grid-scale plus convective
'snow amount, grid-scale plus convective' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Temperature tendency due to grid scale precipation
'Temperature tendency due to grid scale precipation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Specific humitiy tendency due to grid scale precipitation
'Specific humitiy tendency due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#tendency of specific cloud liquid water content due to grid scale precipitation
'tendency of specific cloud liquid water content due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'Fresh snow factor (weighting function for albedo indicating freshness of snow)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}
#tendency of specific cloud ice content due to grid scale precipitation
'tendency of specific cloud ice content due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Graupel (snow pellets) precipitation rate
'Graupel (snow pellets) precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Graupel (snow pellets) precipitation rate
'Graupel (snow pellets) precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snow density
'Snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Pressure perturbation
'Pressure perturbation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#supercell detection index 1 (rot. up+down drafts)
'supercell detection index 1 (rot. up+down drafts)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#supercell detection index 2 (only rot. up drafts)
'supercell detection index 2 (only rot. up drafts)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective Available Potential Energy, most unstable
'Convective Available Potential Energy, most unstable' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 193 ;
	}
#Convective Inhibition, most unstable
'Convective Inhibition, most unstable' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 193 ;
	}
#Convective Available Potential Energy, mean layer
'Convective Available Potential Energy, mean layer' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 192 ;
	}
#Convective Inhibition, mean layer
'Convective Inhibition, mean layer' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 192 ;
	}
#Convective turbulent kinetic enery
'Convective turbulent kinetic enery' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 24 ;
	}
#Tendency of turbulent kinetic energy
'Tendency of turbulent kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Kinetic Energy
'Kinetic Energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Turbulent Kinetic Energy
'Turbulent Kinetic Energy' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Turbulent diffusioncoefficient for momentum
'Turbulent diffusioncoefficient for momentum' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 31 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Turbulent diffusion coefficient for heat (and moisture)
'Turbulent diffusion coefficient for heat (and moisture)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Turbulent transfer coefficient for impulse
'Turbulent transfer coefficient for impulse' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Turbulent transfer coefficient for heat (and Moisture)
'Turbulent transfer coefficient for heat (and Moisture)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#mixed layer depth
'mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#maximum Wind 10m
'maximum Wind 10m' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Air concentration of Ruthenium 103
'Air concentration of Ruthenium 103' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Soil Temperature (multilayers)
'Soil Temperature (multilayers)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfFirstFixedSurface = 106 ;
	}
#Column-integrated Soil Moisture (multilayers)
'Column-integrated Soil Moisture (multilayers)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfFirstFixedSurface = 106 ;
	}
#soil ice content (multilayers)
'soil ice content (multilayers)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	}
#Plant Canopy Surface Water
'Plant Canopy Surface Water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow temperature (top of snow)
'Snow temperature (top of snow)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Minimal Stomatal Resistance
'Minimal Stomatal Resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#sea Ice Temperature
'sea Ice Temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Base reflectivity
'Base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Base reflectivity
'Base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Base reflectivity (cmax)
'Base reflectivity (cmax)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	}
#unknown
'unknown' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Effective transmissivity of solar radiation
'Effective transmissivity of solar radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#sum of contributions to evaporation
'sum of contributions to evaporation' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#total transpiration from all soil layers
'total transpiration from all soil layers' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#total forcing at soil surface
'total forcing at soil surface' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#residuum of soil moisture
'residuum of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Massflux at convective cloud base
'Massflux at convective cloud base' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective Available Potential Energy
'Convective Available Potential Energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#moisture convergence for Kuo-type closure
'moisture convergence for Kuo-type closure' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#total wave direction
'total wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#wind sea mean period
'wind sea mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#wind sea peak period
'wind sea peak period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#swell mean period
'swell mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#swell peak period
'swell peak period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#total wave peak period
'total wave peak period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#total wave mean period
'total wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#total Tm1 period
'total Tm1 period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#total Tm2 period
'total Tm2 period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#total directional spread
'total directional spread' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#analysis error(standard deviation), geopotential(gpm)
'analysis error(standard deviation), geopotential(gpm)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 7 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#analysis error(standard deviation), u-comp. of wind
'analysis error(standard deviation), u-comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 7 ;
	}
#analysis error(standard deviation), v-comp. of wind
'analysis error(standard deviation), v-comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 7 ;
	}
#zonal wind tendency due to subgrid scale oro.
'zonal wind tendency due to subgrid scale oro.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#meridional wind tendency due to subgrid scale oro.
'meridional wind tendency due to subgrid scale oro.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Standard deviation of sub-grid scale orography
'Standard deviation of sub-grid scale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Anisotropy of sub-gridscale orography
'Anisotropy of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Angle of sub-gridscale orography
'Angle of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Slope of sub-gridscale orography
'Slope of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#surface emissivity
'surface emissivity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil Type
'Soil Type' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Leaf area index
'Leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#root depth of vegetation
'root depth of vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#height of ozone maximum (climatological)
'height of ozone maximum (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#vertically integrated ozone content (climatological)
'vertically integrated ozone content (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Plant covering degree in the vegetation phase
'Plant covering degree in the vegetation phase' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Plant covering degree in the quiescent phas
'Plant covering degree in the quiescent phas' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Max Leaf area index
'Max Leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Min Leaf area index
'Min Leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Orographie + Land-Meer-Verteilung
'Orographie + Land-Meer-Verteilung' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#variance of soil moisture content (0-10)
'variance of soil moisture content (0-10)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfStatisticalProcessing = 7 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}
#variance of soil moisture content (10-100)
'variance of soil moisture content (10-100)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfStatisticalProcessing = 7 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#evergreen forest
'evergreen forest' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#deciduous forest
'deciduous forest' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#normalized differential vegetation index
'normalized differential vegetation index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	}
#normalized differential vegetation index (NDVI)
'normalized differential vegetation index (NDVI)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total sulfate aerosol
'Total sulfate aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 192 ;
	}
#Total sulfate aerosol (12M)
'Total sulfate aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total soil dust aerosol
'Total soil dust aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 193 ;
	}
#Total soil dust aerosol (12M)
'Total soil dust aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Organic aerosol
'Organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 194 ;
	}
#Organic aerosol (12M)
'Organic aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Black carbon aerosol
'Black carbon aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 195 ;
	}
#Black carbon aerosol (12M)
'Black carbon aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 195 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea salt aerosol
'Sea salt aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 196 ;
	}
#Sea salt aerosol (12M)
'Sea salt aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#tendency of specific humidity
'tendency of specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#water vapor flux
'water vapor flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}
#Coriolis parameter
'Coriolis parameter' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#geographical latitude
'geographical latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#geographical longitude
'geographical longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Friction velocity
'Friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Delay of the GPS signal trough the (total) atm.
'Delay of the GPS signal trough the (total) atm.' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Delay of the GPS signal trough wet atmos.
'Delay of the GPS signal trough wet atmos.' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Delay of the GPS signal trough dry atmos.
'Delay of the GPS signal trough dry atmos.' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Ozone Mixing Ratio
'Ozone Mixing Ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Air concentration of Ruthenium 103 (Ru103- concentration)
'Air concentration of Ruthenium 103 (Ru103- concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 192 ;
	}
#Ru103-dry deposition
'Ru103-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 193 ;
	}
#Ru103-wet deposition
'Ru103-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 194 ;
	}
#Air concentration of Strontium 90
'Air concentration of Strontium 90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 195 ;
	}
#Sr90-dry deposition
'Sr90-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 196 ;
	}
#Sr90-wet deposition
'Sr90-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 197 ;
	}
#I131-concentration
'I131-concentration' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 198 ;
	}
#I131-dry deposition
'I131-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 199 ;
	}
#I131-wet deposition
'I131-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 200 ;
	}
#Cs137-concentration
'Cs137-concentration' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 201 ;
	}
#Cs137-dry deposition
'Cs137-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 202 ;
	}
#Cs137-wet deposition
'Cs137-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 203 ;
	}
#Air concentration of Tellurium 132 (Te132-concentration)
'Air concentration of Tellurium 132 (Te132-concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 204 ;
	}
#Te132-dry deposition
'Te132-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 205 ;
	}
#Te132-wet deposition
'Te132-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 206 ;
	}
#Air concentration of Zirconium 95 (Zr95-concentration)
'Air concentration of Zirconium 95 (Zr95-concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 207 ;
	}
#Zr95-dry deposition
'Zr95-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 208 ;
	}
#Zr95-wet deposition
'Zr95-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 209 ;
	}
#Air concentration of Krypton 85  (Kr85-concentration)
'Air concentration of Krypton 85  (Kr85-concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 210 ;
	}
#Kr85-dry deposition
'Kr85-dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 211 ;
	}
#Kr85-wet deposition
'Kr85-wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 212 ;
	}
#TRACER - concentration
'TRACER - concentration' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 213 ;
	}
#TRACER - dry deposition
'TRACER - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 214 ;
	}
#TRACER - wet deposition
'TRACER - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 215 ;
	}
#Air concentration of Xenon 133 (Xe133  - concentration)
'Air concentration of Xenon 133 (Xe133  - concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 216 ;
	}
#Xe133  - dry deposition
'Xe133  - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 217 ;
	}
#Xe133  - wet deposition
'Xe133  - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 218 ;
	}
#I131g - concentration
'I131g - concentration' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 219 ;
	}
#Xe133  - wet deposition
'Xe133  - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 220 ;
	}
#I131g  - wet deposition
'I131g  - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 221 ;
	}
#I131o  - concentration
'I131o  - concentration' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 222 ;
	}
#I131o  - dry deposition
'I131o  - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 223 ;
	}
#I131o  - wet deposition
'I131o  - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 224 ;
	}
#Air concentration of Barium 40
'Air concentration of Barium 40' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 225 ;
	}
#Ba140 - dry deposition
'Ba140 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 226 ;
	}
#Ba140  - wet deposition
'Ba140  - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 227 ;
	}
#u-momentum flux due to SSO-effects
'u-momentum flux due to SSO-effects' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#u-momentum flux due to SSO-effects
'u-momentum flux due to SSO-effects' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#v-momentum flux due to SSO-effects
'v-momentum flux due to SSO-effects' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#v-momentum flux due to SSO-effects
'v-momentum flux due to SSO-effects' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Gravity wave dissipation (vertical integral)
'Gravity wave dissipation (vertical integral)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Gravity wave dissipation (vertical integral)
'Gravity wave dissipation (vertical integral)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#UV_Index_Maximum_W  UV_Index clouded (W), daily maximum
'UV_Index_Maximum_W  UV_Index clouded (W), daily maximum' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	}
#wind shear
'wind shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#storm relative helicity
'storm relative helicity' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 105 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#absolute vorticity advection
'absolute vorticity advection' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}
#Konv.-U-Grenze-nn   Hoehe der Konvektionsuntergrenze ueber nn
'Konv.-U-Grenze-nn   Hoehe der Konvektionsuntergrenze ueber nn' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#weather interpretation (WMO)
'weather interpretation (WMO)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Isentrope potentielle Vorticity
'Isentrope potentielle Vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 107 ;
	}
#Druck einer isentropen Flaeche
'Druck einer isentropen Flaeche' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	}
#KO index
'KO index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Aequivalentpotentielle Temperatur
'Aequivalentpotentielle Temperatur' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Ceiling
'Ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Icing Grade (1=LGT,2=MOD,3=SEV)
'Icing Grade (1=LGT,2=MOD,3=SEV)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}
#modified cloud depth for media
'modified cloud depth for media' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#modified cloud cover for media
'modified cloud cover for media' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 199 ;
	}
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 200 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'Monthly Mean of RMS of difference FG-AN of u-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 199 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'Monthly Mean of RMS of difference IA-AN of u-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'Monthly Mean of RMS of difference FG-AN of v-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 199 ;
	}
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'Monthly Mean of RMS of difference IA-AN of v-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 200 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Monthly Mean of RMS of difference FG-AN of geopotential
'Monthly Mean of RMS of difference FG-AN of geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 199 ;
	}
#Monthly Mean of RMS of difference IA-AN of geopotential
'Monthly Mean of RMS of difference IA-AN of geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}
#Monthly Mean of RMS of difference FG-AN of relative humidity
'Monthly Mean of RMS of difference FG-AN of relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 199 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Monthly Mean of RMS of difference IA-AN of relative humidity
'Monthly Mean of RMS of difference IA-AN of relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 200 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Monthly Mean of RMS of difference FG-AN of temperature
'Monthly Mean of RMS of difference FG-AN of temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 199 ;
	}
#Monthly Mean of RMS of difference IA-AN of temperature
'Monthly Mean of RMS of difference IA-AN of temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfGeneratingProcess = 199 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}
#Monthly Mean of RMS of difference FG-AN of kinetic energy
'Monthly Mean of RMS of difference FG-AN of kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 199 ;
	}
#Monthly Mean of RMS of difference IA-AN of kinetic energy
'Monthly Mean of RMS of difference IA-AN of kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 200 ;
	 typeOfStatisticalProcessing = 5 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 satelliteSeries = 331 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	 satelliteNumber = 72 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	 satelliteNumber = 72 ;
	}
#smoothed forecast, temperature
'smoothed forecast, temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#smoothed forecast, maximum temp.
'smoothed forecast, maximum temp.' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#smoothed forecast, minimum temp.
'smoothed forecast, minimum temp.' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#smoothed forecast, dew point temp.
'smoothed forecast, dew point temp.' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#smoothed forecast, u comp. of wind
'smoothed forecast, u comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#smoothed forecast, v comp. of wind
'smoothed forecast, v comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#smoothed forecast, total precipitation rate
'smoothed forecast, total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 197 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#smoothed forecast, total cloud cover
'smoothed forecast, total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}
#smoothed forecast, cloud cover low
'smoothed forecast, cloud cover low' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 100 ;
	 typeOfSecondFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfGeneratingProcess = 197 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	}
#smoothed forecast, cloud cover medium
'smoothed forecast, cloud cover medium' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 100 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	}
#smoothed forecast, cloud cover high
'smoothed forecast, cloud cover high' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 100 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	}
#smoothed forecast, large-scale snowfall rate w.e.
'smoothed forecast, large-scale snowfall rate w.e.' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfGeneratingProcess = 197 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#smoothed forecast, soil temperature
'smoothed forecast, soil temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 typeOfGeneratingProcess = 197 ;
	 typeOfFirstFixedSurface = 106 ;
	}
#smoothed forecast, wind speed (gust)
'smoothed forecast, wind speed (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 197 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#calibrated forecast, total precipitation rate
'calibrated forecast, total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 198 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#calibrated forecast, large-scale snowfall rate w.e.
'calibrated forecast, large-scale snowfall rate w.e.' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 198 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#calibrated forecast, wind speed (gust)
'calibrated forecast, wind speed (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 198 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 scaledValueOfCentralWaveNumber = 2000000 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 625000 ;
	}
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 1666666 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	}
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 1250000 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 83333 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
	}
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 instrumentType = 207 ;
	 satelliteSeries = 333 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	 satelliteNumber = 72 ;
	 typeOfGeneratingProcess = 8 ;
}
