# (C) Copyright 2005- ECMWF.

# TEMPLATE 7.40, Grid point data - jpeg2000
# Octets 6-xx : NG  group reference values
# (XI in the decoding formula)
# ????          ng_group_reference_values

meta   codedValues data_jpeg2000_packing(

              section7Length,
              offsetBeforeData,
              offsetSection7,

              unitsFactor,
              unitsBias,
              changingPrecision,
              numberOfCodedValues,
              bitsPerValue,
              referenceValue,
              binaryScaleFactor,
              decimalScaleFactor,
              optimizeScaleFactor,

              #numberOfValues,
              #referenceValue,
              #binaryScaleFactor,
              #decimalScaleFactor,
              #bitsPerValue,

              # For encoding

              typeOfCompressionUsed,
              targetCompressionRatio,
              Nx,
              Ny,
              interpretationOfNumberOfPoints,
              numberOfDataPoints,
              scanningMode

              ): read_only;

meta values data_apply_bitmap(codedValues,
                              bitmap,
                              missingValue,
                              binaryScaleFactor,
                              numberOfDataPoints,
                              numberOfValues) : dump;

alias data.packedValues = codedValues;

template statistics "common/statistics_grid.def";
