'undefined' = { numberOfGridUsed = 0; }
'ORCA2'     = { numberOfGridUsed = 1; }
'ORCA1'     = { numberOfGridUsed = 2; }
'ORCA025'   = { numberOfGridUsed = 3; }
'ORCA12'    = { numberOfGridUsed = 4; }
'eORCA1'    = { numberOfGridUsed = 5; }
'eORCA025'  = { numberOfGridUsed = 6; }
'eORCA12'   = { numberOfGridUsed = 7; }
