# (C) Copyright 2005- ECMWF.

# TEMPLATE 3.5, Variable resolution rotated latitude/longitude
            
include "grib2/template.3.shape_of_the_earth.def";
include "grib2/template.3.latlon_vares.def";
include "grib2/template.3.rotation.def";
