# Automatically generated by ./tigge_def.pl, do not edit

   '10_meter_u_velocity' = { parameter = 165; }
   '10_meter_v_velocity' = { parameter = 166; }
   '10_metre_wind_gust_of_at_least_15_m/s' = { parameter = 131070; }
   '10_metre_wind_gust_of_at_least_25_m/s' = { parameter = 131071; }
   'convective_available_potential_energy' = { parameter = 59; }
   'convective_inhibition' = { parameter = 228001; }
   'field_capacity' = { parameter = 228170; }
   'geopotential_height' = { parameter = 156; }
   'land_sea_mask' = { parameter = 172; }
   'maximum_wind_gust' = { parameter = 49; }
   'mean_sea_level_pressure' = { parameter = 151; }
   'orography' = { parameter = 228002; }
   'potential_temperature' = { parameter = 3; }
   'potential_vorticity' = { parameter = 60; }
   'sea_surface_temperature_anomaly' = { parameter = 171034; }
   'skin_temperature' = { parameter = 235; }
   'snow_depth_water_equivalent' = { parameter = 228141; }
   'snow_fall_water_equivalent' = { parameter = 228144; }
   'soil_moisture' = { parameter = 228039; }
   'soil_temperature' = { parameter = 228139; }
   'specific_humidity' = { parameter = 133; }
   'sunshine_duration' = { parameter = 189; }
   'surface_air_dew_point_temperature' = { parameter = 168; }
   'surface_air_maximum_temperature' = { parameter = 121; }
   'surface_air_minimum_temperature' = { parameter = 122; }
   'surface_air_temperature' = { parameter = 167; }
   'surface_pressure' = { parameter = 134; }
   'temperature' = { parameter = 130; }
   'time_integrated_outgoing_long_wave_radiation' = { parameter = 179; }
   'time_integrated_surface_latent_heat_flux' = { parameter = 147; }
   'time_integrated_surface_net_solar_radiation' = { parameter = 176; }
   'time_integrated_surface_net_thermal_radiation' = { parameter = 177; }
   'time_integrated_surface_sensible_heat_flux' = { parameter = 146; }
   'total_cloud_cover' = { parameter = 228164; }
   'total_column_water' = { parameter = 136; }
   'total_precipitation' = { parameter = 228228; }
   'total_precipitation_of_at_least_10_mm' = { parameter = 131062; }
   'total_precipitation_of_at_least_20_mm' = { parameter = 131063; }
   'u_velocity' = { parameter = 131; }
   'v_velocity' = { parameter = 132; }
   'wilting_point' = { parameter = 228171; }
   'default' = { parameter = 99999; }
 
