'undefined' = { numberOfGridInReference = 0; }
'T' = { numberOfGridInReference = 1; }
'U' = { numberOfGridInReference = 2; }
'V' = { numberOfGridInReference = 3; }
'W' = { numberOfGridInReference = 4; }
'F' = { numberOfGridInReference = 5; }
