# Concept typeOfLevel 
'surface'                 = {typeOfFirstFixedSurface=1;   typeOfSecondFixedSurface=255;}
'cloudBase'               = {typeOfFirstFixedSurface=2;   typeOfSecondFixedSurface=255;}
'cloudTop'                = {typeOfFirstFixedSurface=3;   typeOfSecondFixedSurface=255;}
'isothermZero'            = {typeOfFirstFixedSurface=4;   typeOfSecondFixedSurface=255;}
'adiabaticCondensation'   = {typeOfFirstFixedSurface=5;   typeOfSecondFixedSurface=255;}
'maxWind'                 = {typeOfFirstFixedSurface=6;   typeOfSecondFixedSurface=255;}
'tropopause'              = {typeOfFirstFixedSurface=7;   typeOfSecondFixedSurface=255;}
'nominalTop'              = {typeOfFirstFixedSurface=8;   typeOfSecondFixedSurface=255;}
'seaBottom'               = {typeOfFirstFixedSurface=9;   typeOfSecondFixedSurface=255;}
# Note: We already had 'entireAtmosphere' mapped before adding this one so had to choose another name
'atmosphere'              = {typeOfFirstFixedSurface=10;  typeOfSecondFixedSurface=255;}
'isothermal'              = {typeOfFirstFixedSurface=20;  typeOfSecondFixedSurface=255;}
'isobaricInPa'            = {typeOfFirstFixedSurface=100; typeOfSecondFixedSurface=255; pressureUnits='Pa';}
'isobaricInhPa'           = {typeOfFirstFixedSurface=100; pressureUnits='hPa'; typeOfSecondFixedSurface=255;}
'isobaricLayer'           = {typeOfFirstFixedSurface=100; typeOfSecondFixedSurface=100;}
'meanSea'                 = {typeOfFirstFixedSurface=101; typeOfSecondFixedSurface=255;}
'heightAboveSea'          = {typeOfFirstFixedSurface=102; typeOfSecondFixedSurface=255;}
'heightAboveSeaLayer'     = {typeOfFirstFixedSurface=102; typeOfSecondFixedSurface=102;}
'heightAboveGround'       = {typeOfFirstFixedSurface=103; typeOfSecondFixedSurface=255;}
'heightAboveGroundLayer'  = {typeOfFirstFixedSurface=103; typeOfSecondFixedSurface=103;}
'sigma'                   = {typeOfFirstFixedSurface=104; typeOfSecondFixedSurface=255;}
'sigmaLayer'              = {typeOfFirstFixedSurface=104; typeOfSecondFixedSurface=104;}
'hybrid'                  = {typeOfFirstFixedSurface=105; typeOfSecondFixedSurface=255;}
'hybridHeight'            = {typeOfFirstFixedSurface=118; typeOfSecondFixedSurface=255;}
'hybridLayer'             = {typeOfFirstFixedSurface=105; typeOfSecondFixedSurface=105;}
'depthBelowLand'          = {typeOfFirstFixedSurface=106; typeOfSecondFixedSurface=255;}
'depthBelowLandLayer'     = {typeOfFirstFixedSurface=106; typeOfSecondFixedSurface=106;}
'theta'                   = {typeOfFirstFixedSurface=107; typeOfSecondFixedSurface=255;}
'thetaLayer'              = {typeOfFirstFixedSurface=107; typeOfSecondFixedSurface=107;}
'pressureFromGround'      = {typeOfFirstFixedSurface=108; typeOfSecondFixedSurface=255;}
'pressureFromGroundLayer' = {typeOfFirstFixedSurface=108; typeOfSecondFixedSurface=108;}
'potentialVorticity'      = {typeOfFirstFixedSurface=109; typeOfSecondFixedSurface=255;}
'eta'                     = {typeOfFirstFixedSurface=111; typeOfSecondFixedSurface=255;}
'soil'                    = {typeOfFirstFixedSurface=151; typeOfSecondFixedSurface=255;}
'soilLayer'               = {typeOfFirstFixedSurface=151; typeOfSecondFixedSurface=151;}
# In the case of Generalized vertical height coordinates, NV must be 6
'generalVertical'         = {genVertHeightCoords=1; typeOfFirstFixedSurface=150; NV=6;}
'generalVerticalLayer'    = {genVertHeightCoords=1; typeOfFirstFixedSurface=150; typeOfSecondFixedSurface=150; NV=6;}
'depthBelowSea'           = {typeOfFirstFixedSurface=160; typeOfSecondFixedSurface=255;}
'oceanSurface'            = {typeOfFirstFixedSurface=160; scaleFactorOfFirstFixedSurface=0; scaledValueOfFirstFixedSurface=0; typeOfSecondFixedSurface=255;}
'oceanLayer'              = {typeOfFirstFixedSurface=160; typeOfSecondFixedSurface=160;}
'entireAtmosphere'        = {typeOfFirstFixedSurface=1;   typeOfSecondFixedSurface=8;}
'entireOcean'             = {typeOfFirstFixedSurface=1;   typeOfSecondFixedSurface=9;}
'snow'                    = {typeOfFirstFixedSurface=114; typeOfSecondFixedSurface=255;}
'snowLayer'               = {typeOfFirstFixedSurface=114; typeOfSecondFixedSurface=114;}
'seaIce'                  = {typeOfFirstFixedSurface=152; typeOfSecondFixedSurface=255;}
'seaIceLayer'             = {typeOfFirstFixedSurface=152; typeOfSecondFixedSurface=152;}
'mixedLayerDepth'         = {typeOfFirstFixedSurface=169; typeOfSecondFixedSurface=255;}
