# Automatically generated by ./create_def.pl, do not edit
#Stream function
'strf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 35 ;
	}
#Velocity potential
'vp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 36 ;
	}
#Potential temperature
'pt' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 13 ;
	}
#Wind speed
'ws' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 32 ;
	}
#Sea ice area fraction
'ci' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 91 ;
	}
#Montgomery potential
'mont' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 37 ;
	}
#Pressure
'pres' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 1 ;
	}
#Potential vorticity
'pv' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 4 ;
	}
#Total column cloud liquid water
'tclw' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 227 ;
	}
#Total column cloud ice water
'tciw' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 58 ;
	}
#Geopotential
'z' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 6 ;
	}
#Temperature
't' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 11 ;
	}
#U component of wind
'u' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 33 ;
	}
#V component of wind
'v' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 34 ;
	}
#Specific humidity
'q' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 51 ;
	}
#Surface pressure
'sp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Vertical velocity
'w' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 39 ;
	}
#Total column water vapour
'tcwv' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 54 ;
	}
#Vorticity (relative)
'vo' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 43 ;
	}
#Mean sea level pressure
'msl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 2 ;
	}
#Divergence
'd' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 44 ;
	}
#Geopotential Height
'gh' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 7 ;
	}
#Relative humidity
'r' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 52 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 topLevel = 10 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 81 ;
	}
#Surface roughness
'sr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 83 ;
	}
#Brightness temperature
'btmp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 118 ;
	}
#Specific cloud ice water content
'ciwc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 229 ;
	}
#Snow depth
'sde' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 66 ;
	}
#Convective cloud cover
'ccc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 72 ;
	}
#Low cloud cover
'lcc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 73 ;
	}
#Medium cloud cover
'mcc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 74 ;
	}
#High cloud cover
'hcc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 75 ;
	}
#Large scale snow
'lssf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 79 ;
	}
#Latent heat flux
'lhf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 121 ;
	}
#Sensible heat flux
'shf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 122 ;
	}
#Boundary layer dissipation
'bld' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 123 ;
	}
#2 metre specific humidity
'sh2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Convective snow
'snoc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 78 ;
	}
#Maximum wind speed
'maxgust' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 219 ;
	}
#Downward short-wave radiation flux
'dswrf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 204 ;
	}
#Upward short-wave radiation flux
'uswrf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 211 ;
	}
#Downward long-wave radiation flux
'dlwrf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 205 ;
	}
#Upward long-wave radiation flux
'ulwrf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 212 ;
	}
#Cloud water
'cwat' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 76 ;
	}
#Cloud work function
'cwork' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 146 ;
	}
#Total column integrated ozone
'tcioz' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 10 ;
	}
#Ground heat flux
'gflux' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 155 ;
	}
#2 metre relative humidity
'r2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Clear Sky Downward Solar Flux
'csdsf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 161 ;
	}
#Clear Sky Upward Solar Flux
'csusf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 160 ;
	}
#Clear Sky Upward Long Wave Flux
'csulf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 162 ;
	}
#Clear Sky Downward Long Wave Flux
'csdlf' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 163 ;
	}
#Albedo
'al' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 84 ;
	}
#Mean evaporation
'evpsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 57 ;
	}
#Mean total precipitation
'tpratsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 61 ;
	}
#Mean large scale precipitation
'lpratsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 62 ;
	}
#Mean convective precipitation
'cpratsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 63 ;
	}
#Mean snowfall rate water equivalent
'srweqsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 64 ;
	}
#Mean surface water runoff
'rofsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 90 ;
	}
#Square of Brunt-Vaisala frequency
'bvf2tht' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 132 ;
	}
#Adiabatic zonal acceleration
'aduahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 151 ;
	}
#Adiabatic meridional acceleration
'advaprs' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 165 ;
	}
#Mean frequency of deep convection
'frcvsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 170 ;
	}
#Mean frequency of shallow convection
'frcvssfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 171 ;
	}
#Mean frequency of stratocumulus parameterisation
'frscsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 172 ;
	}
#Gravity wave zonal acceleration
'gwduahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 173 ;
	}
#Gravity wave meridional acceleration
'gwdvahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 174 ;
	}
#Mean evapotranspiration
'ltrssfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 202 ;
	}
#Adiabatic heating rate
'adhrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 222 ;
	}
#Moisture storage on canopy
'mscsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 223 ;
	}
#Moisture storage on ground or cover
'msgsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 224 ;
	}
#Mass concentration of condensed water in soil
'smcugl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 226 ;
	}
#Upward mass flux at cloud base
'mflxbhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 230 ;
	}
#Upward mass flux
'mfluxhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 231 ;
	}
#Adiabatic moistening rate
'admrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 236 ;
	}
#Ozone mixing ratio
'ozonehbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 237 ;
	}
#Convective zonal acceleration
'cnvuahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 239 ;
	}
#Mean zonal momentum flux by long gravity wave
'fglusfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 147 ;
	}
#Mean meridional momentum flux by long gravity wave
'fglvsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 148 ;
	}
#Mean meridional momentum flux by short gravity wave
'fgsvsfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 154 ;
	}
#Mean zonal momentum flux by short gravity wave
'fgsusfc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 159 ;
	}
#Convective meridional acceleration
'cnvvahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 240 ;
	}
#Large scale condensation heating rate
'lrghrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 241 ;
	}
#Convective heating rate
'cnvhrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 242 ;
	}
#Convective moistening rate
'cnvmrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 243 ;
	}
#Vertical diffusion heating rate
'vdfhrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 246 ;
	}
#Vertical diffusion zonal acceleration
'vdfuahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 247 ;
	}
#Vertical diffusion meridional acceleration
'vdfvahbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 248 ;
	}
#Vertical diffusion moistening rate
'vdfmrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 249 ;
	}
#Solar radiative heating rate
'swhrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 250 ;
	}
#Long wave radiative heating rate
'lwhrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 251 ;
	}
#Large scale moistening rate
'lrgmrhbl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 253 ;
	}
#Type of vegetation
'tovg' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 252 ;
	}
#Virtual temperature
'vtmp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 12 ;
	}
#Vertical velocity
'omg2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 40 ;
	}
#Interception loss
'pitp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 203 ;
	}
#Soil wetness of surface
'ussl' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 225 ;
	}
#Temperature at canopy
'ctmp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 144 ;
	}
#Ground/surface cover temperature
'tgsc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 145 ;
	}
#Pressure tendency
'ptend' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 3 ;
	}
#ICAO Standard Atmosphere reference height
'icaht' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 5 ;
	}
#Geometrical height
'h' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 8 ;
	}
#Standard deviation of height
'hstdv' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 9 ;
	}
#Pseudo-adiabatic potential temperature
'papt' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 14 ;
	}
#Maximum temperature
'tmax' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 15 ;
	}
#Minimum temperature
'tmin' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 16 ;
	}
#Dew point temperature
'dpt' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 17 ;
	}
#Dew point depression (or deficit)
'depr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 18 ;
	}
#Lapse rate
'lapr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 19 ;
	}
#Visibility
'vis' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 20 ;
	}
#Radar spectra (1)
'rdsp1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 21 ;
	}
#Radar spectra (2)
'rdsp2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 22 ;
	}
#Radar spectra (3)
'rdsp3' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 23 ;
	}
#Parcel lifted index (to 500 hPa)
'pli' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 24 ;
	}
#Temperature anomaly
'ta' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 25 ;
	}
#Pressure anomaly
'presa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 26 ;
	}
#Geopotential height anomaly
'gpa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 27 ;
	}
#Wave spectra (1)
'wvsp1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra (2)
'wvsp2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra (3)
'wvsp3' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 30 ;
	}
#Wind direction
'wdir' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 31 ;
	}
#Sigma coordinate vertical velocity
'sgcvv' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 38 ;
	}
#Absolute vorticity
'absv' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 41 ;
	}
#Absolute divergence
'absd' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 42 ;
	}
#Vertical u-component shear
'vucsh' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 45 ;
	}
#Vertical v-component shear
'vvcsh' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 46 ;
	}
#Direction of current
'dirc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 47 ;
	}
#Speed of current
'spc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 48 ;
	}
#U-component of current 
'ucurr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 49 ;
	}
#V-component of current 
'vcurr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 50 ;
	}
#Humidity mixing ratio
'mixr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 53 ;
	}
#Vapour pressure
'vp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 55 ;
	}
#Saturation deficit
'satd' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 56 ;
	}
#Precipitation rate
'prate' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 59 ;
	}
#Thunderstorm probability
'tstm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 60 ;
	}
#Mixed layer depth
'mld' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 67 ;
	}
#Transient thermocline depth
'tthdp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 68 ;
	}
#Main thermocline depth
'mthd' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 69 ;
	}
#Main thermocline anomaly
'mtha' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 70 ;
	}
#Best lifted index (to 500 hPa)
'bli' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 77 ;
	}
#Water temperature
'wtmp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 80 ;
	}
#Deviation of sea-level from mean
'dslm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 82 ;
	}
#Soil moisture content
'ssw' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 86 ;
	}
#Salinity
's' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 88 ;
	}
#Density
'den' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 89 ;
	}
#Ice thickness
'icetk' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 92 ;
	}
#Direction of ice drift
'diced' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 93 ;
	}
#Speed of ice drift
'siced' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 94 ;
	}
#U-component of ice drift
'uice' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 95 ;
	}
#V-component of ice drift
'vice' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 96 ;
	}
#Ice growth rate
'iceg' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 97 ;
	}
#Ice divergence
'iced' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 98 ;
	}
#Snow melt
'snom' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 99 ;
	}
#Signific.height,combined wind waves+swell
'swh' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 100 ;
	}
#Mean direction of wind waves
'mdww' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 101 ;
	}
#Significant height of wind waves
'shww' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period of wind waves
'mpww' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell waves
'swdir' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 104 ;
	}
#Significant height of swell waves
'swell' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period of swell waves
'swper' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 106 ;
	}
#Primary wave direction
'mdps' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 107 ;
	}
#Primary wave mean period
'mpps' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 108 ;
	}
#Secondary wave direction
'dirsw' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 109 ;
	}
#Secondary wave mean period
'swp' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 110 ;
	}
#Net short-wave radiation flux (surface)
'nswrs' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 111 ;
	}
#Net long-wave radiation flux (surface)
'nlwrs' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 112 ;
	}
#Net short-wave radiation flux(atmosph.top)
'nswrt' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 113 ;
	}
#Net long-wave radiation flux(atmosph.top)
'nlwrt' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 114 ;
	}
#Long wave radiation flux
'lwavr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 115 ;
	}
#Short wave radiation flux
'swavr' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 116 ;
	}
#Global radiation flux
'grad' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 117 ;
	}
#Radiance (with respect to wave number)
'lwrad' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 119 ;
	}
#Radiance (with respect to wave length)
'swrad' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 120 ;
	}
#Momentum flux, u-component
'uflx' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 124 ;
	}
#Momentum flux, v-component
'vflx' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 125 ;
	}
#Wind mixing energy
'wmixe' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 126 ;
	}
#Image data
'imgd' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 127 ;
	}
#Cloud liquid water
'clw' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 228 ;
	}
#Percentage of vegetation
'vegrea' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 87 ;
	}
#Vertical integral of eastward heat flux
'vithee' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 190 ;
	}
#Vertical integral of northward heat flux
'vithen' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 191 ;
	}
#Vertical integral of eastward water vapour flux
'viwve' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 157 ;
	}
#Vertical integral of northward water vapour flux
'viwvn' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 152 ;
	}
#specific cloud water content
'qc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 221 ;
	}
#Soil Temperature
'st' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 85 ;
	}
#Snow depth water equivalent
'sd' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 65 ;
	}
#Total Cloud Cover
'tcc' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 71 ;
}
