# file generated by get_86_paramdef_for_grib_api.pl at 2014-11-14 10:59:45 EET host gogol.fmi.fi
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 1 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 2 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 3 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 4 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 8 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 9 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 10 ;
}
'kg kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 12 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 13 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 15 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 18 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 19 ;
}
'Deg' = {
	table2Version = 203 ;
	indicatorOfParameter = 20 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 21 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 22 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 23 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 24 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 27 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 28 ;
}
's-1 10-5' = {
	table2Version = 203 ;
	indicatorOfParameter = 31 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 38 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 39 ;
}
'Pa/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 40 ;
}
'mm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 43 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 44 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 47 ;
}
'mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 50 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 51 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 52 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 53 ;
}
'mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 54 ;
}
'mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 55 ;
}
'mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 56 ;
}
'mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 57 ;
}
'mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 58 ;
}
'JustAnumber' = {
	table2Version = 203 ;
	indicatorOfParameter = 59 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 60 ;
}
'm 10-4' = {
	table2Version = 203 ;
	indicatorOfParameter = 62 ;
}
'm 10-4' = {
	table2Version = 203 ;
	indicatorOfParameter = 63 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 68 ;
}
'W m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 69 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 70 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 71 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 72 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 73 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 74 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 75 ;
}
'cm' = {
	table2Version = 203 ;
	indicatorOfParameter = 77 ;
}
'kg kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 78 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 79 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 80 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 89 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 91 ;
}
'W m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 95 ;
}
'W m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 96 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 99 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 100 ;
}
'kg m-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 101 ;
}
'Code' = {
	table2Version = 203 ;
	indicatorOfParameter = 102 ;
}
'Code' = {
	table2Version = 203 ;
	indicatorOfParameter = 103 ;
}
'kg kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 104 ;
}
'kg kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 105 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 106 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 107 ;
}
'kg m-2 s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 108 ;
}
'kg m-2 s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 109 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 110 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 111 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 112 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 113 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 114 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 115 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 116 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 117 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 118 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 119 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 120 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 121 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 122 ;
}
'W m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 126 ;
}
'W m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 128 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 129 ;
}
'kg m-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 130 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 131 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 132 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 133 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 134 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 141 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 142 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 143 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 144 ;
}
'kt' = {
	table2Version = 203 ;
	indicatorOfParameter = 145 ;
}
'kt' = {
	table2Version = 203 ;
	indicatorOfParameter = 146 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 147 ;
}
'm2 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 148 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 149 ;
}
'C' = {
	table2Version = 203 ;
	indicatorOfParameter = 150 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 151 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 152 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 153 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 154 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 155 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 156 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 157 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 158 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 159 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 161 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 163 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 164 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 165 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 166 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 167 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 168 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 169 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 170 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 171 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 172 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 173 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 174 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 175 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 176 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 177 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 178 ;
}
'K' = {
	table2Version = 203 ;
	indicatorOfParameter = 179 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 180 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 181 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 182 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 183 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 184 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 185 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 186 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 187 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 188 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 189 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 190 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 191 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 192 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 193 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 194 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 195 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 196 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 197 ;
}
'%' = {
	table2Version = 203 ;
	indicatorOfParameter = 198 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 199 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 200 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 201 ;
}
'kg s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 202 ;
}
'kg m-1 s-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 203 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 204 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 205 ;
}
'JustAnumber' = {
	table2Version = 203 ;
	indicatorOfParameter = 206 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 207 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 208 ;
}
'N m-2 s' = {
	table2Version = 203 ;
	indicatorOfParameter = 209 ;
}
'N m-2 s' = {
	table2Version = 203 ;
	indicatorOfParameter = 210 ;
}
'No Unit' = {
	table2Version = 203 ;
	indicatorOfParameter = 211 ;
}
'kg/m2/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 212 ;
}
'kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 213 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 214 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 215 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 216 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 217 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 218 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 219 ;
}
'0to1' = {
	table2Version = 203 ;
	indicatorOfParameter = 220 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 221 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 222 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 223 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 224 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 225 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 226 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 227 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 228 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 229 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 230 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 231 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 232 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 233 ;
}
'm s-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 234 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 235 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 236 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 237 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 238 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 239 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 240 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 241 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 242 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 243 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 244 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 245 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 246 ;
}
'hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 247 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 248 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 249 ;
}
'm' = {
	table2Version = 203 ;
	indicatorOfParameter = 250 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 251 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 252 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 253 ;
}
'J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 254 ;
}
'JustAnumber' = {
	table2Version = 203 ;
	indicatorOfParameter = 255 ;
}
'C' = {
	table2Version = 205 ;
	indicatorOfParameter = 1 ;
}
'%' = {
	table2Version = 205 ;
	indicatorOfParameter = 2 ;
}
'cm' = {
	table2Version = 205 ;
	indicatorOfParameter = 3 ;
}
'cm' = {
	table2Version = 205 ;
	indicatorOfParameter = 4 ;
}
'cm' = {
	table2Version = 205 ;
	indicatorOfParameter = 5 ;
}
'cm' = {
	table2Version = 205 ;
	indicatorOfParameter = 6 ;
}
'm s-1' = {
	table2Version = 205 ;
	indicatorOfParameter = 7 ;
}
'm s-1' = {
	table2Version = 205 ;
	indicatorOfParameter = 8 ;
}
'cm' = {
	table2Version = 205 ;
	indicatorOfParameter = 9 ;
}
'%' = {
	table2Version = 205 ;
	indicatorOfParameter = 10 ;
}
'cm' = {
	table2Version = 205 ;
	indicatorOfParameter = 11 ;
}
'%' = {
	table2Version = 205 ;
	indicatorOfParameter = 12 ;
}
'm s-1' = {
	table2Version = 205 ;
	indicatorOfParameter = 13 ;
}
'm s-1' = {
	table2Version = 205 ;
	indicatorOfParameter = 14 ;
}
'kg m-1 s-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 1 ;
}
'kg m-1 s-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 2 ;
}
'm2 s-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 6 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 8 ;
}
'K' = {
	table2Version = 253 ;
	indicatorOfParameter = 11 ;
}
'K' = {
	table2Version = 253 ;
	indicatorOfParameter = 13 ;
}
'C' = {
	table2Version = 253 ;
	indicatorOfParameter = 15 ;
}
'C' = {
	table2Version = 253 ;
	indicatorOfParameter = 16 ;
}
'K' = {
	table2Version = 253 ;
	indicatorOfParameter = 17 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 20 ;
}
'm s-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 33 ;
}
'm s-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 34 ;
}
'Pa/s' = {
	table2Version = 253 ;
	indicatorOfParameter = 39 ;
}
'm s-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 40 ;
}
's-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 41 ;
}
'kg kg-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 51 ;
}
'%' = {
	table2Version = 253 ;
	indicatorOfParameter = 52 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 54 ;
}
'hPa s-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 57 ;
}
'kg kg-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 58 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 61 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 66 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 67 ;
}
'0to1' = {
	table2Version = 253 ;
	indicatorOfParameter = 71 ;
}
'%' = {
	table2Version = 253 ;
	indicatorOfParameter = 73 ;
}
'%' = {
	table2Version = 253 ;
	indicatorOfParameter = 74 ;
}
'%' = {
	table2Version = 253 ;
	indicatorOfParameter = 75 ;
}
'kg kg-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 76 ;
}
'0to1' = {
	table2Version = 253 ;
	indicatorOfParameter = 81 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 83 ;
}
'%' = {
	table2Version = 253 ;
	indicatorOfParameter = 84 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 86 ;
}
'0to1' = {
	table2Version = 253 ;
	indicatorOfParameter = 91 ;
}
'Deg' = {
	table2Version = 253 ;
	indicatorOfParameter = 101 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 102 ;
}
's' = {
	table2Version = 253 ;
	indicatorOfParameter = 103 ;
}
'J m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 111 ;
}
'J m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 112 ;
}
'W m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 113 ;
}
'J m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 113 ;
}
'W m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 114 ;
}
'J m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 114 ;
}
'J m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 115 ;
}
'J m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 117 ;
}
'kg s-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 121 ;
}
'kg s-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 122 ;
}
'N m-2 s' = {
	table2Version = 253 ;
	indicatorOfParameter = 124 ;
}
'N m-2 s' = {
	table2Version = 253 ;
	indicatorOfParameter = 125 ;
}
'Code' = {
	table2Version = 253 ;
	indicatorOfParameter = 135 ;
}
'JustAnumber' = {
	table2Version = 253 ;
	indicatorOfParameter = 144 ;
}
'J kg-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 160 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 162 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 163 ;
}
'kg/m2/h' = {
	table2Version = 253 ;
	indicatorOfParameter = 181 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 184 ;
}
'kg/m2/h' = {
	table2Version = 253 ;
	indicatorOfParameter = 184 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 185 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 186 ;
}
'm' = {
	table2Version = 253 ;
	indicatorOfParameter = 187 ;
}
'J kg-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 200 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 201 ;
}
'kg/m2/h' = {
	table2Version = 253 ;
	indicatorOfParameter = 201 ;
}
'kg m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 204 ;
}
'JustAnumber' = {
	table2Version = 253 ;
	indicatorOfParameter = 209 ;
}
'dBZ' = {
	table2Version = 253 ;
	indicatorOfParameter = 210 ;
}
'm s-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 228 ;
}
