#Surface net solar radiation, clear sky
'J m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 210 ;
}
#Surface net thermal radiation, clear sky
'J m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 211 ;
}
#Eastward sea water velocity
'm s**-1' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 131 ;
}
#Northward sea water velocity
'm s**-1' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 132 ;
}
#Sea-ice thickness
'm' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 98 ;
}
#Sea surface height
'm' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 145 ;
}
#100 metre U wind component
'm s**-1' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 246 ;
}
#100 metre V wind component
'm s**-1' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 247 ;
}
#100 metre wind speed
'm s**-1' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 249 ;
}
#0 degrees C isothermal level (atm)
'm' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 24 ;
}
#Depth of 20C isotherm
'm' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 163 ;
}
#Average salinity in the upper 300m
'psu' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 175 ;
}
#Total precipitation of at least 1 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 60 ;
}
#Total precipitation of at least 5 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 61 ;
}
#Total precipitation of at least 40 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 82 ;
}
#Total precipitation of at least 60 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 83 ;
}
#Total precipitation of at least 80 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 84 ;
}
#Total precipitation of at least 150 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 86 ;
}
#Total precipitation of at least 200 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 87 ;
}
#Total precipitation of at least 300 mm
'%' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 88 ;
}
#Total column cloud liquid water
'kg m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 78 ;
}
#Total column cloud ice water
'kg m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 79 ;
}
#Top net solar radiation
'J m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 178 ;
}
#Temperature of snow layer
'K' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 238 ;
}
#Sea-ice cover
'(0 - 1)' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 31 ;
}
#Snow density
'kg m**-3' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 33 ;
}
#Sea surface temperature
'K' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 34 ;
}
#Surface solar radiation downwards
'J m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 169 ;
}
#Surface thermal radiation downwards
'J m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 175 ;
}
#Eastward turbulent surface stress
'N m**-2 s' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 180 ;
}
#Northward turbulent surface stress
'N m**-2 s' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 181 ;
}
#Surface runoff
'kg m**-2' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 8 ;
}
#Direct solar radiation
'J m**-2' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 47 ;
}
#Lake total layer temperature
'K' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 11 ;
}
#Lake mix-layer temperature
'K' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 8 ;
}
#Lake mix-layer depth
'm' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 9 ;
}
#Lake bottom temperature
'K' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 10 ;
}
#Lake shape factor
'dimensionless' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 12 ;
}
#Lake ice surface temperature
'K' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 13 ;
}
#Lake ice total depth
'm' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 14 ;
}
#Lake total depth
'm' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 7 ;
}
