# (C) Copyright 2005- ECMWF.

# For grib2 to grib1 conversion
constant dataRepresentationType = 90;

unsigned[1] NB : dump;
alias numberOfContributingSpectralBands=NB;

listOfContributingSpectralBands list(numberOfContributingSpectralBands){
  unsigned[2] satelliteSeries : dump;
  unsigned[2] satelliteNumber : dump;
  unsigned[2] instrumentType : dump;
  unsigned[1] scaleFactorOfCentralWaveNumber = missing() : dump,can_be_missing ;
  unsigned[4] scaledValueOfCentralWaveNumber = missing() : dump,can_be_missing ;
}

alias instrument = instrumentType;
alias ident = satelliteNumber;
