# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.1101, Hovmoller-type grid with averaging or other statistical processing

include "grib2/template.4.parameter.def"
include "grib2/template.4.generating_process.def"
include "grib2/template.4.forecast_time.def"
include "grib2/template.4.horizontal.def"
include "grib2/template.4.statistical.def"
