# Automatically generated by ./create_def.pl, do not edit
#Pressure (S) (not reduced)
'ps' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Pressure
'p' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	}
#Pressure Reduced to MSL
'pmsl' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#Pressure Tendency (S)
'dpsdt' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geopotential (S)
'fis' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geopotential (full lev)
'fif' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Geopotential
'fi' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	}
#Geometric Height of the earths surface above sea level
'hsurf' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geometric Height of the layer limits above sea level(NN)
'hhl' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Total Column Integrated Ozone
'to3' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 10 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature (G)
't_g' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#2m Temperature (AV)
't_2m_av' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Climat. temperature, 2m Temperature
't_2m_cl' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Temperature
't' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	}
#Max 2m Temperature (i)
'tmax_2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#Min 2m Temperature (i)
'tmin_2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#2m Dew Point Temperature
'td_2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2m Dew Point Temperature (AV)
'td_2m_av' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Radar spectra (1)
'dbz_max' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 21 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Wave spectra (1)
'wvsp1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra (2)
'wvsp2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra (3)
'wvsp3' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 30 ;
	}
#Wind Direction (DD_10M)
'dd_10m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#Wind Direction (DD)
'dd' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Wind speed (SP_10M)
'sp_10m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#Wind speed (SP)
'sp' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#U component of wind
'u_10m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#U component of wind
'u' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	}
#V component of wind
'v_10m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#V component of wind
'v' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	}
#Vertical Velocity (Pressure) ( omega=dp/dt )
'omega' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical Velocity (Geometric) (w)
'w' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 40 ;
	}
#Specific Humidity (S)
'qv_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Specific Humidity (2m)
'qv_2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Specific Humidity
'qv' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	}
#2m Relative Humidity
'relhum_2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Relative Humidity
'relhum' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	}
#Total column integrated water vapour
'tqv' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 54 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Evaporation (s)
'aevap_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Total Column-Integrated Cloud Ice
'tqi' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Precipitation rate (S)
'tot_prec' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Large-Scale Precipitation rate
'prec_gsp' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 62 ;
	 timeRangeIndicator = 4 ;
	}
#Convective Precipitation rate
'prec_con' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Snow depth water equivalent
'w_snow' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 65 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Snow Depth
'h_snow' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 66 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Cloud Cover
'clct' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 71 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Cloud Cover
'clc_con' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Cover (800 hPa - Soil)
'clcl' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cloud Cover (400 - 800 hPa)
'clcm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cloud Cover (0 - 400 hPa)
'clch' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Column-Integrated Cloud Water
'tqc' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 76 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Snowfall rate water equivalent (s)
'snow_con' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Large-Scale snowfall rate water equivalent (s)
'snow_gsp' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Land Cover (1=land, 0=sea)
'fr_land' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 81 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Surface Roughness length Surface Roughness
'z0' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 83 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Albedo (in short-wave)
'alb_rad' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Albedo (in short-wave)
'albedo_b' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Soil Temperature  ( 36 cm depth, vv=0h)
't_cl' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 36 ;
	}
#Soil Temperature (41 cm depth)
't_cl_lm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 41 ;
	}
#Soil Temperature
't_m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 9 ;
	}
#Soil Temperature
't_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}
#Column-integrated Soil Moisture
'w_cl' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 190 ;
	 topLevel = 100 ;
	}
#Column-integrated Soil Moisture (1) 0 -10 cm
'w_g1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 10 ;
	 topLevel = 0 ;
	}
#Column-integrated Soil Moisture (2) 10-100cm
'w_g2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	}
#Plant cover
'plcov' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 87 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Water Runoff (10-100)
'runoff_g' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 timeRangeIndicator = 4 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	}
#Water Runoff (10-190)
'runoff_g_lm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 timeRangeIndicator = 4 ;
	 bottomLevel = 190 ;
	 topLevel = 10 ;
	}
#Water Runoff (s)
'runoff_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 10 ;
	 topLevel = 0 ;
	 timeRangeIndicator = 4 ;
	}
#Sea Ice Cover ( 0= free, 1=cover)
'fr_ice' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#sea Ice Thickness
'h_ice' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 92 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Significant height of combined wind waves and swell
'swh' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 100 ;
	}
#Direction of wind waves
'mdww' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 101 ;
	}
#Significant height of wind waves
'shww' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period of wind waves
'mpww' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell waves
'mdps' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 104 ;
	}
#Significant height of swell waves
'shps' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period of swell waves
'mpps' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 106 ;
	}
#Net short wave radiation flux (m) (at the surface)
'asob_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Net short wave radiation flux
'sobs_rad' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Net long wave radiation flux (m) (at the surface)
'athb_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Net long wave radiation flux
'thbs_rad' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Net short wave radiation flux (m) (on the model top)
'asob_t' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}
#Net short wave radiation flux
'sobt_rad' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 0 ;
	}
#Net long wave radiation flux (m) (on the model top)
'athb_t' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}
#Net long wave radiation flux
'thbt_rad' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 0 ;
	}
#Latent Heat Net Flux (m)
'alhfl_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Sensible Heat Net Flux (m)
'ashfl_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Momentum Flux, U-Component (m)
'aumfl_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Momentum Flux, V-Component (m)
'avmfl_s' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Photosynthetically active radiation (m) (at the surface)
'apab_s' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Photosynthetically active radiation
'pabs_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Solar radiation heating rate
'sohr_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 13 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Thermal radiation heating rate
'thhr_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 14 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Latent heat flux from bare soil
'alhfl_bs' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 18 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Latent heat flux from plants
'alhfl_pl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 19 ;
	 indicatorOfTypeOfLevel = 111 ;
	 timeRangeIndicator = 3 ;
	}
#Sunshine
'dursun' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 20 ;
	 timeRangeIndicator = 4 ;
	}
#Stomatal Resistance
'rstom' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 21 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Cloud cover
'clc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 29 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Non-Convective Cloud Cover, grid scale
'clc_sgs' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 30 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Mixing Ratio
'qc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Ice Mixing Ratio
'qi' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Rain mixing ratio
'qr' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 35 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Snow mixing ratio
'qs' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 36 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Total column integrated rain
'tqr' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 37 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total column integrated snow
'tqs' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 38 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Grauple
'qg' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 39 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Total column integrated grauple
'tqg' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 40 ;
	}
#Total Column integrated water (all components incl. precipitation)
'twater' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 41 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#vertical integral of divergence of total water content (s)
'tdiv_hum' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#subgrid scale cloud water
'qc_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 43 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#subgridscale cloud ice
'qi_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 44 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#cloud cover CH (0..8)
'clch_8' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 51 ;
	}
#cloud cover CM (0..8)
'clcm_8' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 52 ;
	}
#cloud cover CL (0..8)
'clcl_8' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 53 ;
	}
#cloud base above msl, shallow convection
'hbas_sc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 2 ;
	}
#cloud top above msl, shallow convection
'htop_sc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 59 ;
	 indicatorOfTypeOfLevel = 3 ;
	}
#specific cloud water content, convective cloud
'clw_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Height of Convective Cloud Base (i)
'hbas_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 2 ;
	}
#Height of Convective Cloud Top (i)
'htop_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 3 ;
	}
#base index (vertical level) of main convective cloud (i)
'bas_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#top index (vertical level) of main convective cloud (i)
'top_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature tendency due to convection
'dt_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific humitiy tendency due to convection
'dqv_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#zonal wind tendency due to convection
'du_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 78 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#meridional wind tendency due to convection
'dv_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#height of top of dry convection
'htop_dc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 82 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#height of 0 degree celsius level code 0,3,6 ?
'hzerocl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 4 ;
	}
#Height of snow fall limit
'snowlmt' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 4 ;
	}
#Tendency of specific cloud liquid water content due to conversion
'dqc_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 88 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#tendency of  specific cloud ice content due to convection
'dqi_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 89 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific content of precipitation particles (needed for water loadin)g
'q_sedim' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 99 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Large scale rain rate
'prr_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 100 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Large scale snowfall rate water equivalent
'prs_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 101 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Large scale rain rate (s)
'rain_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Convective rain rate
'prr_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective snowfall rate water equivalent
'prs_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective rain rate (s)
'rain_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#rain amount, grid-scale plus convective
'rr_f' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#snow amount, grid-scale plus convective
'rr_c' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 123 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature tendency due to grid scale precipation
'dt_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific humitiy tendency due to grid scale precipitation
'dqv_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#tendency of specific cloud liquid water content due to grid scale precipitation
'dqc_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 127 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'freshsnw' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 129 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#tendency of specific cloud ice content due to grid scale precipitation
'dqi_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Graupel (snow pellets) precipitation rate
'prg_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 131 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Graupel (snow pellets) precipitation rate
'grau_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Snow density
'rho_snow' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Pressure perturbation
'pp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 139 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#supercell detection index 1 (rot. up+down drafts)
'sdi_1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 141 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#supercell detection index 2 (only rot. up drafts)
'sdi_2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 142 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy, most unstable
'cape_mu' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 143 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Inhibition, most unstable
'cin_mu' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 144 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy, mean layer
'cape_ml' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 145 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Inhibition, mean layer
'cin_ml' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 146 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective turbulent kinetic enery
'tke_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 147 ;
	}
#Tendency of turbulent kinetic energy
'tketens' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 148 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Kinetic Energy
'ke' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 149 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Turbulent Kinetic Energy
'tke' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 152 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent diffusioncoefficient for momentum
'tkvm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 153 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent diffusion coefficient for heat (and moisture)
'tkvh' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 154 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent transfer coefficient for impulse
'tcm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 170 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Turbulent transfer coefficient for heat (and Moisture)
'tch' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 171 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#mixed layer depth
'mh' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 173 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#maximum Wind 10m
'vmax_10m' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	 timeRangeIndicator = 2 ;
	}
#Air concentration of Ruthenium 103
'ru-103' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 194 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Soil Temperature (multilayers)
't_so' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 197 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#Column-integrated Soil Moisture (multilayers)
'w_so' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#soil ice content (multilayers)
'w_so_ice' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#Plant Canopy Surface Water
'w_i' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 200 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Snow temperature (top of snow)
't_snow' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 203 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Minimal Stomatal Resistance
'prs_min' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 212 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#sea Ice Temperature
't_ice' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 215 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Base reflectivity
'dbz_850' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Base reflectivity
'dbz' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Base reflectivity (cmax)
'dbz_cmax' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	}
#unknown
'dttdiv' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Effective transmissivity of solar radiation
'sotr_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#sum of contributions to evaporation
'evatra_sum' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 236 ;
	}
#total transpiration from all soil layers
'tra_sum' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 237 ;
	}
#total forcing at soil surface
'totforce_s' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 238 ;
	}
#residuum of soil moisture
'resid_wso' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 239 ;
	}
#Massflux at convective cloud base
'mflx_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 240 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy
'cape_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 241 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#moisture convergence for Kuo-type closure
'qcvg_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 243 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#total wave direction
'mwd' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 4 ;
	}
#wind sea mean period
'mwp_x' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#wind sea peak period
'ppww' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	}
#swell mean period
'mpp_s' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#swell peak period
'ppps' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	}
#total wave peak period
'pp1d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 9 ;
	}
#total wave mean period
'tm10' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 10 ;
	}
#total Tm1 period
'tm01' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 17 ;
	}
#total Tm2 period
'tm02' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 18 ;
	}
#total directional spread
'sprd' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 19 ;
	}
#analysis error(standard deviation), geopotential(gpm)
'ana_err_fi' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 40 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#analysis error(standard deviation), u-comp. of wind
'ana_err_u' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 41 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#analysis error(standard deviation), v-comp. of wind
'ana_err_v' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 42 ;
	 level = 100 ;
	}
#zonal wind tendency due to subgrid scale oro.
'du_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 44 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#meridional wind tendency due to subgrid scale oro.
'dv_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 45 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Standard deviation of sub-grid scale orography
'sso_stdh' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 46 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Anisotropy of sub-gridscale orography
'sso_gamma' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 47 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Angle of sub-gridscale orography
'sso_theta' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 48 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Slope of sub-gridscale orography
'sso_sigma' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 49 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#surface emissivity
'emis_rad' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 56 ;
	 indicatorOfTypeOfLevel = 1 ;
	 level = 0 ;
	 timeRangeIndicator = 0 ;
	}
#Soil Type
'soiltyp' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Leaf area index
'lai' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#root depth of vegetation
'rootdp' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 62 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#height of ozone maximum (climatological)
'hmo3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 64 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#vertically integrated ozone content (climatological)
'vio3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 65 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Plant covering degree in the vegetation phase
'plcov_mx' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 67 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Plant covering degree in the quiescent phas
'plcov_mn' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Max Leaf area index
'lai_mx' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Min Leaf area index
'lai_mn' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 70 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Orographie + Land-Meer-Verteilung
'oro_mod' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 71 ;
	}
#variance of soil moisture content (0-10)
'wvar1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 10 ;
	}
#variance of soil moisture content (10-100)
'wvar2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	}
#evergreen forest
'for_e' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#deciduous forest
'for_d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 76 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#normalized differential vegetation index
'ndvi' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 77 ;
	 timeRangeIndicator = 3 ;
	}
#normalized differential vegetation index (NDVI)
'ndvi_max' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 3 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'ndvi_mrat' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'ndviratio' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Total sulfate aerosol
'aer_so4' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	}
#Total sulfate aerosol (12M)
'aer_so412' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}
#Total soil dust aerosol
'aer_dust' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	}
#Total soil dust aerosol (12M)
'aer_dust12' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	 timeRangeIndicator = 3 ;
	}
#Organic aerosol
'aer_org' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	}
#Organic aerosol (12M)
'aer_org12' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	 timeRangeIndicator = 3 ;
	}
#Black carbon aerosol
'aer_bc' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	}
#Black carbon aerosol (12M)
'aer_bc12' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	 timeRangeIndicator = 3 ;
	}
#Sea salt aerosol
'aer_ss' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	}
#Sea salt aerosol (12M)
'aer_ss12' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	 timeRangeIndicator = 3 ;
	}
#tendency of specific humidity
'dqvdt' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 104 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#water vapor flux
'qvsflx' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 105 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Coriolis parameter
'fc' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geographical latitude
'rlat' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geographical longitude
'rlon' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 115 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Friction velocity
'ustr' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 120 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Delay of the GPS signal trough the (total) atm.
'ztd' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Delay of the GPS signal trough wet atmos.
'zwd' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Delay of the GPS signal trough dry atmos.
'zhd' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 123 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ozone Mixing Ratio
'o3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 180 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Air concentration of Ruthenium 103 (Ru103- concentration)
'ru-103' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 194 ;
	}
#Ru103-dry deposition
'ru-103d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 195 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ru103-wet deposition
'ru-103w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 196 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Strontium 90
'sr-90' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 197 ;
	}
#Sr90-dry deposition
'sr-90d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Sr90-wet deposition
'sr-90w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131-concentration
'i-131a' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 200 ;
	}
#I131-dry deposition
'i-131ad' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 201 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131-wet deposition
'i-131aw' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 202 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cs137-concentration
'cs-137' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 203 ;
	}
#Cs137-dry deposition
'cs-137d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 204 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cs137-wet deposition
'cs-137w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 205 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Tellurium 132 (Te132-concentration)
'te-132' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 206 ;
	}
#Te132-dry deposition
'te-132d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 207 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Te132-wet deposition
'te-132w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 208 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Zirconium 95 (Zr95-concentration)
'zr-95' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 209 ;
	}
#Zr95-dry deposition
'zr-95d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 210 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Zr95-wet deposition
'zr-95w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 211 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Krypton 85  (Kr85-concentration)
'kr-85' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 212 ;
	}
#Kr85-dry deposition
'kr-85d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 213 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Kr85-wet deposition
'kr-85w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 214 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#TRACER - concentration
'tr-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 215 ;
	}
#TRACER - dry deposition
'tr-2d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 216 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#TRACER - wet deposition
'tr-2w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 217 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Xenon 133 (Xe133  - concentration)
'xe-133' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 218 ;
	}
#Xe133  - dry deposition
'xe-133d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 219 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Xe133  - wet deposition
'xe-133w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 220 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131g - concentration
'i-131g' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 221 ;
	}
#Xe133  - wet deposition
'i-131gd' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 222 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131g  - wet deposition
'i-131gw' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 223 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131o  - concentration
'i-131o' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 224 ;
	}
#I131o  - dry deposition
'i-131od' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 225 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131o  - wet deposition
'i-131ow' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 226 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Barium 40
'ba-140' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 227 ;
	}
#Ba140 - dry deposition
'ba-140d' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 228 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ba140  - wet deposition
'ba-140w' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 229 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#u-momentum flux due to SSO-effects
'austr_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#u-momentum flux due to SSO-effects
'ustr_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#v-momentum flux due to SSO-effects
'avstr_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#v-momentum flux due to SSO-effects
'vstr_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Gravity wave dissipation (vertical integral)
'avdis_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Gravity wave dissipation (vertical integral)
'vdis_sso' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#UV_Index_Maximum_W  UV_Index clouded (W), daily maximum
'uv_max' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 248 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#wind shear
'w_shaer' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 29 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#storm relative helicity
'srh' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 30 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#absolute vorticity advection
'vabs' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#NiederschlagBew.-ArtKombination Niederschl.-Bew.-Blautherm. (283..407)
'cl_typ' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Konvektions-U-GrenzeHoehe der Konvektionsuntergrenze ueber Grund
'ccl_gnd' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Konv.-U-Grenze-nn   Hoehe der Konvektionsuntergrenze ueber nn
'ccl_nn' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 94 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#weather interpretation (WMO)
'ww' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 99 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geostrophische  Vorticityadvektion
'advorg' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 101 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Geo Temperatur Adv  geostrophische Schichtdickenadvektion
'advor' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 103 ;
	 indicatorOfTypeOfLevel = 101 ;
	}
#Schichtdicken-Advektion
'adrtg' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 107 ;
	 indicatorOfTypeOfLevel = 101 ;
	}
#Winddivergenz
'wdiv' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 109 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Qn-Vektor Q isother-senkr-KompQn ,Komp. Q-Vektor senkrecht zu den Isothermen
'fqn' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Isentrope potentielle Vorticity
'ipv' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#XIPV Wind X-Komp     Wind X-Komponente auf isentropen Flaechen
'up' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 131 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#YIPV Wind Y-Komp     Wind Y-Komponente auf isentropen Flaechen
'vp' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 132 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Druck einer isentropen Flaeche
'ptheta' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#KO index
'ko' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 140 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Aequivalentpotentielle Temperatur
'thetae' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 154 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Ceiling
'ceiling' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 157 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Icing Grade (1=LGT,2=MOD,3=SEV)
'ice_grd' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 196 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#modified cloud depth for media
'cldepth' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 203 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#modified cloud cover for media
'clct_mod' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 204 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'efa-ps' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 1 ;
	}
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'eia-ps' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 2 ;
	}
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'efa-u' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 3 ;
	}
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'eia-u' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 4 ;
	}
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'efa-v' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 5 ;
	}
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'eia-v' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 6 ;
	}
#Monthly Mean of RMS of difference FG-AN of geopotential
'efa-fi' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 7 ;
	}
#Monthly Mean of RMS of difference IA-AN of geopotential
'eia-fi' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 8 ;
	}
#Monthly Mean of RMS of difference FG-AN of relative humidity
'efa-rh' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 9 ;
	}
#Monthly Mean of RMS of difference IA-AN of relative humidity
'eia-rh' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 10 ;
	}
#Monthly Mean of RMS of difference FG-AN of temperature
'efa-t' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 11 ;
	}
#Monthly Mean of RMS of difference IA-AN of temperature
'eia-t' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 12 ;
	}
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'efa-om' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 13 ;
	}
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'eia-om' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 14 ;
	}
#Monthly Mean of RMS of difference FG-AN of kinetic energy
'efa-ke' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 15 ;
	}
#Monthly Mean of RMS of difference IA-AN of kinetic energy
'eia-ke' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 16 ;
	}
#Synth. Sat. brightness temperature cloudy
'synme5_bt_cl' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'synme5_bt_cs' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'synme5_rad_cl' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synme5_rad_cs' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature cloudy
'synme6_bt_cl' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'synme6_bt_cs' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'synme6_rad_cl' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synme6_rad_cs' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature clear sky
'synme7_bt_cl_ir11.5' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synme7_bt_cl_wv6.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'synme7_bt_cs_ir11.5' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature cloudy
'synme7_bt_cs_wv6.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance clear sky
'synme7_rad_cl_ir11.5' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synme7_rad_cl_wv6.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance clear sky
'synme7_rad_cs_ir11.5' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance cloudy
'synme7_rad_cs_wv6.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_ir10.8' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_ir12.1' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_ir13.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_ir3.9' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_ir8.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_ir9.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_wv6.2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'synmsg_bt_cl_wv7.3' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_ir8.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_ir10.8' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_ir12.1' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_ir13.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_ir3.9' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_ir9.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_wv6.2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'synmsg_bt_cs_wv7.3' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_ir10.8' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_ir12.1' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_ir13.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_ir3.9' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_ir8.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_ir9.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_wv6.2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'synmsg_rad_cl_wv7.3' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_ir10.8' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_ir12.1' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_ir13.4' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_ir3.9' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_ir8.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_ir9.7' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_wv6.2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'synmsg_rad_cs_wv7.3' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 4 ;
	}
#smoothed forecast, temperature
't_2m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#smoothed forecast, maximum temp.
'tmax_2m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#smoothed forecast, minimum temp.
'tmin_2m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#smoothed forecast, dew point temp.
'td_2m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#smoothed forecast, u comp. of wind
'u_10m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#smoothed forecast, v comp. of wind
'v_10m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#smoothed forecast, total precipitation rate
'tot_prec_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, total cloud cover
'clct_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 71 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover low
'clcl_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover medium
'clcm_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover high
'clch_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, large-scale snowfall rate w.e.
'snow_gsp_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, soil temperature
't_s_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}
#smoothed forecast, wind speed (gust)
'vmax_10m_s' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#calibrated forecast, total precipitation rate
'tot_prec_c' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#calibrated forecast, large-scale snowfall rate w.e.
'snow_gsp_c' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#calibrated forecast, wind speed (gust)
'vmax_10m_c' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
}
