# (C) Copyright 2005- ECMWF.

constant GRIBEXSection1Problem = 56  - section1Length ;

template mars_labeling "grib1/mars_labeling.def";

unsigned[2] satelliteIdentifier  : dump;
alias mars.ident = satelliteIdentifier;

unsigned[2] instrumentIdentifier  : dump;
alias mars.instrument = instrumentIdentifier;

unsigned[2] channelNumber : dump, can_be_missing;
alias mars.channel = channelNumber;

unsigned[1] functionCode : dump ;
