#Surface net solar radiation, clear sky
'210' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 210 ;
}
#Surface net thermal radiation, clear sky
'211' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 211 ;
}
#Eastward sea water velocity
'151131' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 131 ;
}
#Northward sea water velocity
'151132' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 132 ;
}
#Sea-ice thickness
'174098' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 98 ;
}
#Sea surface height
'151145' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 145 ;
}
#100 metre U wind component
'228246' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 246 ;
}
#100 metre V wind component
'228247' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 247 ;
}
#100 metre wind speed
'228249' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 249 ;
}
#0 degrees C isothermal level (atm)
'228024' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 24 ;
}
#Depth of 20C isotherm
'151163' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 163 ;
}
#Average salinity in the upper 300m
'151175' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 175 ;
}
#Total precipitation of at least 1 mm
'131060' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 60 ;
}
#Total precipitation of at least 5 mm
'131061' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 61 ;
}
#Total precipitation of at least 40 mm
'131082' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 82 ;
}
#Total precipitation of at least 60 mm
'131083' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 83 ;
}
#Total precipitation of at least 80 mm
'131084' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 84 ;
}
#Total precipitation of at least 150 mm
'131086' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 86 ;
}
#Total precipitation of at least 200 mm
'131087' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 87 ;
}
#Total precipitation of at least 300 mm
'131088' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 88 ;
}
#Total column cloud liquid water
'78' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 78 ;
}
#Total column cloud ice water
'79' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 79 ;
}
#Top net solar radiation
'178' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 178 ;
}
#Temperature of snow layer
'238' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 238 ;
}
#Sea-ice cover
'31' = {
  discipline = 192 ;
  parameterCategory = 128 ;
  parameterNumber = 31 ;
}
#Snow density
'33' = {
  discipline = 192 ;
  parameterCategory = 128 ;
  parameterNumber = 33 ;
}
#Sea surface temperature
'34' = {
  discipline = 192 ;
  parameterCategory = 128 ;
  parameterNumber = 34 ;
}
#Surface solar radiation downwards
'169' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 169 ;
}
#Surface thermal radiation downwards
'175' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 175 ;
}
#Eastward turbulent surface stress
'180' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 180 ;
}
#Northward turbulent surface stress
'181' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 181 ;
}
#Surface runoff
'174008' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 8 ;
}
#Direct solar radiation
'47' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 47 ;
}
#Lake total layer temperature
'228011' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 11 ;
}
#Lake mix-layer temperature
'228008' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 8 ;
}
#Lake mix-layer depth
'228009' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 9 ;
}
#Lake bottom temperature
'228010' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 10 ;
}
#Lake shape factor
'228012' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 12 ;
}
#Lake ice surface temperature
'228013' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 13 ;
}
#Lake ice total depth
'228014' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 14 ;
}
#Lake total depth
'228007' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 7 ;
}
