# Automatically generated by ./create_def.pl, do not edit
#Convective available potential energy
'J kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	}
#Snow phase change heat flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Condensate
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	}
#Horizontal moisture convergence
'kg kg**-1 s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	}
#Categorical rain
'(Code table 4.222)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Categorical freezing rain
'(Code table 4.222)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Categorical ice pellets
'(Code table 4.222)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Categorical snow
'(Code table 4.222)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Convective precipitation rate
'kg m**-2 s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	}
#Percent frozen precipitation
'%' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Potential evaporation
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	}
#Potential evaporation rate
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	}
#Snow cover
'%' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	}
#Rain fraction of total cloud water
'Proportion' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	}
#Rime factor
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}
#Total column integrated rain
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	}
#Total column integrated snow
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	}
#Water equivalent of accumulated snow depth (deprecated)
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Vertical speed shear
's**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}
#Horizontal momentum flux
'N m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	}
#U-component storm motion
'm s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	}
#V-component storm motion
'm s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	}
#Drag coefficient
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	}
#Frictional velocity
'm s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 197 ;
	}
#5-wave geopotential height
'gpm' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Zonal flux of gravity wave stress
'N m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Meridional flux of gravity wave stress
'N m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Planetary boundary layer height
'm' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#5-wave geopotential height anomaly
'gpm' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Downward short-wave radiation flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}
#Upward short-wave radiation flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}
#UV index 
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 196 ;
	}
#Downward long-wave radiation flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	}
#Upward long-wave radiation flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 193 ;
	}
#Non-convective cloud cover
'%' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	}
#Cloud work function
'J kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	}
#Convective cloud efficiency
'Proportion' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	}
#Total column-integrated cloud water
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	}
#Total column-integrated cloud ice
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 197 ;
	}
#Total column-integrated condensate
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	}
#Ice fraction of total condensate
'Proportion' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	}
#Surface lifted index
'K' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	}
#Best (4-layer) lifted index
'K' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	}
#Ozone mixing ratio
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	}
#Maximum snow albedo
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Snow free albedo
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
's' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 194 ;
	}
#Baseflow-groundwater runoff
'kg m**-2' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Storm surface runoff
'kg m**-2' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Volumetric soil moisture content
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Ground heat flux
'W m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Moisture availability
'%' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#Exchange coefficient
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Plant canopy surface water
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Blackadar mixing length scale
'm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Canopy conductance
'm s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#Minimal stomatal resistance
's m**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	}
#Solar parameter in canopy conductance
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	}
#Temperature parameter in canopy conductance
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	}
#Soil moisture parameter in canopy conductance
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 205 ;
	}
#Humidity parameter in canopy conductance
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#Number of soil layers in root zone
'Numeric' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Transpiration stress-onset (soil moisture)
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Direct evaporation cease (soil moisture)
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#Soil porosity
'Proportion' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Temperature tendency by all radiation
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Relative Error Variance
'~' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#Large Scale Condensate Heating rate
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Deep Convective Heating rate
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Total Downward Heat Flux at Surface
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Temperature Tendency By All Physics
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#Temperature Tendency By Non-radiation Physics
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#Standard Dev. of IR Temp. over 1x1 deg. area
'K' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	}
#Shallow Convective Heating rate
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}
#Vertical Diffusion Heating rate
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	}
#Potential temperature at top of viscous sublayer
'K' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	}
#Tropical Cyclone Heat Potential
'J m**-2 K**-1' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	}
#Minimum Relative Humidity
'%' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	}
#Total Icing Potential Diagnostic
'dimensionless' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	}
#Number concentration for ice particles
'dimensionless' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	}
#Snow temperature
'K' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}
#Total column-integrated supercooled liquid water
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 209 ;
	}
#Total column-integrated melting ice
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 210 ;
	}
#Evaporation - Precipitation
'cm per day' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 211 ;
	}
#Sublimation (evaporation from snow)
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 212 ;
	}
#Deep Convective Moistening Rate
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 213 ;
	}
#Shallow Convective Moistening Rate
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 214 ;
	}
#Vertical Diffusion Moistening Rate
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 215 ;
	}
#Condensation Pressure of Parcali Lifted From Indicate Surface
'Pa' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 216 ;
	}
#Large scale moistening rate
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 217 ;
	}
#Specific humidity at top of viscous sublayer
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 218 ;
	}
#Maximum specific humidity at 2m
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 219 ;
	}
#Minimum specific humidity at 2m
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 220 ;
	}
#Liquid precipitation (rainfall)
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 221 ;
	}
#Snow temperature, depth-avg
'K' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 222 ;
	}
#Total precipitation (nearest grid point)
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 223 ;
	}
#Convective precipitation (nearest grid point)
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 224 ;
	}
#Freezing Rain
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 225 ;
	}
#Latitude of U Wind Component of Velocity
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 198 ;
	}
#Longitude of U Wind Component of Velocity
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 199 ;
	}
#Latitude of V Wind Component of Velocity
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 200 ;
	}
#Longitude of V Wind Component of Velocity
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 201 ;
	}
#Latitude of Presure Point
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 202 ;
	}
#Longitude of Presure Point
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 203 ;
	}
#Vertical Eddy Diffusivity Heat exchange
'm**2 s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 204 ;
	}
#Covariance between Meridional and Zonal Components of the wind.
'm**2 s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 205 ;
	}
#Covariance between Temperature and Zonal Components of the wind.
'K m s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 206 ;
	}
#Covariance between Temperature and Meridional Components of the wind.
'K m s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 207 ;
	}
#Vertical Diffusion Zonal Acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 208 ;
	}
#Vertical Diffusion Meridional Acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 209 ;
	}
#Gravity wave drag zonal acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 210 ;
	}
#Gravity wave drag meridional acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 211 ;
	}
#Convective zonal momentum mixing acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 212 ;
	}
#Convective meridional momentum mixing acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 213 ;
	}
#Tendency of vertical velocity
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 214 ;
	}
#Omega (Dp/Dt) divide by density
'K' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 215 ;
	}
#Convective Gravity wave drag zonal acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 216 ;
	}
#Convective Gravity wave drag meridional acceleration
'm s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 217 ;
	}
#Velocity Point Model Surface
'~' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 218 ;
	}
#Potential Vorticity (Mass-Weighted)
'(s m**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 219 ;
	}
#MSLP (Eta model reduction)
'Pa' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#MSLP (MAPS System Reduction)
'Pa' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#3-hr pressure tendency (Std. Atmos. Reduction)
'Pa s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Pressure of level from which parcel was lifted
'Pa' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#X-gradient of Log Pressure
'm**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Y-gradient of Log Pressure
'm**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#X-gradient of Height
'm**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 203 ;
	}
#Y-gradient of Height
'm**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 204 ;
	}
#Layer Thickness
'm' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 205 ;
	}
#Natural Log of Surface Pressure
'ln(kPa)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 206 ;
	}
#Convective updraft mass flux
'kg (m**2 s-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 207 ;
	}
#Convective downdraft mass flux
'kg (m**2 s-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 208 ;
	}
#Convective detrainment mass flux
'kg (m**2 s-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 209 ;
	}
#Mass Point Model Surface
'~' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 210 ;
	}
#Geopotential Height (nearest grid point)
'gpm' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 211 ;
	}
#Pressure (nearest grid point)
'Pa' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 212 ;
	}
#UV-B downward solar flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	}
#Clear sky UV-B downward solar flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}
#Clear Sky Downward Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}
#Solar Radiative Heating Rate
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}
#Clear Sky Upward Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	}
#Cloud Forcing Net Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	}
#Visible Beam Downward Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 200 ;
	}
#Visible Diffuse Downward Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 201 ;
	}
#Near IR Beam Downward Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 202 ;
	}
#Near IR Diffuse Downward Solar Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 203 ;
	}
#Downward Total radiation Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 204 ;
	}
#Upward Total radiation Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 205 ;
	}
#Long-Wave Radiative Heating Rate
'K s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 194 ;
	}
#Clear Sky Upward Long Wave Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 195 ;
	}
#Clear Sky Downward Long Wave Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 196 ;
	}
#Cloud Forcing Net Long Wave Flux
'W m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 197 ;
	}
#Convective Cloud Mass Flux
'Pa s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 200 ;
	}
#Richardson Number
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 194 ;
	}
#Convective Weather Detection Index
'~' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	}
#Updraft Helicity
'm**2 s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 197 ;
	}
#Leaf Area Index
'~' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 198 ;
	}
#Particulate matter (coarse)
'(10**-6 g) m**-3' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 192 ;
	}
#Particulate matter (fine)
'(10**-6 g) m**-3' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 193 ;
	}
#Particulate matter (fine)
'log10((10**-6g) m**-3)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 194 ;
	}
#Integrated column particulate matter (fine)
'log10((10**-6g) m**-3)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 195 ;
	}
#Ozone Concentration (PPB)
'ppb' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	}
#Categorical Ozone Concentration
'dimensionless' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 194 ;
	}
#Ozone vertical diffusion
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 195 ;
	}
#Ozone production
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 196 ;
	}
#Ozone tendency
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 197 ;
	}
#Ozone production from temperature term
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 198 ;
	}
#Ozone production from col ozone term
'kg (kg s**-1)**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 199 ;
	}
#Derived radar reflectivity backscatter from rain
'mm**6 m**-3' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 192 ;
	}
#Derived radar reflectivity backscatter from ice
'mm**6 m**-3' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 193 ;
	}
#Derived radar reflectivity backscatter from parameterized convection
'mm**6 m**-3' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 194 ;
	}
#Derived radar reflectivity
'dB' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 195 ;
	}
#Maximum/Composite radar reflectivity
'dB' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 196 ;
	}
#Lightning
'dimensionless' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	}
#Slight risk convective outlook
'categorical' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 194 ;
	}
#Moderate risk convective outlook
'categorical' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	}
#High risk convective outlook
'categorical' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	}
#Tornado probability
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	}
#Hail probability
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	}
#Wind probability
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	}
#Significant Tornado probability
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	}
#Significant Hail probability
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	}
#Significant Wind probability
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	}
#Categorical Thunderstorm (1-yes, 0-no)
'categorical' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	}
#Number of mixed layers next to surface
'Integer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	}
#Flight Category
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	}
#Confidence - Ceiling
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	}
#Confidence - Visibility
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	}
#Confidence - Flight Category
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	}
#Low-Level aviation interest
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 209 ;
	}
#High-Level aviation interest
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 210 ;
	}
#Visible, Black Sky Albedo
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 211 ;
	}
#Visible, White Sky Albedo
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 212 ;
	}
#Near IR, Black Sky Albedo
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 213 ;
	}
#Near IR, White Sky Albedo
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 214 ;
	}
#Total Probability of Severe Thunderstorms (Days 2,3)
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 215 ;
	}
#Total Probability of Extreme Severe Thunderstorms (Days 2,3)
'%' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 216 ;
	}
#Supercooled Large Droplet (SLD) Potential
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 217 ;
	}
#Radiative emissivity
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 218 ;
	}
#Turbulence Potential Forecast Index
'~' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 219 ;
	}
#Volcanic Ash Forecast Transport and Dispersion
'log10(kg m**-3)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 232 ;
	}
#Latitude (-90 to +90)
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 192 ;
	}
#East Longitude (0 - 360)
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 193 ;
	}
#Model Layer number (From bottom up)
'~' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 195 ;
	}
#Latitude (nearest neighbor) (-90 to +90)
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 196 ;
	}
#East Longitude (nearest neighbor) (0 - 360)
'deg' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 197 ;
	}
#Probability of Freezing Precipitation
'%' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Probability of precipitation exceeding flash flood guidance values
'%' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Probability of Wetting Rain, exceeding in 0.10 in a given time period
'%' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Vegetation Type
'Integer(0-13)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#Wilting Point
'Fraction' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}
#Rate of water dropping from canopy to ground
'~' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 206 ;
	}
#Ice-free water surface
'%' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 207 ;
	}
#Surface exchange coefficients for T and Q divided by delta z
'm s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 208 ;
	}
#Surface exchange coefficients for U and V divided by delta z
'm s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 209 ;
	}
#Vegetation canopy temperature
'K' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 210 ;
	}
#Surface water storage
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 211 ;
	}
#Liquid soil moisture content (non-frozen)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 212 ;
	}
#Open water evaporation (standing water)
'W m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 213 ;
	}
#Groundwater recharge
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 214 ;
	}
#Flood plain recharge
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 215 ;
	}
#Roughness length for heat
'm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 216 ;
	}
#Normalized Difference Vegetation Index
'~' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 217 ;
	}
#Land-sea coverage (nearest neighbor) [land=1,sea=0]
'~' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 218 ;
	}
#Asymptotic mixing length scale
'm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 219 ;
	}
#Water vapor added by precip assimilation
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 220 ;
	}
#Water condensate added by precip assimilation
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 221 ;
	}
#Water Vapor Flux Convergance (Vertical Int)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 222 ;
	}
#Water Condensate Flux Convergance (Vertical Int)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 223 ;
	}
#Water Vapor Zonal Flux (Vertical Int)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 224 ;
	}
#Water Vapor Meridional Flux (Vertical Int)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 225 ;
	}
#Water Condensate Zonal Flux (Vertical Int)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 226 ;
	}
#Water Condensate Meridional Flux (Vertical Int)
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 227 ;
	}
#Aerodynamic conductance
'm s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 228 ;
	}
#Canopy water evaporation
'W m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 229 ;
	}
#Transpiration
'W m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 230 ;
	}
#Surface Slope Type
'Index' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Direct evaporation from bare soil
'W m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#Land Surface Precipitation Accumulation
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Bare soil surface skin temperature
'K' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#Average surface skin temperature
'K' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Effective radiative skin temperature
'K' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#Field Capacity
'Fraction' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 203 ;
	}
#Scatterometer Estimated U Wind Component
'm s**-1' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Scatterometer Estimated V Wind Component
'm s**-1' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Wave Steepness
'~' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Ocean Mixed Layer U Velocity
'm s**-1' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Ocean Mixed Layer V Velocity
'm s**-1' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Barotropic U velocity
'm s**-1' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Barotropic V velocity
'm s**-1' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Storm Surge
'm' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#Extra Tropical Storm Surge
'm' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Ocean Surface Elevation Relative to Geoid
'm' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Sea Surface Height Relative to Geoid
'm' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Ocean Mixed Layer Potential Density (Reference 2000m)<br
'kg m**-3' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#Net Air-Ocean Heat Flux
'W m**-2' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Assimilative Heat Flux
'W m**-2' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#Surface Temperature Trend
'degreeperday' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Surface Salinity Trend
'psuperday' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#Kinetic Energy
'J kg**-1' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Salt Flux
'kg (m**2 s**-1)**-1' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#3-D Temperature
'deg C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}
#3-D Salinity
'~' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}
#Barotropic Kinectic Energy
'J kg**-1' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	}
#Geometric Depth Below Sea Surface
'm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}
#Interface Depths
'm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}
#Ocean Heat Content
'Jm-2' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}
#Image data
'~' = {
	 discipline = 255 ;
	 parameterCategory = 255 ;
	 parameterNumber = 255 ;
	}
#Sunshine Duration
's' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 201 ;
	}
#Icing severity
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 234 ;
	}
#Ventilation Rate
'm**2 s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 224 ;
	}
#Convective inhibition
'J kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	}
#Total Cloud Cover
'%' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}
#Total Precipitation
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
}
