# Japanese Meteorological Agency
codetable[1] localDefinitionNumber 'grib1/localDefinitionNumber.34.table' = 1 : dump;
template  localDefinition  "grib1/local.34.[localDefinitionNumber:l].def";

template_nofail marsKeywords "mars/grib.[stream:s].[type:s].def";
