# (C) Copyright 2005- ECMWF.

# TEMPLATE 7.42, Grid point data - CCSDS
meta codedValues data_ccsds_packing(
              section7Length,
              offsetBeforeData,
              offsetSection7,
              numberOfValues,
              referenceValue,
              binaryScaleFactor,
              decimalScaleFactor,
              bitsPerValue,

              numberOfDataPoints,

              ccsdsFlags,
              ccsdsBlockSize,
              ccsdsRsi

            ): read_only;

meta values data_apply_bitmap(codedValues,
                                bitmap,
                                missingValue,
                                binaryScaleFactor,
                                numberOfDataPoints,
                                numberOfValues) : dump;

# See ECC-711
meta packingError simple_packing_error(bitsPerValue,binaryScaleFactor,decimalScaleFactor,referenceValue,ieee) : no_copy;
meta unpackedError simple_packing_error(zero,binaryScaleFactor,decimalScaleFactor,referenceValue,ieee) : no_copy;

alias data.packedValues = codedValues;

template statistics "common/statistics_grid.def";
