# Automatically generated by ./create_def.pl, do not edit
#Total precipitation of at least 1 mm
'tpg1' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 60 ;
	}
#Total precipitation of at least 5 mm
'tpg5' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 61 ;
	}
#Total precipitation of at least 10 mm
'tpg10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 62 ;
	}
#Total precipitation of at least 20 mm
'tpg20' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 63 ;
	}
#Total precipitation of at least 40 mm
'tpg40' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 82 ;
	}
#Total precipitation of at least 60 mm
'tpg60' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 83 ;
	}
#Total precipitation of at least 80 mm
'tpg80' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 84 ;
	}
#Total precipitation of at least 100 mm
'tpg100' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 85 ;
	}
#Total precipitation of at least 150 mm
'tpg150' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 86 ;
	}
#Total precipitation of at least 200 mm
'tpg200' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 87 ;
	}
#Total precipitation of at least 300 mm
'tpg300' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 88 ;
	}
#Stream function
'strf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 1 ;
	}
#Velocity potential
'vp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 2 ;
	}
#Potential temperature
'pt' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 3 ;
	}
#Equivalent potential temperature
'eqpt' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 4 ;
	}
#Saturated equivalent potential temperature
'sept' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 5 ;
	}
#Soil sand fraction
'ssfr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 6 ;
	}
#Soil clay fraction
'scfr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 7 ;
	}
#Surface runoff
'sro' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 8 ;
	}
#Sub-surface runoff
'ssro' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 9 ;
	}
#Wind speed
'ws' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 10 ;
	}
#U component of divergent wind
'udvw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 11 ;
	}
#V component of divergent wind
'vdvw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 12 ;
	}
#U component of rotational wind
'urtw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 13 ;
	}
#V component of rotational wind
'vrtw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 14 ;
	}
#UV visible albedo for direct radiation
'aluvp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 15 ;
	}
#UV visible albedo for diffuse radiation
'aluvd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 16 ;
	}
#Near IR albedo for direct radiation
'alnip' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 17 ;
	}
#Near IR albedo for diffuse radiation
'alnid' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 18 ;
	}
#Clear sky surface UV
'uvcs' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 19 ;
	}
#Clear sky surface photosynthetically active radiation
'parcs' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 20 ;
	}
#Unbalanced component of temperature
'uctp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 21 ;
	}
#Unbalanced component of logarithm of surface pressure
'ucln' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 22 ;
	}
#Unbalanced component of divergence
'ucdv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 23 ;
	}
#Reserved for future unbalanced components
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 24 ;
	}
#Reserved for future unbalanced components
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 25 ;
	}
#Lake cover
'cl' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 26 ;
	}
#Low vegetation cover
'cvl' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 27 ;
	}
#High vegetation cover
'cvh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 28 ;
	}
#Type of low vegetation
'tvl' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 29 ;
	}
#Type of high vegetation
'tvh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 30 ;
	}
#Sea ice area fraction
'ci' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 31 ;
	}
#Snow albedo
'asn' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 32 ;
	}
#Snow density
'rsn' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 33 ;
	}
#Sea surface temperature
'sst' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 34 ;
	}
#Ice temperature layer 1
'istl1' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 35 ;
	}
#Ice temperature layer 2
'istl2' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 36 ;
	}
#Ice temperature layer 3
'istl3' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 37 ;
	}
#Ice temperature layer 4
'istl4' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 38 ;
	}
#Volumetric soil water layer 1
'swvl1' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 39 ;
	}
#Volumetric soil water layer 2
'swvl2' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 40 ;
	}
#Volumetric soil water layer 3
'swvl3' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 41 ;
	}
#Volumetric soil water layer 4
'swvl4' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 42 ;
	}
#Soil type
'slt' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 43 ;
	}
#Snow evaporation
'es' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt
'smlt' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 45 ;
	}
#Solar duration
'sdur' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 46 ;
	}
#Direct solar radiation
'dsrp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 47 ;
	}
#Magnitude of turbulent surface stress
'magss' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 48 ;
	}
#10 metre wind gust since previous post-processing
'10fg' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 49 ;
	}
#Large-scale precipitation fraction
'lspf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 50 ;
	}
#Maximum temperature at 2 metres in the last 24 hours
'mx2t24' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 51 ;
	}
#Minimum temperature at 2 metres in the last 24 hours
'mn2t24' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 52 ;
	}
#Montgomery potential
'mont' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 53 ;
	}
#Pressure
'pres' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 54 ;
	}
#Mean temperature at 2 metres in the last 24 hours
'mean2t24' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours
'mn2d24' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 56 ;
	}
#Downward UV radiation at the surface
'uvb' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 57 ;
	}
#Photosynthetically active radiation at the surface
'par' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 58 ;
	}
#Convective available potential energy
'cape' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 59 ;
	}
#Potential vorticity
'pv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 60 ;
	}
#Observation count
'obct' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 62 ;
	}
#Start time for skin temperature difference
'stsktd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 63 ;
	}
#Finish time for skin temperature difference
'ftsktd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 64 ;
	}
#Skin temperature difference
'sktd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 65 ;
	}
#Leaf area index, low vegetation
'lai_lv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 66 ;
	}
#Leaf area index, high vegetation
'lai_hv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 67 ;
	}
#Minimum stomatal resistance, low vegetation
'msr_lv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 68 ;
	}
#Minimum stomatal resistance, high vegetation
'msr_hv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 69 ;
	}
#Biome cover, low vegetation
'bc_lv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 70 ;
	}
#Biome cover, high vegetation
'bc_hv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 71 ;
	}
#Instantaneous surface solar radiation downwards
'issrd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 72 ;
	}
#Instantaneous surface thermal radiation downwards
'istrd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 73 ;
	}
#Standard deviation of filtered subgrid orography
'sdfor' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 74 ;
	}
#Specific rain water content
'crwc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 75 ;
	}
#Specific snow water content
'cswc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 76 ;
	}
#Eta-coordinate vertical velocity
'etadot' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 77 ;
	}
#Total column cloud liquid water
'tclw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 78 ;
	}
#Total column cloud ice water
'tciw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 79 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 80 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 81 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 82 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 83 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 84 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 85 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 86 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 87 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 88 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 89 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 90 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 91 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 92 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 93 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 94 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 95 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 96 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 97 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 98 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 99 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 100 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 101 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 102 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 103 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 104 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 105 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 106 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 107 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 108 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 109 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 110 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 111 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 112 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 113 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 114 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 115 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 116 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 117 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 118 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 119 ;
	}
#Experimental product
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 120 ;
	}
#Maximum temperature at 2 metres in the last 6 hours
'mx2t6' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 121 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'mn2t6' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 122 ;
	}
#10 metre wind gust in the last 6 hours
'10fg6' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 123 ;
	}
#Surface emissivity
'emis' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 124 ;
	}
#Vertically integrated total energy
'vite' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 125 ;
	}
#Generic parameter for sensitive area prediction
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 126 ;
	}
#Atmospheric tide
'at' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 127 ;
	}
#Atmospheric tide
'at' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 127 ;
	}
#Budget values
'bv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 128 ;
	}
#Budget values
'bv' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 128 ;
	}
#Geopotential
'z' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'z' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'z' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'z' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'z' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 129 ;
	}
#Temperature
't' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
't' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
't' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
't' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
't' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 130 ;
	}
#U component of wind
'u' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'u' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'u' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'u' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'u' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 131 ;
	}
#V component of wind
'v' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'v' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'v' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'v' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'v' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 132 ;
	}
#Specific humidity
'q' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'q' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'q' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'q' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'q' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 133 ;
	}
#Surface pressure
'sp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'sp' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'sp' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 52 ;
	}
#Surface pressure
'sp' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'sp' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 134 ;
	}
#Vertical velocity
'w' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 135 ;
	}
#Vertical velocity
'w' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 135 ;
	}
#Total column water
'tcw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 136 ;
	}
#Total column water
'tcw' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 136 ;
	}
#Total column water vapour
'tcwv' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 137 ;
	}
#Total column water vapour
'tcwv' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 137 ;
	}
#Vorticity (relative)
'vo' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'vo' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'vo' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'vo' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'vo' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 138 ;
	}
#Soil temperature level 1
'stl1' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 139 ;
	}
#Soil temperature level 1
'stl1' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 139 ;
	}
#Soil temperature level 1
'stl1' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 139 ;
	}
#Soil temperature level 1
'stl1' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 139 ;
	}
#Soil wetness level 1
'swl1' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 140 ;
	}
#Soil wetness level 1
'swl1' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 140 ;
	}
#Snow depth
'sd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 141 ;
	}
#Snow depth
'sd' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 141 ;
	}
#Snow depth
'sd' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 141 ;
	}
#Large-scale precipitation
'lsp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 142 ;
	}
#Large-scale precipitation
'lsp' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 142 ;
	}
#Large-scale precipitation
'lsp' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation
'cp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 143 ;
	}
#Convective precipitation
'cp' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 143 ;
	}
#Convective precipitation
'cp' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall
'sf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 144 ;
	}
#Snowfall
'sf' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation
'bld' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 145 ;
	}
#Boundary layer dissipation
'bld' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux
'sshf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'sshf' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'sshf' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'sshf' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'sshf' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux
'slhf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'slhf' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'slhf' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'slhf' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'slhf' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 147 ;
	}
#Charnock
'chnk' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 148 ;
	}
#Surface net radiation
'snr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 149 ;
	}
#Top net radiation
'tnr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 150 ;
	}
#Mean sea level pressure
'msl' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'msl' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'msl' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'msl' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'msl' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 151 ;
	}
#Logarithm of surface pressure
'lnsp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 152 ;
	}
#Logarithm of surface pressure
'lnsp' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 152 ;
	}
#Short-wave heating rate
'swhr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 153 ;
	}
#Long-wave heating rate
'lwhr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 154 ;
	}
#Divergence
'd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'd' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'd' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'd' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'd' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 155 ;
	}
#Geopotential Height
'gh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 156 ;
	}
#Relative humidity
'r' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 157 ;
	}
#Relative humidity
'r' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 157 ;
	}
#Relative humidity
'r' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 157 ;
	}
#Tendency of surface pressure
'tsp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 158 ;
	}
#Tendency of surface pressure
'tsp' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 158 ;
	}
#Boundary layer height
'blh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 159 ;
	}
#Standard deviation of orography
'sdor' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 160 ;
	}
#Anisotropy of sub-gridscale orography
'isor' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 161 ;
	}
#Angle of sub-gridscale orography
'anor' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 162 ;
	}
#Slope of sub-gridscale orography
'slor' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 163 ;
	}
#Total cloud cover
'tcc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'tcc' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'tcc' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'tcc' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'tcc' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 164 ;
	}
#10 metre U wind component
'10u' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre U wind component
'10u' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre U wind component
'10u' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre U wind component
'10u' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component
'10v' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 166 ;
	}
#10 metre V wind component
'10v' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 166 ;
	}
#10 metre V wind component
'10v' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 166 ;
	}
#10 metre V wind component
'10v' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature
'2t' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre temperature
'2t' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre temperature
'2t' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre temperature
'2t' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre dewpoint temperature
'2d' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 168 ;
	}
#2 metre dewpoint temperature
'2d' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 168 ;
	}
#2 metre dewpoint temperature
'2d' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 168 ;
	}
#2 metre dewpoint temperature
'2d' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 168 ;
	}
#Surface solar radiation downwards
'ssrd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 169 ;
	}
#Surface solar radiation downwards
'ssrd' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 169 ;
	}
#Soil temperature level 2
'stl2' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 170 ;
	}
#Soil temperature level 2
'stl2' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 170 ;
	}
#Soil wetness level 2
'swl2' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 171 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'lsm' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 172 ;
	}
#Surface roughness
'sr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 173 ;
	}
#Surface roughness
'sr' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 173 ;
	}
#Albedo
'al' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 174 ;
	}
#Albedo
'al' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 174 ;
	}
#Albedo
'al' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 174 ;
	}
#Surface thermal radiation downwards
'strd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 175 ;
	}
#Surface thermal radiation downwards
'strd' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 175 ;
	}
#Surface net solar radiation
'ssr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net solar radiation
'ssr' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net solar radiation
'ssr' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net solar radiation
'ssr' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation
'str' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 177 ;
	}
#Surface net thermal radiation
'str' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 177 ;
	}
#Surface net thermal radiation
'str' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 177 ;
	}
#Surface net thermal radiation
'str' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation
'tsr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 178 ;
	}
#Top net solar radiation
'tsr' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 178 ;
	}
#Top net solar radiation
'tsr' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation
'ttr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 179 ;
	}
#Top net thermal radiation
'ttr' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 179 ;
	}
#Top net thermal radiation
'ttr' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 179 ;
	}
#Eastward turbulent surface stress
'ewss' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 180 ;
	}
#Eastward turbulent surface stress
'ewss' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 180 ;
	}
#Eastward turbulent surface stress
'ewss' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 180 ;
	}
#Northward turbulent surface stress
'nsss' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 181 ;
	}
#Northward turbulent surface stress
'nsss' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 181 ;
	}
#Northward turbulent surface stress
'nsss' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation
'e' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 182 ;
	}
#Evaporation
'e' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 182 ;
	}
#Evaporation
'e' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 182 ;
	}
#Evaporation
'e' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 182 ;
	}
#Soil temperature level 3
'stl3' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 183 ;
	}
#Soil temperature level 3
'stl3' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 183 ;
	}
#Soil wetness level 3
'swl3' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 184 ;
	}
#Soil wetness level 3
'swl3' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 184 ;
	}
#Convective cloud cover
'ccc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 185 ;
	}
#Convective cloud cover
'ccc' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 185 ;
	}
#Convective cloud cover
'ccc' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 185 ;
	}
#Low cloud cover
'lcc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 186 ;
	}
#Low cloud cover
'lcc' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 186 ;
	}
#Medium cloud cover
'mcc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 187 ;
	}
#Medium cloud cover
'mcc' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 187 ;
	}
#High cloud cover
'hcc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 188 ;
	}
#High cloud cover
'hcc' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 188 ;
	}
#Sunshine duration
'sund' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 189 ;
	}
#East-West component of sub-gridscale orographic variance
'ewov' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 190 ;
	}
#East-West component of sub-gridscale orographic variance
'ewov' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 190 ;
	}
#North-South component of sub-gridscale orographic variance
'nsov' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 191 ;
	}
#North-South component of sub-gridscale orographic variance
'nsov' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 191 ;
	}
#North-West/South-East component of sub-gridscale orographic variance
'nwov' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 192 ;
	}
#North-West/South-East component of sub-gridscale orographic variance
'nwov' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 192 ;
	}
#North-East/South-West component of sub-gridscale orographic variance
'neov' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 193 ;
	}
#North-East/South-West component of sub-gridscale orographic variance
'neov' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 193 ;
	}
#Brightness temperature
'btmp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 194 ;
	}
#Eastward gravity wave surface stress
'lgws' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 195 ;
	}
#Eastward gravity wave surface stress
'lgws' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 195 ;
	}
#Northward gravity wave surface stress
'mgws' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 196 ;
	}
#Northward gravity wave surface stress
'mgws' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation
'gwd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 197 ;
	}
#Gravity wave dissipation
'gwd' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 197 ;
	}
#Skin reservoir content
'src' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 198 ;
	}
#Vegetation fraction
'veg' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 199 ;
	}
#Variance of sub-gridscale orography
'vso' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 200 ;
	}
#Variance of sub-gridscale orography
'vso' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 200 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'mx2t' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 201 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'mx2t' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 201 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'mx2t' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'mn2t' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 202 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'mn2t' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 202 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'mn2t' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 202 ;
	}
#Ozone mass mixing ratio
'o3' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 203 ;
	}
#Precipitation analysis weights
'paw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 204 ;
	}
#Precipitation analysis weights
'paw' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 204 ;
	}
#Runoff
'ro' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 205 ;
	}
#Runoff
'ro' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 205 ;
	}
#Total column ozone
'tco3' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 206 ;
	}
#10 metre wind speed
'10si' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 207 ;
	}
#Top net solar radiation, clear sky
'tsrc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation, clear sky
'ttrc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation, clear sky
'ssrc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky
'strc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 211 ;
	}
#TOA incident solar radiation
'tisr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 212 ;
	}
#Vertically integrated moisture divergence
'vimd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 213 ;
	}
#Diabatic heating by radiation
'dhr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 214 ;
	}
#Diabatic heating by vertical diffusion
'dhvd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 215 ;
	}
#Diabatic heating by cumulus convection
'dhcc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 216 ;
	}
#Diabatic heating large-scale condensation
'dhlc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 217 ;
	}
#Vertical diffusion of zonal wind
'vdzw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 218 ;
	}
#Vertical diffusion of meridional wind
'vdmw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 219 ;
	}
#East-West gravity wave drag tendency
'ewgd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 220 ;
	}
#North-South gravity wave drag tendency
'nsgd' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 221 ;
	}
#Convective tendency of zonal wind
'ctzw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 222 ;
	}
#Convective tendency of zonal wind
'ctzw' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 222 ;
	}
#Convective tendency of meridional wind
'ctmw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 223 ;
	}
#Convective tendency of meridional wind
'ctmw' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 223 ;
	}
#Vertical diffusion of humidity
'vdh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 224 ;
	}
#Humidity tendency by cumulus convection
'htcc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 225 ;
	}
#Humidity tendency by large-scale condensation
'htlc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 226 ;
	}
#Tendency due to removal of negative humidity
'crnh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 227 ;
	}
#Tendency due to removal of negative humidity
'crnh' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 227 ;
	}
#Total precipitation
'tp' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 228 ;
	}
#Total precipitation
'tp' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 228 ;
	}
#Total precipitation
'tp' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 228 ;
	}
#Total precipitation
'tp' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 228 ;
	}
#Instantaneous eastward turbulent surface stress
'iews' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 229 ;
	}
#Instantaneous eastward turbulent surface stress
'iews' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 229 ;
	}
#Instantaneous northward turbulent surface stress
'inss' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 230 ;
	}
#Instantaneous northward turbulent surface stress
'inss' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 230 ;
	}
#Instantaneous surface sensible heat flux
'ishf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 231 ;
	}
#Instantaneous moisture flux
'ie' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 232 ;
	}
#Instantaneous moisture flux
'ie' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 232 ;
	}
#Apparent surface humidity
'asq' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 233 ;
	}
#Apparent surface humidity
'asq' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 233 ;
	}
#Logarithm of surface roughness length for heat
'lsrh' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 234 ;
	}
#Logarithm of surface roughness length for heat
'lsrh' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 234 ;
	}
#Skin temperature
'skt' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 235 ;
	}
#Skin temperature
'skt' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 235 ;
	}
#Soil temperature level 4
'stl4' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 236 ;
	}
#Soil temperature level 4
'stl4' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 236 ;
	}
#Soil wetness level 4
'swl4' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 237 ;
	}
#Soil wetness level 4
'swl4' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 237 ;
	}
#Temperature of snow layer
'tsn' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 238 ;
	}
#Temperature of snow layer
'tsn' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 238 ;
	}
#Convective snowfall
'csf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 239 ;
	}
#Large-scale snowfall
'lsf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 240 ;
	}
#Accumulated cloud fraction tendency
'acf' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 241 ;
	}
#Accumulated liquid water tendency
'alw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 242 ;
	}
#Forecast albedo
'fal' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 243 ;
	}
#Forecast surface roughness
'fsr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 244 ;
	}
#Forecast surface roughness
'fsr' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 244 ;
	}
#Forecast logarithm of surface roughness for heat
'flsr' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 245 ;
	}
#Forecast logarithm of surface roughness for heat
'flsr' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 245 ;
	}
#Specific cloud liquid water content
'clwc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 246 ;
	}
#Specific cloud ice water content
'ciwc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 247 ;
	}
#Fraction of cloud cover
'cc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 248 ;
	}
#Accumulated ice water tendency
'aiw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 249 ;
	}
#Ice age
'ice' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 250 ;
	}
#Adiabatic tendency of temperature
'atte' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 251 ;
	}
#Adiabatic tendency of humidity
'athe' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 252 ;
	}
#Adiabatic tendency of zonal wind
'atze' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 253 ;
	}
#Adiabatic tendency of meridional wind
'atmw' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 254 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 255 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 255 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 255 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 255 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 255 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 255 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 255 ;
	}
#Stream function difference
'strfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 1 ;
	}
#Velocity potential difference
'vpotdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 2 ;
	}
#Potential temperature difference
'ptdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 3 ;
	}
#Equivalent potential temperature difference
'eqptdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 4 ;
	}
#Saturated equivalent potential temperature difference
'septdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 5 ;
	}
#U component of divergent wind difference
'udvwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 11 ;
	}
#V component of divergent wind difference
'vdvwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 12 ;
	}
#U component of rotational wind difference
'urtwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 13 ;
	}
#V component of rotational wind difference
'vrtwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 14 ;
	}
#Unbalanced component of temperature difference
'uctpdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 21 ;
	}
#Unbalanced component of logarithm of surface pressure difference
'uclndiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 22 ;
	}
#Unbalanced component of divergence difference
'ucdvdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 23 ;
	}
#Reserved for future unbalanced components
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 24 ;
	}
#Reserved for future unbalanced components
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 25 ;
	}
#Lake cover difference
'cldiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 26 ;
	}
#Low vegetation cover difference
'cvldiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 27 ;
	}
#High vegetation cover difference
'cvhdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 28 ;
	}
#Type of low vegetation difference
'tvldiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 29 ;
	}
#Type of high vegetation difference
'tvhdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 30 ;
	}
#Sea-ice cover difference
'sicdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 31 ;
	}
#Snow albedo difference
'asndiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 32 ;
	}
#Snow density difference
'rsndiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 33 ;
	}
#Sea surface temperature difference
'sstdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 34 ;
	}
#Ice surface temperature layer 1 difference
'istl1diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 35 ;
	}
#Ice surface temperature layer 2 difference
'istl2diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 36 ;
	}
#Ice surface temperature layer 3 difference
'istl3diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 37 ;
	}
#Ice surface temperature layer 4 difference
'istl4diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 38 ;
	}
#Volumetric soil water layer 1 difference
'swvl1diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 39 ;
	}
#Volumetric soil water layer 2 difference
'swvl2diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 40 ;
	}
#Volumetric soil water layer 3 difference
'swvl3diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 41 ;
	}
#Volumetric soil water layer 4 difference
'swvl4diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 42 ;
	}
#Soil type difference
'sltdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 43 ;
	}
#Snow evaporation difference
'esdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt difference
'smltdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 45 ;
	}
#Solar duration difference
'sdurdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 46 ;
	}
#Direct solar radiation difference
'dsrpdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 47 ;
	}
#Magnitude of turbulent surface stress difference
'magssdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 48 ;
	}
#10 metre wind gust difference
'10fgdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 49 ;
	}
#Large-scale precipitation fraction difference
'lspfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 50 ;
	}
#Maximum 2 metre temperature difference
'mx2t24diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 51 ;
	}
#Minimum 2 metre temperature difference
'mn2t24diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 52 ;
	}
#Montgomery potential difference
'montdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 53 ;
	}
#Pressure difference
'presdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 54 ;
	}
#Mean 2 metre temperature in the last 24 hours difference
'mean2t24diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours difference
'mn2d24diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 56 ;
	}
#Downward UV radiation at the surface difference
'uvbdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 57 ;
	}
#Photosynthetically active radiation at the surface difference
'pardiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 58 ;
	}
#Convective available potential energy difference
'capediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 59 ;
	}
#Potential vorticity difference
'pvdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 60 ;
	}
#Total precipitation from observations difference
'tpodiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 61 ;
	}
#Observation count difference
'obctdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 62 ;
	}
#Start time for skin temperature difference
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 63 ;
	}
#Finish time for skin temperature difference
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 64 ;
	}
#Skin temperature difference
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 65 ;
	}
#Leaf area index, low vegetation
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 66 ;
	}
#Leaf area index, high vegetation
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 67 ;
	}
#Minimum stomatal resistance, low vegetation
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 68 ;
	}
#Minimum stomatal resistance, high vegetation
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 69 ;
	}
#Biome cover, low vegetation
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 70 ;
	}
#Biome cover, high vegetation
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 71 ;
	}
#Total column liquid water
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 78 ;
	}
#Total column ice water
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 79 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 80 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 81 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 82 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 83 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 84 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 85 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 86 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 87 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 88 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 89 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 90 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 91 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 92 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 93 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 94 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 95 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 96 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 97 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 98 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 99 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 100 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 101 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 102 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 103 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 104 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 105 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 106 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 107 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 108 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 109 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 110 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 111 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 112 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 113 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 114 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 115 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 116 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 117 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 118 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 119 ;
	}
#Experimental product
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 120 ;
	}
#Maximum temperature at 2 metres difference
'mx2t6diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 121 ;
	}
#Minimum temperature at 2 metres difference
'mn2t6diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 122 ;
	}
#10 metre wind gust in the last 6 hours difference
'10fg6diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 123 ;
	}
#Vertically integrated total energy
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 125 ;
	}
#Generic parameter for sensitive area prediction
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 126 ;
	}
#Atmospheric tide difference
'atdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 127 ;
	}
#Budget values difference
'bvdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 128 ;
	}
#Geopotential difference
'zdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 129 ;
	}
#Temperature difference
'tdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 130 ;
	}
#U component of wind difference
'udiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 131 ;
	}
#V component of wind difference
'vdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 132 ;
	}
#Specific humidity difference
'qdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 133 ;
	}
#Surface pressure difference
'spdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 134 ;
	}
#Vertical velocity (pressure) difference
'wdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 135 ;
	}
#Total column water difference
'tcwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 136 ;
	}
#Total column water vapour difference
'tcwvdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 137 ;
	}
#Vorticity (relative) difference
'vodiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 138 ;
	}
#Soil temperature level 1 difference
'stl1diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 139 ;
	}
#Soil wetness level 1 difference
'swl1diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 140 ;
	}
#Snow depth difference
'sddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 141 ;
	}
#Stratiform precipitation (Large-scale precipitation) difference
'lspdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation difference
'cpdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall (convective + stratiform) difference
'sfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation difference
'blddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux difference
'sshfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux difference
'slhfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 147 ;
	}
#Charnock difference
'chnkdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 148 ;
	}
#Surface net radiation difference
'snrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 149 ;
	}
#Top net radiation difference
'tnrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 150 ;
	}
#Mean sea level pressure difference
'msldiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 151 ;
	}
#Logarithm of surface pressure difference
'lnspdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 152 ;
	}
#Short-wave heating rate difference
'swhrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 153 ;
	}
#Long-wave heating rate difference
'lwhrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 154 ;
	}
#Divergence difference
'ddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 155 ;
	}
#Height difference
'ghdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 156 ;
	}
#Relative humidity difference
'rdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 157 ;
	}
#Tendency of surface pressure difference
'tspdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 158 ;
	}
#Boundary layer height difference
'blhdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 159 ;
	}
#Standard deviation of orography difference
'sdordiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 160 ;
	}
#Anisotropy of sub-gridscale orography difference
'isordiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 161 ;
	}
#Angle of sub-gridscale orography difference
'anordiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 162 ;
	}
#Slope of sub-gridscale orography difference
'slordiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 163 ;
	}
#Total cloud cover difference
'tccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 164 ;
	}
#10 metre U wind component difference
'10udiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component difference
'10vdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature difference
'2tdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 167 ;
	}
#Surface solar radiation downwards difference
'ssrddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 169 ;
	}
#Soil temperature level 2 difference
'stl2diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 170 ;
	}
#Soil wetness level 2 difference
'swl2diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 171 ;
	}
#Land-sea mask difference
'lsmdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 172 ;
	}
#Surface roughness difference
'srdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 173 ;
	}
#Albedo difference
'aldiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 174 ;
	}
#Surface thermal radiation downwards difference
'strddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 175 ;
	}
#Surface net solar radiation difference
'ssrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation difference
'strdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation difference
'tsrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation difference
'ttrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 179 ;
	}
#East-West surface stress difference
'ewssdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress difference
'nsssdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation difference
'ediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 182 ;
	}
#Soil temperature level 3 difference
'stl3diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 183 ;
	}
#Soil wetness level 3 difference
'swl3diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 184 ;
	}
#Convective cloud cover difference
'cccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 185 ;
	}
#Low cloud cover difference
'lccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 186 ;
	}
#Medium cloud cover difference
'mccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 187 ;
	}
#High cloud cover difference
'hccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 188 ;
	}
#Sunshine duration difference
'sunddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 189 ;
	}
#East-West component of sub-gridscale orographic variance difference
'ewovdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 190 ;
	}
#North-South component of sub-gridscale orographic variance difference
'nsovdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 191 ;
	}
#North-West/South-East component of sub-gridscale orographic variance difference
'nwovdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 192 ;
	}
#North-East/South-West component of sub-gridscale orographic variance difference
'neovdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 193 ;
	}
#Brightness temperature difference
'btmpdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 194 ;
	}
#Longitudinal component of gravity wave stress difference
'lgwsdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 195 ;
	}
#Meridional component of gravity wave stress difference
'mgwsdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation difference
'gwddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 197 ;
	}
#Skin reservoir content difference
'srcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 198 ;
	}
#Vegetation fraction difference
'vegdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 199 ;
	}
#Variance of sub-gridscale orography difference
'vsodiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 200 ;
	}
#Maximum temperature at 2 metres since previous post-processing difference
'mx2tdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres since previous post-processing difference
'mn2tdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 202 ;
	}
#Ozone mass mixing ratio difference
'o3diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 203 ;
	}
#Precipitation analysis weights difference
'pawdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 204 ;
	}
#Runoff difference
'rodiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 205 ;
	}
#Total column ozone difference
'tco3diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 206 ;
	}
#10 metre wind speed difference
'10sidiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 207 ;
	}
#Top net solar radiation, clear sky difference
'tsrcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation, clear sky difference
'ttrcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation, clear sky difference
'ssrcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky difference
'strcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 211 ;
	}
#TOA incident solar radiation difference
'tisrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 212 ;
	}
#Diabatic heating by radiation difference
'dhrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 214 ;
	}
#Diabatic heating by vertical diffusion difference
'dhvddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 215 ;
	}
#Diabatic heating by cumulus convection difference
'dhccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 216 ;
	}
#Diabatic heating large-scale condensation difference
'dhlcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 217 ;
	}
#Vertical diffusion of zonal wind difference
'vdzwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 218 ;
	}
#Vertical diffusion of meridional wind difference
'vdmwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 219 ;
	}
#East-West gravity wave drag tendency difference
'ewgddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 220 ;
	}
#North-South gravity wave drag tendency difference
'nsgddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 221 ;
	}
#Convective tendency of zonal wind difference
'ctzwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 222 ;
	}
#Convective tendency of meridional wind difference
'ctmwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 223 ;
	}
#Vertical diffusion of humidity difference
'vdhdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 224 ;
	}
#Humidity tendency by cumulus convection difference
'htccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 225 ;
	}
#Humidity tendency by large-scale condensation difference
'htlcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 226 ;
	}
#Change from removal of negative humidity difference
'crnhdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 227 ;
	}
#Total precipitation difference
'tpdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 228 ;
	}
#Instantaneous X surface stress difference
'iewsdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 229 ;
	}
#Instantaneous Y surface stress difference
'inssdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 230 ;
	}
#Instantaneous surface heat flux difference
'ishfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 231 ;
	}
#Instantaneous moisture flux difference
'iediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 232 ;
	}
#Apparent surface humidity difference
'asqdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 233 ;
	}
#Logarithm of surface roughness length for heat difference
'lsrhdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 234 ;
	}
#Skin temperature difference
'sktdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 235 ;
	}
#Soil temperature level 4 difference
'stl4diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 236 ;
	}
#Soil wetness level 4 difference
'swl4diff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 237 ;
	}
#Temperature of snow layer difference
'tsndiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 238 ;
	}
#Convective snowfall difference
'csfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall difference
'lsfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 240 ;
	}
#Accumulated cloud fraction tendency difference
'acfdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 241 ;
	}
#Accumulated liquid water tendency difference
'alwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 242 ;
	}
#Forecast albedo difference
'faldiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 243 ;
	}
#Forecast surface roughness difference
'fsrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 244 ;
	}
#Forecast logarithm of surface roughness for heat difference
'flsrdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 245 ;
	}
#Specific cloud liquid water content difference
'clwcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 246 ;
	}
#Specific cloud ice water content difference
'ciwcdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 247 ;
	}
#Cloud cover difference
'ccdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 248 ;
	}
#Accumulated ice water tendency difference
'aiwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 249 ;
	}
#Ice age difference
'icediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 250 ;
	}
#Adiabatic tendency of temperature difference
'attediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 251 ;
	}
#Adiabatic tendency of humidity difference
'athediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 252 ;
	}
#Adiabatic tendency of zonal wind difference
'atzediff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 253 ;
	}
#Adiabatic tendency of meridional wind difference
'atmwdiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 254 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 255 ;
	}
#Probability of a tropical storm
'pts' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 89 ;
	}
#Probability of a hurricane
'ph' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 90 ;
	}
#Probability of a tropical depression
'ptd' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 91 ;
	}
#Climatological probability of a tropical storm
'cpts' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 92 ;
	}
#Climatological probability of a hurricane
'cph' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 93 ;
	}
#Climatological probability of a tropical depression
'cptd' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 94 ;
	}
#Probability anomaly of a tropical storm
'pats' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 95 ;
	}
#Probability anomaly of a hurricane
'pah' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 96 ;
	}
#Probability anomaly of a tropical depression
'patd' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 97 ;
	}
#Total precipitation of at least 25 mm
'tpg25' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 98 ;
	}
#Total precipitation of at least 50 mm
'tpg50' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 99 ;
	}
#10 metre wind gust of at least 10 m/s
'10fgg10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 100 ;
	}
#Convective available potential energy shear index
'capesi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 44 ;
	}
#Water vapour flux index
'wvfi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 45 ;
	}
#Convective available potential energy index
'capei' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 59 ;
	}
#Maximum of significant wave height index
'maxswhi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 216 ;
	}
#Wave experimental parameter 1
'wx1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 80 ;
	}
#Wave experimental parameter 2
'wx2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 81 ;
	}
#Wave experimental parameter 3
'wx3' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 82 ;
	}
#Wave experimental parameter 4
'wx4' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 83 ;
	}
#Wave experimental parameter 5
'wx5' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 84 ;
	}
#Wave induced mean sea level correction
'weta' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 98 ;
	}
#Ratio of wave angular and frequency width
'wraf' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 99 ;
	}
#Number of events in freak waves statistics
'wnslc' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 100 ;
	}
#U-component of atmospheric surface momentum flux
'utaua' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 101 ;
	}
#V-component of atmospheric surface momentum flux
'vtaua' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 102 ;
	}
#U-component of surface momentum flux into ocean
'utauo' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 103 ;
	}
#V-component of surface momentum flux into ocean
'vtauo' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 104 ;
	}
#Wave turbulent energy flux into ocean
'wphio' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 105 ;
	}
#Wave directional width of first swell partition
'wdw1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 106 ;
	}
#Wave frequency width of first swell partition
'wfw1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 107 ;
	}
#Wave directional width of second swell partition
'wdw2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 108 ;
	}
#Wave frequency width of second swell partition
'wfw2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 109 ;
	}
#Wave directional width of third swell partition
'wdw3' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 110 ;
	}
#Wave frequency width of third swell partition
'wfw3' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 111 ;
	}
#Wave energy flux magnitude
'wefxm' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 112 ;
	}
#Wave energy flux mean direction
'wefxd' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 113 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'h1012' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 114 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'h1214' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 115 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'h1417' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 116 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'h1721' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 117 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'h2125' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 118 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'h2530' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 119 ;
	}
#Significant wave height of all waves with period larger than 10s
'sh10' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 120 ;
	}
#Significant wave height of first swell partition
'swh1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 121 ;
	}
#Mean wave direction of first swell partition
'mwd1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 122 ;
	}
#Mean wave period of first swell partition
'mwp1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 123 ;
	}
#Significant wave height of second swell partition
'swh2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 124 ;
	}
#Mean wave direction of second swell partition
'mwd2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 125 ;
	}
#Mean wave period of second swell partition
'mwp2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 126 ;
	}
#Significant wave height of third swell partition
'swh3' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 127 ;
	}
#Mean wave direction of third swell partition
'mwd3' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 128 ;
	}
#Mean wave period of third swell partition
'mwp3' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 129 ;
	}
#Wave Spectral Skewness
'wss' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 207 ;
	}
#Free convective velocity over the oceans
'wstar' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 208 ;
	}
#Air density over the oceans
'rhoao' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 209 ;
	}
#Mean square wave strain in sea ice
'mswsi' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 210 ;
	}
#Normalized energy flux into waves
'phiaw' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 211 ;
	}
#Normalized energy flux into ocean
'phioc' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 212 ;
	}
#Turbulent Langmuir number
'tla' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 213 ;
	}
#Normalized stress into ocean
'tauoc' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 214 ;
	}
#Reserved
'~' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 193 ;
	}
#Water vapour flux
'wvf' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 45 ;
	}
#Vertical integral of divergence of cloud liquid water flux
'vilwd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 79 ;
	}
#Vertical integral of divergence of cloud frozen water flux
'viiwd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 80 ;
	}
#Vertical integral of eastward cloud liquid water flux
'vilwe' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 88 ;
	}
#Vertical integral of northward cloud liquid water flux
'vilwn' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 89 ;
	}
#Vertical integral of eastward cloud frozen water flux
'viiwe' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 90 ;
	}
#Vertical integral of northward cloud frozen water flux 
'viiwn' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 91 ;
	}
#Vertical integral of mass tendency
'vimat' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 92 ;
	}
#U-tendency from dynamics
'utendd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 114 ;
	}
#V-tendency from dynamics
'vtendd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 115 ;
	}
#T-tendency from dynamics
'ttendd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 116 ;
	}
#q-tendency from dynamics
'qtendd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 117 ;
	}
#T-tendency from radiation
'ttendr' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 118 ;
	}
#U-tendency from turbulent diffusion + subgrid orography
'utendts' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 119 ;
	}
#V-tendency from turbulent diffusion + subgrid orography
'vtendts' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 120 ;
	}
#T-tendency from turbulent diffusion + subgrid orography
'ttendts' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 121 ;
	}
#q-tendency from turbulent diffusion
'qtendt' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 122 ;
	}
#U-tendency from subgrid orography
'utends' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 123 ;
	}
#V-tendency from subgrid orography
'vtends' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 124 ;
	}
#T-tendency from subgrid orography
'ttends' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 125 ;
	}
#U-tendency from convection (deep+shallow)
'utendcds' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 126 ;
	}
#V-tendency from convection (deep+shallow)
'vtendcds' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 127 ;
	}
#T-tendency from convection (deep+shallow)
'ttendcds' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 128 ;
	}
#q-tendency from convection (deep+shallow)
'qtendcds' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 129 ;
	}
#Liquid Precipitation flux from convection
'lpc' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 130 ;
	}
#Ice Precipitation flux from convection
'ipc' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 131 ;
	}
#T-tendency from cloud scheme
'ttendcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 132 ;
	}
#q-tendency from cloud scheme
'qtendcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 133 ;
	}
#ql-tendency from cloud scheme
'qltendcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 134 ;
	}
#qi-tendency from cloud scheme
'qitendcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 135 ;
	}
#Liquid Precip flux from cloud scheme (stratiform)
'lpcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 136 ;
	}
#Ice Precip flux from cloud scheme (stratiform)
'ipcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 137 ;
	}
#U-tendency from shallow convection
'utendcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 138 ;
	}
#V-tendency from shallow convection
'vtendcs' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 139 ;
	}
#T-tendency from shallow convection
'ttendsc' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 140 ;
	}
#q-tendency from shallow convection
'qtendsc' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 141 ;
	}
#Standardised precipitation index valid in the last 3 months
'spi03' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 1 ;
	}
#Standardised precipitation index valid in the last 6 months
'spi06' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 2 ;
	}
#Standardised precipitation index valid in the last 12 months
'spi12' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 3 ;
	}
#100 metre U wind component anomaly
'100ua' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 6 ;
	}
#100 metre V wind component anomaly
'100va' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 7 ;
	}
#Lake mix-layer temperature anomaly
'lmlta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 24 ;
	}
#Lake ice depth anomaly
'licda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 25 ;
	}
#Maximum temperature at 2 metres in the last 6 hours anomaly
'mx2t6a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 121 ;
	}
#Minimum temperature at 2 metres in the last 6 hours anomaly
'mn2t6a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 122 ;
	}
#Mean surface runoff rate
'msror' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 8 ;
	}
#Mean sub-surface runoff rate
'mssror' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 9 ;
	}
#Mean surface runoff rate anomaly
'msrora' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 8 ;
	}
#Mean sub-surface runoff rate anomaly
'mssrora' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 9 ;
	}
#Clear-sky (II) down surface sw flux
'sswcsdown' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 10 ;
	}
#Clear-sky (II) up surface sw flux
'sswcsup' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 13 ;
	}
#Visibility at 1.5m
'vis15' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 25 ;
	}
#Minimum temperature at 1.5m since previous post-processing
'mn15t' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 50 ;
	}
#Maximum temperature at 1.5m since previous post-processing
'mx15t' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 51 ;
	}
#Relative humidity at 1.5m
'rhum' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 52 ;
	}
#2 metre specific humidity
'2sh' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 96 ;
	}
#Sea ice snow thickness
'sisnthick' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 97 ;
	}
#Short wave radiation flux at surface
'swrsurf' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 116 ;
	}
#Short wave radiation flux at top of atmosphere
'swrtop' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 117 ;
	}
#Total column water vapour
'tcwvap' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 137 ;
	}
#Large scale rainfall rate
'lsrrate' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 142 ;
	}
#Convective rainfall rate
'crfrate' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 143 ;
	}
#Very low cloud amount
'vlca' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 186 ;
	}
#Convective snowfall rate
'csfrate' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall rate
'lsfrate' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 240 ;
	}
#Total cloud amount - random overlap
'tccro' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 248 ;
	}
#Total cloud amount in lw radiation
'tcclwr' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 249 ;
	}
#Volcanic ash aerosol mixing ratio
'aermr13' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 13 ;
	}
#Volcanic sulphate aerosol mixing ratio
'aermr14' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 14 ;
	}
#Volcanic SO2 precursor mixing ratio
'aermr15' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 15 ;
	}
#SO4 aerosol precursor mass mixing ratio
'aerpr03' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 28 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 1
'aerwv01' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 29 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 2
'aerwv02' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 30 ;
	}
#DMS surface emission
'emdms' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 43 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 3
'aerwv03' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 44 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 4
'aerwv04' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 45 ;
	}
#Experimental product
'~' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 55 ;
	}
#Experimental product
'~' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 56 ;
	}
#Mixing ration of organic carbon aerosol, nucleation mode
'ocnuc' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 57 ;
	}
#Monoterpene precursor mixing ratio
'monot' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 58 ;
	}
#Secondary organic precursor mixing ratio
'soapr' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 59 ;
	}
#Injection height (from IS4FIRES)
'injh' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 60 ;
	}
#Particulate matter d < 1 um
'pm1' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 72 ;
	}
#Particulate matter d < 2.5 um
'pm2p5' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 73 ;
	}
#Particulate matter d < 10 um
'pm10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 74 ;
	}
#Wildfire viewing angle of observation
'vafire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 79 ;
	}
#Wildfire Flux of Ethane (C2H6)
'c2h6fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 118 ;
	}
#Mean altitude of maximum injection
'mami' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 119 ;
	}
#Altitude of plume top
'apt' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 120 ;
	}
#UV visible albedo for direct radiation, isotropic component 
'aluvpi' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 186 ;
	}
#UV visible albedo for direct radiation, volumetric component 
'aluvpv' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 187 ;
	}
#UV visible albedo for direct radiation, geometric component 
'aluvpg' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 188 ;
	}
#Near IR albedo for direct radiation, isotropic component 
'alnipi' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 189 ;
	}
#Near IR albedo for direct radiation, volumetric component
'alnipv' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 190 ;
	}
#Near IR albedo for direct radiation, geometric component 
'alnipg' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 191 ;
	}
#UV visible albedo for diffuse radiation, isotropic component 
'aluvdi' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 192 ;
	}
#UV visible albedo for diffuse radiation, volumetric component 
'aluvdv' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 193 ;
	}
#UV visible albedo for diffuse radiation, geometric component 
'aluvdg' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 194 ;
	}
#Near IR albedo for diffuse radiation, isotropic component 
'alnidi' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 195 ;
	}
#Near IR albedo for diffuse radiation, volumetric component 
'alnidv' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 196 ;
	}
#Near IR albedo for diffuse radiation, geometric component 
'alnidg' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 197 ;
	}
#Total aerosol optical depth at 340 nm
'aod340' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 217 ;
	}
#Total aerosol optical depth at 355 nm
'aod355' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 218 ;
	}
#Total aerosol optical depth at 380 nm
'aod380' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 219 ;
	}
#Total aerosol optical depth at 400 nm
'aod400' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 220 ;
	}
#Total aerosol optical depth at 440 nm
'aod440' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 221 ;
	}
#Total aerosol optical depth at 500 nm
'aod500' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 222 ;
	}
#Total aerosol optical depth at 532 nm
'aod532' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 223 ;
	}
#Total aerosol optical depth at 645 nm
'aod645' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 224 ;
	}
#Total aerosol optical depth at 800 nm
'aod800' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 225 ;
	}
#Total aerosol optical depth at 858 nm
'aod858' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 226 ;
	}
#Total aerosol optical depth at 1020 nm
'aod1020' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 227 ;
	}
#Total aerosol optical depth at 1064 nm
'aod1064' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 228 ;
	}
#Total aerosol optical depth at 1640 nm
'aod1640' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 229 ;
	}
#Total aerosol optical depth at 2130 nm
'aod2130' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 230 ;
	}
#Wildfire Flux of Toluene (C7H8)
'c7h8fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 231 ;
	}
#Wildfire Flux of Benzene (C6H6)
'c6h6fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 232 ;
	}
#Wildfire Flux of Xylene (C8H10)
'c8h10fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 233 ;
	}
#Wildfire Flux of Butenes (C4H8)
'c4h8fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 234 ;
	}
#Wildfire Flux of Pentenes (C5H10)
'c5h10fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 235 ;
	}
#Wildfire Flux of Hexene (C6H12)
'c6h12fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 236 ;
	}
#Wildfire Flux of Octene (C8H16)
'c8h16fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 237 ;
	}
#Wildfire Flux of Butanes (C4H10)
'c4h10fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 238 ;
	}
#Wildfire Flux of Pentanes (C5H12)
'c5h12fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 239 ;
	}
#Wildfire Flux of Hexanes (C6H14)
'c6h14fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 240 ;
	}
#Wildfire Flux of Heptane (C7H16)
'c7h16fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 241 ;
	}
#Altitude of plume bottom
'apb' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 242 ;
	}
#Volcanic sulphate aerosol optical depth at 550 nm
'vsuaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 243 ;
	}
#Volcanic ash optical depth at 550 nm
'vashaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 244 ;
	}
#Profile of total aerosol dry extinction coefficient
'taedec550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 245 ;
	}
#Profile of total aerosol dry absorption coefficient
'taedab550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 246 ;
	}
#Nitrate fine mode aerosol mass mixing ratio
'aermr16' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 247 ;
	}
#Nitrate coarse mode aerosol mass mixing ratio
'aermr17' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 248 ;
	}
#Ammonium aerosol mass mixing ratio
'aermr18' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 249 ;
	}
#Nitrate aerosol optical depth at 550 nm
'niaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 250 ;
	}
#Ammonium aerosol optical depth at 550 nm
'amaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 251 ;
	}
#Aerosol type 13 mass mixing ratio
'aermr13diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 13 ;
	}
#Aerosol type 14 mass mixing ratio
'aermr14diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 14 ;
	}
#Aerosol type 15 mass mixing ratio
'aermr15diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 15 ;
	}
#SO4 aerosol precursor mass mixing ratio
'aerpr03diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 28 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 1
'aerwv01diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 29 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 2
'aerwv02diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 30 ;
	}
#DMS surface emission
'emdmsdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 43 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 3
'aerwv03diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 44 ;
	}
#Water vapour mixing ratio for hydrophilic aerosols in mode 4
'aerwv04diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 45 ;
	}
#Experimental product
'~' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 55 ;
	}
#Experimental product
'~' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 56 ;
	}
#Wildfire Flux of Ethane (C2H6)
'c2h6firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 118 ;
	}
#Altitude of emitter
'alediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 119 ;
	}
#Altitude of plume top
'aptdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 120 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 1 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 2 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 3 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 4 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 5 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 6 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 7 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 8 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 9 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 10 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 11 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 12 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 13 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 14 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 15 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 16 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 17 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 18 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 19 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 20 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 21 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 22 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 23 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 24 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 25 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 26 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 27 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 28 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 29 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 30 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 31 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 32 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 33 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 34 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 35 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 36 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 37 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 38 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 39 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 40 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 41 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 42 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 43 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 44 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 45 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 46 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 47 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 48 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 49 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 50 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 51 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 52 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 53 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 54 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 55 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 56 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 57 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 58 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 59 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 60 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 61 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 62 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 63 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 64 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 65 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 66 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 67 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 68 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 69 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 70 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 71 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 72 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 73 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 74 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 75 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 76 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 77 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 78 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 79 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 80 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 81 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 82 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 83 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 84 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 85 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 86 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 87 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 88 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 89 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 90 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 91 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 92 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 93 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 94 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 95 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 96 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 97 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 98 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 99 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 100 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 101 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 102 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 103 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 104 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 105 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 106 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 107 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 108 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 109 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 110 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 111 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 112 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 113 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 114 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 115 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 116 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 117 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 118 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 119 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 120 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 121 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 122 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 123 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 124 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 125 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 126 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 127 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 128 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 129 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 130 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 131 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 132 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 133 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 134 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 135 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 136 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 137 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 138 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 139 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 140 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 141 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 142 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 143 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 144 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 145 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 146 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 147 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 148 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 149 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 150 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 151 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 152 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 153 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 154 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 155 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 156 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 157 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 158 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 159 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 160 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 161 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 162 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 163 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 164 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 165 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 166 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 167 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 168 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 169 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 170 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 171 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 172 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 173 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 174 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 175 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 176 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 177 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 178 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 179 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 180 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 181 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 182 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 183 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 184 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 185 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 186 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 187 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 188 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 189 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 190 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 191 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 192 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 193 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 194 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 195 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 196 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 197 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 198 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 199 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 200 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 201 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 202 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 203 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 204 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 205 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 206 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 207 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 208 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 209 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 210 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 211 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 212 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 213 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 214 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 215 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 216 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 217 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 218 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 219 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 220 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 221 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 222 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 223 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 224 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 225 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 226 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 227 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 228 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 229 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 230 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 231 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 232 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 233 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 234 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 235 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 236 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 237 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 238 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 239 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 240 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 241 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 242 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 243 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 244 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 245 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 246 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 247 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 248 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 249 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 250 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 251 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 252 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 253 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 254 ;
	}
#Experimental product
'~' = {
	 table2Version = 212 ;
	 indicatorOfParameter = 255 ;
	}
#Random pattern 1 for sppt
'sppt1' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 1 ;
	}
#Random pattern 2 for sppt
'sppt2' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 2 ;
	}
#Random pattern 3 for sppt
'sppt3' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 3 ;
	}
#Random pattern 4 for sppt
'sppt4' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 4 ;
	}
#Random pattern 5 for sppt
'sppt5' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 5 ;
	}
#Random pattern 1 for SPP scheme
'spp1' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 101 ;
	}
#Random pattern 2 for SPP scheme
'spp2' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 102 ;
	}
#Random pattern 3 for SPP scheme
'spp3' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 103 ;
	}
#Random pattern 4 for SPP scheme
'spp4' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 104 ;
	}
#Random pattern 5 for SPP scheme
'spp5' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 105 ;
	}
#Random pattern 6 for SPP scheme
'spp6' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 106 ;
	}
#Random pattern 7 for SPP scheme
'spp7' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 107 ;
	}
#Random pattern 8 for SPP scheme
'spp8' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 108 ;
	}
#Random pattern 9 for SPP scheme
'spp9' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 109 ;
	}
#Random pattern 10 for SPP scheme
'spp10' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 110 ;
	}
#Random pattern 11 for SPP scheme
'spp11' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 111 ;
	}
#Random pattern 12 for SPP scheme
'spp12' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 112 ;
	}
#Random pattern 13 for SPP scheme
'spp13' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 113 ;
	}
#Random pattern 14 for SPP scheme
'spp14' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 114 ;
	}
#Random pattern 15 for SPP scheme
'spp15' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 115 ;
	}
#Random pattern 16 for SPP scheme
'spp16' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 116 ;
	}
#Random pattern 17 for SPP scheme
'spp17' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 117 ;
	}
#Random pattern 18 for SPP scheme
'spp18' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 118 ;
	}
#Random pattern 19 for SPP scheme
'spp19' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 119 ;
	}
#Random pattern 20 for SPP scheme
'spp20' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 120 ;
	}
#Random pattern 21 for SPP scheme
'spp21' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 121 ;
	}
#Random pattern 22 for SPP scheme
'spp22' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 122 ;
	}
#Random pattern 23 for SPP scheme
'spp23' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 123 ;
	}
#Random pattern 24 for SPP scheme
'spp24' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 124 ;
	}
#Random pattern 25 for SPP scheme
'spp25' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 125 ;
	}
#Random pattern 26 for SPP scheme
'spp26' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 126 ;
	}
#Random pattern 27 for SPP scheme
'spp27' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 127 ;
	}
#Random pattern 28 for SPP scheme
'spp28' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 128 ;
	}
#Random pattern 29 for SPP scheme
'spp29' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 129 ;
	}
#Random pattern 30 for SPP scheme
'spp30' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 130 ;
	}
#Random pattern 31 for SPP scheme
'spp31' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 131 ;
	}
#Random pattern 32 for SPP scheme
'spp32' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 132 ;
	}
#Random pattern 33 for SPP scheme
'spp33' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 133 ;
	}
#Random pattern 34 for SPP scheme
'spp34' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 134 ;
	}
#Random pattern 35 for SPP scheme
'spp35' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 135 ;
	}
#Random pattern 36 for SPP scheme
'spp36' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 136 ;
	}
#Random pattern 37 for SPP scheme
'spp37' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 137 ;
	}
#Random pattern 38 for SPP scheme
'spp38' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 138 ;
	}
#Random pattern 39 for SPP scheme
'spp39' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 139 ;
	}
#Random pattern 40 for SPP scheme
'spp40' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 140 ;
	}
#Random pattern 41 for SPP scheme
'spp41' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 141 ;
	}
#Random pattern 42 for SPP scheme
'spp42' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 142 ;
	}
#Random pattern 43 for SPP scheme
'spp43' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 143 ;
	}
#Random pattern 44 for SPP scheme
'spp44' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 144 ;
	}
#Random pattern 45 for SPP scheme
'spp45' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 145 ;
	}
#Random pattern 46 for SPP scheme
'spp46' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 146 ;
	}
#Random pattern 47 for SPP scheme
'spp47' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 147 ;
	}
#Random pattern 48 for SPP scheme
'spp48' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 148 ;
	}
#Random pattern 49 for SPP scheme
'spp49' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 149 ;
	}
#Random pattern 50 for SPP scheme
'spp50' = {
	 table2Version = 213 ;
	 indicatorOfParameter = 150 ;
	}
#Cosine of solar zenith angle
'uvcossza' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 1 ;
	}
#UV biologically effective dose
'uvbed' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 2 ;
	}
#UV biologically effective dose clear-sky
'uvbedcs' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 3 ;
	}
#Total surface UV spectral flux (280-285 nm)
'uvsflxt280285' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 4 ;
	}
#Total surface UV spectral flux (285-290 nm)
'uvsflxt285290' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 5 ;
	}
#Total surface UV spectral flux (290-295 nm)
'uvsflxt290295' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 6 ;
	}
#Total surface UV spectral flux (295-300 nm)
'uvsflxt295300' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 7 ;
	}
#Total surface UV spectral flux (300-305 nm)
'uvsflxt300305' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 8 ;
	}
#Total surface UV spectral flux (305-310 nm)
'uvsflxt305310' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 9 ;
	}
#Total surface UV spectral flux (310-315 nm)
'uvsflxt310315' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 10 ;
	}
#Total surface UV spectral flux (315-320 nm)
'uvsflxt315320' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 11 ;
	}
#Total surface UV spectral flux (320-325 nm)
'uvsflxt320325' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 12 ;
	}
#Total surface UV spectral flux (325-330 nm)
'uvsflxt325330' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 13 ;
	}
#Total surface UV spectral flux (330-335 nm)
'uvsflxt330335' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 14 ;
	}
#Total surface UV spectral flux (335-340 nm)
'uvsflxt335340' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 15 ;
	}
#Total surface UV spectral flux (340-345 nm)
'uvsflxt340345' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 16 ;
	}
#Total surface UV spectral flux (345-350 nm)
'uvsflxt345350' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 17 ;
	}
#Total surface UV spectral flux (350-355 nm)
'uvsflxt350355' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 18 ;
	}
#Total surface UV spectral flux (355-360 nm)
'uvsflxt355360' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 19 ;
	}
#Total surface UV spectral flux (360-365 nm)
'uvsflxt360365' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 20 ;
	}
#Total surface UV spectral flux (365-370 nm)
'uvsflxt365370' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 21 ;
	}
#Total surface UV spectral flux (370-375 nm)
'uvsflxt370375' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 22 ;
	}
#Total surface UV spectral flux (375-380 nm)
'uvsflxt375380' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 23 ;
	}
#Total surface UV spectral flux (380-385 nm)
'uvsflxt380385' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 24 ;
	}
#Total surface UV spectral flux (385-390 nm)
'uvsflxt385390' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 25 ;
	}
#Total surface UV spectral flux (390-395 nm)
'uvsflxt390395' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 26 ;
	}
#Total surface UV spectral flux (395-400 nm)
'uvsflxt395400' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 27 ;
	}
#Clear-sky surface UV spectral flux (280-285 nm)
'uvsflxcs280285' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 28 ;
	}
#Clear-sky surface UV spectral flux (285-290 nm)
'uvsflxcs285290' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 29 ;
	}
#Clear-sky surface UV spectral flux (290-295 nm)
'uvsflxcs290295' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 30 ;
	}
#Clear-sky surface UV spectral flux (295-300 nm)
'uvsflxcs295300' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 31 ;
	}
#Clear-sky surface UV spectral flux (300-305 nm)
'uvsflxcs300305' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 32 ;
	}
#Clear-sky surface UV spectral flux (305-310 nm)
'uvsflxcs305310' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 33 ;
	}
#Clear-sky surface UV spectral flux (310-315 nm)
'uvsflxcs310315' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 34 ;
	}
#Clear-sky surface UV spectral flux (315-320 nm)
'uvsflxcs315320' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 35 ;
	}
#Clear-sky surface UV spectral flux (320-325 nm)
'uvsflxcs320325' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 36 ;
	}
#Clear-sky surface UV spectral flux (325-330 nm)
'uvsflxcs325330' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 37 ;
	}
#Clear-sky surface UV spectral flux (330-335 nm)
'uvsflxcs330335' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 38 ;
	}
#Clear-sky surface UV spectral flux (335-340 nm)
'uvsflxcs335340' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 39 ;
	}
#Clear-sky surface UV spectral flux (340-345 nm)
'uvsflxcs340345' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 40 ;
	}
#Clear-sky surface UV spectral flux (345-350 nm)
'uvsflxcs345350' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 41 ;
	}
#Clear-sky surface UV spectral flux (350-355 nm)
'uvsflxcs350355' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 42 ;
	}
#Clear-sky surface UV spectral flux (355-360 nm)
'uvsflxcs355360' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 43 ;
	}
#Clear-sky surface UV spectral flux (360-365 nm)
'uvsflxcs360365' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 44 ;
	}
#Clear-sky surface UV spectral flux (365-370 nm)
'uvsflxcs365370' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 45 ;
	}
#Clear-sky surface UV spectral flux (370-375 nm)
'uvsflxcs370375' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 46 ;
	}
#Clear-sky surface UV spectral flux (375-380 nm)
'uvsflxcs375380' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 47 ;
	}
#Clear-sky surface UV spectral flux (380-385 nm)
'uvsflxcs380385' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 48 ;
	}
#Clear-sky surface UV spectral flux (385-390 nm)
'uvsflxcs385390' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 49 ;
	}
#Clear-sky surface UV spectral flux (390-395 nm)
'uvsflxcs390395' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 50 ;
	}
#Clear-sky surface UV spectral flux (395-400 nm)
'uvsflxcs395400' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 51 ;
	}
#Profile of optical thickness at 340 nm
'aot340' = {
	 table2Version = 214 ;
	 indicatorOfParameter = 52 ;
	}
#Source/gain of sea salt aerosol (0.03 - 0.5 um)
'aersrcsss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 1 ;
	}
#Source/gain of sea salt aerosol (0.5 - 5 um)
'aersrcssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 2 ;
	}
#Source/gain of sea salt aerosol (5 - 20 um)
'aersrcssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 3 ;
	}
#Dry deposition of sea salt aerosol (0.03 - 0.5 um)
'aerddpsss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 4 ;
	}
#Dry deposition of sea salt aerosol (0.5 - 5 um)
'aerddpssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 5 ;
	}
#Dry deposition of sea salt aerosol (5 - 20 um)
'aerddpssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 6 ;
	}
#Sedimentation of sea salt aerosol (0.03 - 0.5 um)
'aersdmsss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 7 ;
	}
#Sedimentation of sea salt aerosol (0.5 - 5 um)
'aersdmssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 8 ;
	}
#Sedimentation of sea salt aerosol (5 - 20 um)
'aersdmssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 9 ;
	}
#Wet deposition of sea salt aerosol (0.03 - 0.5 um) by large-scale precipitation
'aerwdlssss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 10 ;
	}
#Wet deposition of sea salt aerosol (0.5 - 5 um) by large-scale precipitation
'aerwdlsssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 11 ;
	}
#Wet deposition of sea salt aerosol (5 - 20 um) by large-scale precipitation
'aerwdlsssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 12 ;
	}
#Wet deposition of sea salt aerosol (0.03 - 0.5 um) by convective precipitation
'aerwdccsss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 13 ;
	}
#Wet deposition of sea salt aerosol (0.5 - 5 um) by convective precipitation
'aerwdccssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 14 ;
	}
#Wet deposition of sea salt aerosol (5 - 20 um) by convective precipitation
'aerwdccssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 15 ;
	}
#Negative fixer of sea salt aerosol (0.03 - 0.5 um)
'aerngtsss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 16 ;
	}
#Negative fixer of sea salt aerosol (0.5 - 5 um)
'aerngtssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 17 ;
	}
#Negative fixer of sea salt aerosol (5 - 20 um)
'aerngtssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 18 ;
	}
#Vertically integrated mass of sea salt aerosol (0.03 - 0.5 um)
'aermsssss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 19 ;
	}
#Vertically integrated mass of sea salt aerosol (0.5 - 5 um)
'aermssssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 20 ;
	}
#Vertically integrated mass of sea salt aerosol (5 - 20 um)
'aermssssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 21 ;
	}
#Sea salt aerosol (0.03 - 0.5 um) optical depth
'aerodsss' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 22 ;
	}
#Sea salt aerosol (0.5 - 5 um) optical depth
'aerodssm' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 23 ;
	}
#Sea salt aerosol (5 - 20 um) optical depth
'aerodssl' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 24 ;
	}
#Source/gain of dust aerosol (0.03 - 0.55 um)
'aersrcdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 25 ;
	}
#Source/gain of dust aerosol (0.55 - 9 um)
'aersrcdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 26 ;
	}
#Source/gain of dust aerosol (9 - 20 um)
'aersrcdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 27 ;
	}
#Dry deposition of dust aerosol (0.03 - 0.55 um)
'aerddpdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 28 ;
	}
#Dry deposition of dust aerosol (0.55 - 9 um)
'aerddpdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 29 ;
	}
#Dry deposition of dust aerosol (9 - 20 um)
'aerddpdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 30 ;
	}
#Sedimentation of dust aerosol (0.03 - 0.55 um)
'aersdmdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 31 ;
	}
#Sedimentation of dust aerosol (0.55 - 9 um)
'aersdmdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 32 ;
	}
#Sedimentation of dust aerosol (9 - 20 um)
'aersdmdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 33 ;
	}
#Wet deposition of dust aerosol (0.03 - 0.55 um) by large-scale precipitation
'aerwdlsdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 34 ;
	}
#Wet deposition of dust aerosol (0.55 - 9 um) by large-scale precipitation
'aerwdlsdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 35 ;
	}
#Wet deposition of dust aerosol (9 - 20 um) by large-scale precipitation
'aerwdlsdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 36 ;
	}
#Wet deposition of dust aerosol (0.03 - 0.55 um) by convective precipitation
'aerwdccdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 37 ;
	}
#Wet deposition of dust aerosol (0.55 - 9 um) by convective precipitation
'aerwdccdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 38 ;
	}
#Wet deposition of dust aerosol (9 - 20 um) by convective precipitation
'aerwdccdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 39 ;
	}
#Negative fixer of dust aerosol (0.03 - 0.55 um)
'aerngtdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 40 ;
	}
#Negative fixer of dust aerosol (0.55 - 9 um)
'aerngtdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 41 ;
	}
#Negative fixer of dust aerosol (9 - 20 um)
'aerngtdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 42 ;
	}
#Vertically integrated mass of dust aerosol (0.03 - 0.55 um)
'aermssdus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 43 ;
	}
#Vertically integrated mass of dust aerosol (0.55 - 9 um)
'aermssdum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 44 ;
	}
#Vertically integrated mass of dust aerosol (9 - 20 um)
'aermssdul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 45 ;
	}
#Dust aerosol (0.03 - 0.55 um) optical depth
'aeroddus' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 46 ;
	}
#Dust aerosol (0.55 - 9 um) optical depth
'aeroddum' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 47 ;
	}
#Dust aerosol (9 - 20 um) optical depth
'aeroddul' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 48 ;
	}
#Source/gain of hydrophobic organic matter aerosol
'aersrcomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 49 ;
	}
#Source/gain of hydrophilic organic matter aerosol
'aersrcomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 50 ;
	}
#Dry deposition of hydrophobic organic matter aerosol
'aerddpomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 51 ;
	}
#Dry deposition of hydrophilic organic matter aerosol
'aerddpomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 52 ;
	}
#Sedimentation of hydrophobic organic matter aerosol
'aersdmomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 53 ;
	}
#Sedimentation of hydrophilic organic matter aerosol
'aersdmomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 54 ;
	}
#Wet deposition of hydrophobic organic matter aerosol by large-scale precipitation
'aerwdlsomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 55 ;
	}
#Wet deposition of hydrophilic organic matter aerosol by large-scale precipitation
'aerwdlsomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 56 ;
	}
#Wet deposition of hydrophobic organic matter aerosol by convective precipitation
'aerwdccomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 57 ;
	}
#Wet deposition of hydrophilic organic matter aerosol by convective precipitation
'aerwdccomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 58 ;
	}
#Negative fixer of hydrophobic organic matter aerosol
'aerngtomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 59 ;
	}
#Negative fixer of hydrophilic organic matter aerosol
'aerngtomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 60 ;
	}
#Vertically integrated mass of hydrophobic organic matter aerosol
'aermssomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 61 ;
	}
#Vertically integrated mass of hydrophilic organic matter aerosol
'aermssomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 62 ;
	}
#Hydrophobic organic matter aerosol optical depth
'aerodomhphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 63 ;
	}
#Hydrophilic organic matter aerosol optical depth
'aerodomhphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 64 ;
	}
#Source/gain of hydrophobic black carbon aerosol
'aersrcbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 65 ;
	}
#Source/gain of hydrophilic black carbon aerosol
'aersrcbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 66 ;
	}
#Dry deposition of hydrophobic black carbon aerosol
'aerddpbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 67 ;
	}
#Dry deposition of hydrophilic black carbon aerosol
'aerddpbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 68 ;
	}
#Sedimentation of hydrophobic black carbon aerosol
'aersdmbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 69 ;
	}
#Sedimentation of hydrophilic black carbon aerosol
'aersdmbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 70 ;
	}
#Wet deposition of hydrophobic black carbon aerosol by large-scale precipitation
'aerwdlsbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 71 ;
	}
#Wet deposition of hydrophilic black carbon aerosol by large-scale precipitation
'aerwdlsbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 72 ;
	}
#Wet deposition of hydrophobic black carbon aerosol by convective precipitation
'aerwdccbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 73 ;
	}
#Wet deposition of hydrophilic black carbon aerosol by convective precipitation
'aerwdccbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 74 ;
	}
#Negative fixer of hydrophobic black carbon aerosol
'aerngtbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 75 ;
	}
#Negative fixer of hydrophilic black carbon aerosol
'aerngtbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 76 ;
	}
#Vertically integrated mass of hydrophobic black carbon aerosol
'aermssbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 77 ;
	}
#Vertically integrated mass of hydrophilic black carbon aerosol
'aermssbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 78 ;
	}
#Hydrophobic black carbon aerosol optical depth
'aerodbchphob' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 79 ;
	}
#Hydrophilic black carbon aerosol optical depth
'aerodbchphil' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 80 ;
	}
#Source/gain of sulphate aerosol
'aersrcsu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 81 ;
	}
#Dry deposition of sulphate aerosol
'aerddpsu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 82 ;
	}
#Sedimentation of sulphate aerosol
'aersdmsu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 83 ;
	}
#Wet deposition of sulphate aerosol by large-scale precipitation
'aerwdlssu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 84 ;
	}
#Wet deposition of sulphate aerosol by convective precipitation
'aerwdccsu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 85 ;
	}
#Negative fixer of sulphate aerosol
'aerngtsu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 86 ;
	}
#Vertically integrated mass of sulphate aerosol
'aermsssu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 87 ;
	}
#Sulphate aerosol optical depth
'aerodsu' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 88 ;
	}
#Accumulated total aerosol optical depth at 550 nm
'accaod550' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 89 ;
	}
#Effective (snow effect included) UV visible albedo for direct radiation
'aluvpsn' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 90 ;
	}
#10 metre wind speed dust emission potential
'aerdep10si' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 91 ;
	}
#10 metre wind gustiness dust emission potential
'aerdep10fg' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 92 ;
	}
#Total aerosol optical thickness at 532 nm
'aot532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 93 ;
	}
#Natural (sea-salt and dust) aerosol optical thickness at 532 nm
'naot532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 94 ;
	}
#Antropogenic (black carbon, organic matter, sulphate) aerosol optical thickness at 532 nm
'aaot532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 95 ;
	}
#Total absorption aerosol optical depth at 340 nm
'aodabs340' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 96 ;
	}
#Total absorption aerosol optical depth at 355 nm
'aodabs355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 97 ;
	}
#Total absorption aerosol optical depth at 380 nm
'aodabs380' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 98 ;
	}
#Total absorption aerosol optical depth at 400 nm
'aodabs400' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 99 ;
	}
#Total absorption aerosol optical depth at 440 nm
'aodabs440' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 100 ;
	}
#Total absorption aerosol optical depth at 469 nm
'aodabs469' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 101 ;
	}
#Total absorption aerosol optical depth at 500 nm
'aodabs500' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 102 ;
	}
#Total absorption aerosol optical depth at 532 nm
'aodabs532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 103 ;
	}
#Total absorption aerosol optical depth at 550 nm
'aodabs550' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 104 ;
	}
#Total absorption aerosol optical depth at 645 nm
'aodabs645' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 105 ;
	}
#Total absorption aerosol optical depth at 670 nm
'aodabs670' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 106 ;
	}
#Total absorption aerosol optical depth at 800 nm
'aodabs800' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 107 ;
	}
#Total absorption aerosol optical depth at 858 nm
'aodabs858' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 108 ;
	}
#Total absorption aerosol optical depth at 865 nm
'aodabs865' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 109 ;
	}
#Total absorption aerosol optical depth at 1020 nm
'aodabs1020' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 110 ;
	}
#Total absorption aerosol optical depth at 1064 nm
'aodabs1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 111 ;
	}
#Total absorption aerosol optical depth at 1240 nm
'aodabs1240' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 112 ;
	}
#Total absorption aerosol optical depth at 1640 nm
'aodabs1640' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 113 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 340 nm
'aodfm340' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 114 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 355 nm
'aodfm355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 115 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 380 nm
'aodfm380' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 116 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 400 nm
'aodfm400' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 117 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 440 nm
'aodfm440' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 118 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 469 nm
'aodfm469' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 119 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 500 nm
'aodfm500' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 120 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 532 nm
'aodfm532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 121 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 550 nm
'aodfm550' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 122 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 645 nm
'aodfm645' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 123 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 670 nm
'aodfm670' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 124 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 800 nm
'aodfm800' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 125 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 858 nm
'aodfm858' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 126 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 865 nm
'aodfm865' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 127 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 1020 nm
'aodfm1020' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 128 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 1064 nm
'aodfm1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 129 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 1240 nm
'aodfm1240' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 130 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 1640 nm
'aodfm1640' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 131 ;
	}
#Single scattering albedo at 340 nm
'ssa340' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 132 ;
	}
#Single scattering albedo at 355 nm
'ssa355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 133 ;
	}
#Single scattering albedo at 380 nm
'ssa380' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 134 ;
	}
#Single scattering albedo at 400 nm
'ssa400' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 135 ;
	}
#Single scattering albedo at 440 nm
'ssa440' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 136 ;
	}
#Single scattering albedo at 469 nm
'ssa469' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 137 ;
	}
#Single scattering albedo at 500 nm
'ssa500' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 138 ;
	}
#Single scattering albedo at 532 nm
'ssa532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 139 ;
	}
#Single scattering albedo at 550 nm
'ssa550' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 140 ;
	}
#Single scattering albedo at 645 nm
'ssa645' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 141 ;
	}
#Single scattering albedo at 670 nm
'ssa670' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 142 ;
	}
#Single scattering albedo at 800 nm
'ssa800' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 143 ;
	}
#Single scattering albedo at 858 nm
'ssa858' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 144 ;
	}
#Single scattering albedo at 865 nm
'ssa865' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 145 ;
	}
#Single scattering albedo at 1020 nm
'ssa1020' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 146 ;
	}
#Single scattering albedo at 1064 nm
'ssa1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 147 ;
	}
#Single scattering albedo at 1240 nm
'ssa1240' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 148 ;
	}
#Single scattering albedo at 1640 nm
'ssa1640' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 149 ;
	}
#Asymmetry factor at 340 nm
'asymmetry340' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 150 ;
	}
#Asymmetry factor at 355 nm
'asymmetry355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 151 ;
	}
#Asymmetry factor at 380 nm
'asymmetry380' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 152 ;
	}
#Asymmetry factor at 400 nm
'asymmetry400' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 153 ;
	}
#Asymmetry factor at 440 nm
'asymmetry440' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 154 ;
	}
#Asymmetry factor at 469 nm
'asymmetry469' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 155 ;
	}
#Asymmetry factor at 500 nm
'asymmetry500' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 156 ;
	}
#Asymmetry factor at 532 nm
'asymmetry532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 157 ;
	}
#Asymmetry factor at 550 nm
'asymmetry550' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 158 ;
	}
#Asymmetry factor at 645 nm
'asymmetry645' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 159 ;
	}
#Asymmetry factor at 670 nm
'asymmetry670' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 160 ;
	}
#Asymmetry factor at 800 nm
'asymmetry800' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 161 ;
	}
#Asymmetry factor at 858 nm
'asymmetry858' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 162 ;
	}
#Asymmetry factor at 865 nm
'asymmetry865' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 163 ;
	}
#Asymmetry factor at 1020 nm
'asymmetry1020' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 164 ;
	}
#Asymmetry factor at 1064 nm
'asymmetry1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 165 ;
	}
#Asymmetry factor at 1240 nm
'asymmetry1240' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 166 ;
	}
#Asymmetry factor at 1640 nm
'asymmetry1640' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 167 ;
	}
#Source/gain of sulphur dioxide
'aersrcso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 168 ;
	}
#Dry deposition of sulphur dioxide
'aerddpso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 169 ;
	}
#Sedimentation of sulphur dioxide
'aersdmso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 170 ;
	}
#Wet deposition of sulphur dioxide by large-scale precipitation
'aerwdlsso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 171 ;
	}
#Wet deposition of sulphur dioxide by convective precipitation
'aerwdccso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 172 ;
	}
#Negative fixer of sulphur dioxide
'aerngtso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 173 ;
	}
#Vertically integrated mass of sulphur dioxide
'aermssso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 174 ;
	}
#Sulphur dioxide optical depth
'aerodso2' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 175 ;
	}
#Total absorption aerosol optical depth at 2130 nm
'aodabs2130' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 176 ;
	}
#Total fine mode (r < 0.5 um) aerosol optical depth at 2130 nm
'aodfm2130' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 177 ;
	}
#Single scattering albedo at 2130 nm
'ssa2130' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 178 ;
	}
#Asymmetry factor at 2130 nm
'asymmetry2130' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 179 ;
	}
#Aerosol extinction coefficient at 355 nm
'aerext355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 180 ;
	}
#Aerosol extinction coefficient at 532 nm
'aerext532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 181 ;
	}
#Aerosol extinction coefficient at 1064 nm
'aerext1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 182 ;
	}
#Aerosol backscatter coefficient at 355 nm (from top of atmosphere)
'aerbackscattoa355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 183 ;
	}
#Aerosol backscatter coefficient at 532 nm (from top of atmosphere)
'aerbackscattoa532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 184 ;
	}
#Aerosol backscatter coefficient at 1064 nm (from top of atmosphere)
'aerbackscattoa1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 185 ;
	}
#Aerosol backscatter coefficient at 355 nm (from ground)
'aerbackscatgnd355' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 186 ;
	}
#Aerosol backscatter coefficient at 532 nm (from ground)
'aerbackscatgnd532' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 187 ;
	}
#Aerosol backscatter coefficient at 1064 nm (from ground)
'aerbackscatgnd1064' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 188 ;
	}
#Source/gain of fine-mode nitrate aerosol
'aersrcnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 189 ;
	}
#Source/gain of coarse-mode nitrate aerosol
'aersrcnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 190 ;
	}
#Dry deposition of fine-mode nitrate aerosol
'aerddpnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 191 ;
	}
#Dry deposition of coarse-mode nitrate aerosol
'aerddpnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 192 ;
	}
#Sedimentation of fine-mode nitrate aerosol
'aersdmnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 193 ;
	}
#Sedimentation of coarse-mode nitrate aerosol
'aersdmnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 194 ;
	}
#Wet deposition of fine-mode nitrate aerosol by large-scale precipitation
'aerwdlnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 195 ;
	}
#Wet deposition of coarse-mode nitrate aerosol by large-scale precipitation
'aerwdlnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 196 ;
	}
#Wet deposition of fine-mode nitrate aerosol by convective precipitation
'aerwdcnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 197 ;
	}
#Wet deposition of coarse-mode nitrate aerosol by convective precipitation
'aerwdcnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 198 ;
	}
#Negative fixer of fine-mode nitrate aerosol
'aerngtnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 199 ;
	}
#Negative fixer of coarse-mode nitrate aerosol
'aerngtnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 200 ;
	}
#Vertically integrated mass of fine-mode nitrate aerosol
'aermssnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 201 ;
	}
#Vertically integrated mass of coarse-mode nitrate aerosol
'aermssnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 202 ;
	}
#Fine-mode nitrate aerosol optical depth at 550 nm
'aerodnif' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 203 ;
	}
#Coarse-mode nitrate aerosol optical depth at 550 nm
'aerodnic' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 204 ;
	}
#Source/gain of ammonium aerosol
'aersrcam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 205 ;
	}
#Dry deposition of ammonium aerosol
'aerddpam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 206 ;
	}
#Sedimentation of ammonium aerosol
'aersdmam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 207 ;
	}
#Wet deposition of ammonium aerosol by large-scale precipitation
'aerwdlam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 208 ;
	}
#Wet deposition of ammonium aerosol by convective precipitation
'aerwdcam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 209 ;
	}
#Negative fixer of ammonium aerosol
'aerngtam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 210 ;
	}
#Vertically integrated mass of ammonium aerosol
'aermssam' = {
	 table2Version = 215 ;
	 indicatorOfParameter = 211 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 1 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 2 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 3 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 4 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 5 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 6 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 7 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 8 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 9 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 10 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 11 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 12 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 13 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 14 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 15 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 16 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 17 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 18 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 19 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 20 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 21 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 22 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 23 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 24 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 25 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 26 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 27 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 28 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 29 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 30 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 31 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 32 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 33 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 34 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 35 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 36 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 37 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 38 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 39 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 40 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 41 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 42 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 43 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 44 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 45 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 46 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 47 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 48 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 49 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 50 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 51 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 52 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 53 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 54 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 55 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 56 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 57 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 58 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 59 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 60 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 61 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 62 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 63 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 64 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 65 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 66 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 67 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 68 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 69 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 70 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 71 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 72 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 73 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 74 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 75 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 76 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 77 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 78 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 79 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 80 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 81 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 82 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 83 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 84 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 85 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 86 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 87 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 88 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 89 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 90 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 91 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 92 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 93 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 94 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 95 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 96 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 97 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 98 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 99 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 100 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 101 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 102 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 103 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 104 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 105 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 106 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 107 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 108 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 109 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 110 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 111 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 112 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 113 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 114 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 115 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 116 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 117 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 118 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 119 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 120 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 121 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 122 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 123 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 124 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 125 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 126 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 127 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 128 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 129 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 130 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 131 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 132 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 133 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 134 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 135 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 136 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 137 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 138 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 139 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 140 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 141 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 142 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 143 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 144 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 145 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 146 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 147 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 148 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 149 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 150 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 151 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 152 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 153 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 154 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 155 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 156 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 157 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 158 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 159 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 160 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 161 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 162 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 163 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 164 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 165 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 166 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 167 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 168 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 169 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 170 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 171 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 172 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 173 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 174 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 175 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 176 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 177 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 178 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 179 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 180 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 181 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 182 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 183 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 184 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 185 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 186 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 187 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 188 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 189 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 190 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 191 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 192 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 193 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 194 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 195 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 196 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 197 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 198 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 199 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 200 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 201 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 202 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 203 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 204 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 205 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 206 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 207 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 208 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 209 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 210 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 211 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 212 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 213 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 214 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 215 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 216 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 217 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 218 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 219 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 220 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 221 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 222 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 223 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 224 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 225 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 226 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 227 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 228 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 229 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 230 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 231 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 232 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 233 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 234 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 235 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 236 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 237 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 238 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 239 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 240 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 241 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 242 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 243 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 244 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 245 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 246 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 247 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 248 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 249 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 250 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 251 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 252 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 253 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 254 ;
	}
#Experimental product
'~' = {
	 table2Version = 216 ;
	 indicatorOfParameter = 255 ;
	}
#Hydrogen peroxide
'h2o2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 3 ;
	}
#Methane (chemistry)
'ch4_c' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 4 ;
	}
#Nitric acid
'hno3' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 6 ;
	}
#Methyl peroxide
'ch3ooh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 7 ;
	}
#Paraffins
'par' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 9 ;
	}
#Ethene
'c2h4' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 10 ;
	}
#Olefins
'ole' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 11 ;
	}
#Aldehydes
'ald2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 12 ;
	}
#Peroxyacetyl nitrate
'pan' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 13 ;
	}
#Peroxides
'rooh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 14 ;
	}
#Organic nitrates
'onit' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 15 ;
	}
#Isoprene
'c5h8' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 16 ;
	}
#Dimethyl sulfide
'dms' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 18 ;
	}
#Ammonia
'nh3' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 19 ;
	}
#Sulfate
'so4' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 20 ;
	}
#Ammonium
'nh4' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 21 ;
	}
#Methane sulfonic acid
'msa' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 22 ;
	}
#Methyl glyoxal
'ch3cocho' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 23 ;
	}
#Stratospheric ozone
'o3s' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 24 ;
	}
#Lead
'pb' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 26 ;
	}
#Nitrogen monoxide
'no' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 27 ;
	}
#Hydroperoxy radical
'ho2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 28 ;
	}
#Methylperoxy radical
'ch3o2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 29 ;
	}
#Hydroxyl radical
'oh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 30 ;
	}
#Nitrate radical
'no3' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 32 ;
	}
#Dinitrogen pentoxide
'n2o5' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 33 ;
	}
#Pernitric acid
'ho2no2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 34 ;
	}
#Peroxy acetyl radical
'c2o3' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 35 ;
	}
#Organic ethers
'ror' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 36 ;
	}
#PAR budget corrector
'rxpar' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 37 ;
	}
#NO to NO2 operator
'xo2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 38 ;
	}
#NO to alkyl nitrate operator
'xo2n' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 39 ;
	}
#Amine
'nh2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 40 ;
	}
#Polar stratospheric cloud
'psc' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 41 ;
	}
#Methanol
'ch3oh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 42 ;
	}
#Formic acid
'hcooh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 43 ;
	}
#Methacrylic acid
'mcooh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 44 ;
	}
#Ethane
'c2h6' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 45 ;
	}
#Ethanol
'c2h5oh' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 46 ;
	}
#Propane
'c3h8' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 47 ;
	}
#Propene
'c3h6' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 48 ;
	}
#Terpenes
'c10h16' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 49 ;
	}
#Methacrolein MVK
'ispd' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 50 ;
	}
#Nitrate
'no3_a' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 51 ;
	}
#Acetone
'ch3coch3' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 52 ;
	}
#Acetone product
'aco2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 53 ;
	}
#IC3H7O2
'ic3h7o2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 54 ;
	}
#HYPROPO2
'hypropo2' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 55 ;
	}
#Nitrogen oxides Transp
'noxa' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 56 ;
	}
#Total column hydrogen peroxide
'tc_h2o2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 3 ;
	}
#Total column methane
'tc_ch4' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 4 ;
	}
#Total column nitric acid
'tc_hno3' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 6 ;
	}
#Total column methyl peroxide
'tc_ch3ooh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 7 ;
	}
#Total column paraffins
'tc_par' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 9 ;
	}
#Total column ethene
'tc_c2h4' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 10 ;
	}
#Total column olefins
'tc_ole' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 11 ;
	}
#Total column aldehydes
'tc_ald2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 12 ;
	}
#Total column  peroxyacetyl nitrate
'tc_pan' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 13 ;
	}
#Total column peroxides
'tc_rooh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 14 ;
	}
#Total column organic nitrates
'tc_onit' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 15 ;
	}
#Total column  isoprene
'tc_c5h8' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 16 ;
	}
#Total column dimethyl sulfide
'tc_dms' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 18 ;
	}
#Total column ammonia
'tc_nh3' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 19 ;
	}
#Total column  sulfate
'tc_so4' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 20 ;
	}
#Total column ammonium
'tc_nh4' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 21 ;
	}
#Total column  methane sulfonic acid
'tc_msa' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 22 ;
	}
#Total column methyl glyoxal
'tc_ch3cocho' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 23 ;
	}
#Total column stratospheric ozone
'tc_o3s' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 24 ;
	}
#Total column  lead
'tc_pb' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 26 ;
	}
#Total column nitrogen monoxide
'tc_no' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 27 ;
	}
#Total column hydroperoxy radical
'tc_ho2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 28 ;
	}
#Total column methylperoxy radical
'tc_ch3o2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 29 ;
	}
#Total column hydroxyl radical
'tc_oh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 30 ;
	}
#Total column nitrate radical
'tc_no3' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 32 ;
	}
#Total column dinitrogen pentoxide
'tc_n2o5' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 33 ;
	}
#Total column pernitric acid
'tc_ho2no2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 34 ;
	}
#Total column peroxy acetyl radical
'tc_c2o3' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 35 ;
	}
#Total column  organic ethers
'tc_ror' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 36 ;
	}
#Total column PAR budget corrector
'tc_rxpar' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 37 ;
	}
#Total column NO to NO2 operator
'tc_xo2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 38 ;
	}
#Total column NO to alkyl nitrate operator
'tc_xo2n' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 39 ;
	}
#Total column amine
'tc_nh2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 40 ;
	}
#Total column  polar stratospheric cloud
'tc_psc' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 41 ;
	}
#Total column methanol
'tc_ch3oh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 42 ;
	}
#Total column formic acid
'tc_hcooh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 43 ;
	}
#Total column  methacrylic acid
'tc_mcooh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 44 ;
	}
#Total column  ethane
'tc_c2h6' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 45 ;
	}
#Total column ethanol
'tc_c2h5oh' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 46 ;
	}
#Total column propane
'tc_c3h8' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 47 ;
	}
#Total column propene
'tc_c3h6' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 48 ;
	}
#Total column terpenes
'tc_c10h16' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 49 ;
	}
#Total column methacrolein MVK
'tc_ispd' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 50 ;
	}
#Total column nitrate
'tc_no3_a' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 51 ;
	}
#Total column acetone
'tc_ch3coch3' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 52 ;
	}
#Total column acetone product
'tc_aco2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 53 ;
	}
#Total column IC3H7O2
'tc_ic3h7o2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 54 ;
	}
#Total column HYPROPO2
'tc_hypropo2' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 55 ;
	}
#Total column nitrogen oxides Transp
'tc_noxa' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 56 ;
	}
#Ozone emissions
'e_go3' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 1 ;
	}
#Nitrogen oxides emissions
'e_nox' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 2 ;
	}
#Hydrogen peroxide emissions
'e_h2o2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 3 ;
	}
#Methane emissions
'e_ch4' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 4 ;
	}
#Carbon monoxide emissions
'e_co' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 5 ;
	}
#Nitric acid emissions
'e_hno3' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 6 ;
	}
#Methyl peroxide emissions
'e_ch3ooh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 7 ;
	}
#Formaldehyde emissions
'e_hcho' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 8 ;
	}
#Paraffins emissions
'e_par' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 9 ;
	}
#Ethene emissions
'e_c2h4' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 10 ;
	}
#Olefins emissions
'e_ole' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 11 ;
	}
#Aldehydes emissions
'e_ald2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 12 ;
	}
#Peroxyacetyl nitrate emissions
'e_pan' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 13 ;
	}
#Peroxides emissions
'e_rooh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 14 ;
	}
#Organic nitrates emissions
'e_onit' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 15 ;
	}
#Isoprene emissions
'e_c5h8' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 16 ;
	}
#Sulfur dioxide emissions
'e_so2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 17 ;
	}
#Dimethyl sulfide emissions
'e_dms' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 18 ;
	}
#Ammonia emissions
'e_nh3' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 19 ;
	}
#Sulfate emissions
'e_so4' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 20 ;
	}
#Ammonium emissions
'e_nh4' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 21 ;
	}
#Methane sulfonic acid emissions
'e_msa' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 22 ;
	}
#Methyl glyoxal emissions
'e_ch3cocho' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 23 ;
	}
#Stratospheric ozone emissions
'e_o3s' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 24 ;
	}
#Radon emissions
'e_ra' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 25 ;
	}
#Lead emissions
'e_pb' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 26 ;
	}
#Nitrogen monoxide emissions
'e_no' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 27 ;
	}
#Hydroperoxy radical emissions
'e_ho2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 28 ;
	}
#Methylperoxy radical emissions
'e_ch3o2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 29 ;
	}
#Hydroxyl radical emissions
'e_oh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 30 ;
	}
#Nitrogen dioxide emissions
'e_no2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 31 ;
	}
#Nitrate radical emissions
'e_no3' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 32 ;
	}
#Dinitrogen pentoxide emissions
'e_n2o5' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 33 ;
	}
#Pernitric acid emissions
'e_ho2no2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 34 ;
	}
#Peroxy acetyl radical emissions
'e_c2o3' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 35 ;
	}
#Organic ethers emissions
'e_ror' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 36 ;
	}
#PAR budget corrector emissions
'e_rxpar' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 37 ;
	}
#NO to NO2 operator emissions
'e_xo2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 38 ;
	}
#NO to alkyl nitrate operator emissions
'e_xo2n' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 39 ;
	}
#Amine emissions
'e_nh2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 40 ;
	}
#Polar stratospheric cloud emissions
'e_psc' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 41 ;
	}
#Methanol emissions
'e_ch3oh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 42 ;
	}
#Formic acid emissions
'e_hcooh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 43 ;
	}
#Methacrylic acid emissions
'e_mcooh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 44 ;
	}
#Ethane emissions
'e_c2h6' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 45 ;
	}
#Ethanol emissions
'e_c2h5oh' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 46 ;
	}
#Propane emissions
'e_c3h8' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 47 ;
	}
#Propene emissions
'e_c3h6' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 48 ;
	}
#Terpenes emissions
'e_c10h16' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 49 ;
	}
#Methacrolein MVK  emissions
'e_ispd' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 50 ;
	}
#Nitrate emissions
'e_no3_a' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 51 ;
	}
#Acetone emissions
'e_ch3coch3' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 52 ;
	}
#Acetone product emissions
'e_aco2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 53 ;
	}
#IC3H7O2 emissions
'e_ic3h7o2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 54 ;
	}
#HYPROPO2 emissions
'e_hypropo2' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 55 ;
	}
#Nitrogen oxides Transp emissions
'e_noxa' = {
	 table2Version = 219 ;
	 indicatorOfParameter = 56 ;
	}
#Ozone deposition velocity
'dv_go3' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 1 ;
	}
#Nitrogen oxides deposition velocity
'dv_nox' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 2 ;
	}
#Hydrogen peroxide deposition velocity
'dv_h2o2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 3 ;
	}
#Methane deposition velocity
'dv_ch4' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 4 ;
	}
#Carbon monoxide deposition velocity
'dv_co' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 5 ;
	}
#Nitric acid deposition velocity
'dv_hno3' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 6 ;
	}
#Methyl peroxide deposition velocity
'dv_ch3ooh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 7 ;
	}
#Formaldehyde deposition velocity
'dv_hcho' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 8 ;
	}
#Paraffins deposition velocity
'dv_par' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 9 ;
	}
#Ethene deposition velocity
'dv_c2h4' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 10 ;
	}
#Olefins deposition velocity
'dv_ole' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 11 ;
	}
#Aldehydes deposition velocity
'dv_ald2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 12 ;
	}
#Peroxyacetyl nitrate deposition velocity
'dv_pan' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 13 ;
	}
#Peroxides deposition velocity
'dv_rooh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 14 ;
	}
#Organic nitrates deposition velocity
'dv_onit' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 15 ;
	}
#Isoprene deposition velocity
'dv_c5h8' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 16 ;
	}
#Sulfur dioxide deposition velocity
'dv_so2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 17 ;
	}
#Dimethyl sulfide deposition velocity
'dv_dms' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 18 ;
	}
#Ammonia deposition velocity
'dv_nh3' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 19 ;
	}
#Sulfate deposition velocity
'dv_so4' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 20 ;
	}
#Ammonium deposition velocity
'dv_nh4' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 21 ;
	}
#Methane sulfonic acid deposition velocity
'dv_msa' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 22 ;
	}
#Methyl glyoxal deposition velocity
'dv_ch3cocho' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 23 ;
	}
#Stratospheric ozone deposition velocity
'dv_o3s' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 24 ;
	}
#Radon deposition velocity
'dv_ra' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 25 ;
	}
#Lead deposition velocity
'dv_pb' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 26 ;
	}
#Nitrogen monoxide deposition velocity
'dv_no' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 27 ;
	}
#Hydroperoxy radical deposition velocity
'dv_ho2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 28 ;
	}
#Methylperoxy radical deposition velocity
'dv_ch3o2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 29 ;
	}
#Hydroxyl radical deposition velocity
'dv_oh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 30 ;
	}
#Nitrogen dioxide deposition velocity
'dv_no2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 31 ;
	}
#Nitrate radical deposition velocity
'dv_no3' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 32 ;
	}
#Dinitrogen pentoxide deposition velocity
'dv_n2o5' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 33 ;
	}
#Pernitric acid deposition velocity
'dv_ho2no2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 34 ;
	}
#Peroxy acetyl radical deposition velocity
'dv_c2o3' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 35 ;
	}
#Organic ethers deposition velocity
'dv_ror' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 36 ;
	}
#PAR budget corrector deposition velocity
'dv_rxpar' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 37 ;
	}
#NO to NO2 operator deposition velocity
'dv_xo2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 38 ;
	}
#NO to alkyl nitrate operator deposition velocity
'dv_xo2n' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 39 ;
	}
#Amine deposition velocity
'dv_nh2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 40 ;
	}
#Polar stratospheric cloud deposition velocity
'dv_psc' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 41 ;
	}
#Methanol deposition velocity
'dv_ch3oh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 42 ;
	}
#Formic acid deposition velocity
'dv_hcooh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 43 ;
	}
#Methacrylic acid deposition velocity
'dv_mcooh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 44 ;
	}
#Ethane deposition velocity
'dv_c2h6' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 45 ;
	}
#Ethanol deposition velocity
'dv_c2h5oh' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 46 ;
	}
#Propane deposition velocity
'dv_c3h8' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 47 ;
	}
#Propene deposition velocity
'dv_c3h6' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 48 ;
	}
#Terpenes deposition velocity
'dv_c10h16' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 49 ;
	}
#Methacrolein MVK  deposition velocity
'dv_ispd' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 50 ;
	}
#Nitrate deposition velocity
'dv_no3_a' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 51 ;
	}
#Acetone deposition velocity
'dv_ch3coch3' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 52 ;
	}
#Acetone product deposition velocity
'dv_aco2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 53 ;
	}
#IC3H7O2 deposition velocity
'dv_ic3h7o2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 54 ;
	}
#HYPROPO2 deposition velocity
'dv_hypropo2' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 55 ;
	}
#Nitrogen oxides Transp deposition velocity
'dv_noxa' = {
	 table2Version = 221 ;
	 indicatorOfParameter = 56 ;
	}
#-10 degrees C isothermal level (atm)
'degm10l' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 20 ;
	}
#Total sky direct solar radiation at surface
'fdir' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 21 ;
	}
#Clear-sky direct solar radiation at surface
'cdir' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 22 ;
	}
#Cloud base height
'cbh' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 23 ;
	}
#0 degrees C isothermal level (atm)
'deg0l' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 24 ;
	}
#Horizontal visibility
'hvis' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 25 ;
	}
#Maximum temperature at 2 metres in the last 3 hours
'mx2t3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 26 ;
	}
#Minimum temperature at 2 metres in the last 3 hours
'mn2t3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 27 ;
	}
#10 metre wind gust in the last 3 hours
'10fg3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 28 ;
	}
#Instantaneous 10 metre wind gust
'i10fg' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 29 ;
	}
#2 metre relative humidity with respect to water
'2rhw' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 37 ;
	}
#Soil wetness index in layer 1
'swi1' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 40 ;
	}
#Soil wetness index in layer 2
'swi2' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 41 ;
	}
#Soil wetness index in layer 3
'swi3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 42 ;
	}
#Soil wetness index in layer 4
'swi4' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 43 ;
	}
#Convective available potential energy shear
'capes' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 44 ;
	}
#Height of convective cloud top
'hcct' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 46 ;
	}
#Height of zero-degree wet-bulb temperature
'hwbt0' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 47 ;
	}
#Height of one-degree wet-bulb temperature
'hwbt1' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 48 ;
	}
#Instantaneous total lightning flash density
'litoti' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 50 ;
	}
#Averaged total lightning flash density in the last hour
'litota1' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 51 ;
	}
#Instantaneous cloud-to-ground lightning flash density
'licgi' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 52 ;
	}
#Averaged cloud-to-ground lightning flash density in the last hour
'licga1' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 53 ;
	}
#SMOS observed soil moisture retrieved using neural network
'smnnob' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 70 ;
	}
#SMOS observed soil moisture uncertainty retrieved using neural network
'smnner' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 71 ;
	}
#SMOS radio frequency interference probability
'smnnrfi' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 72 ;
	}
#SMOS number of observations per grid point
'smnnnb' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 73 ;
	}
#SMOS observation time for the satellite soil moisture data
'smnntim' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 74 ;
	}
#GPP coefficient from Biogenic Flux Adjustment System
'gppbfas' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 78 ;
	}
#Rec coefficient from Biogenic Flux Adjustment System
'recbfas' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 79 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'aco2nee' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 80 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'aco2gpp' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 81 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'aco2rec' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 82 ;
	}
#Flux of Carbon Dioxide Net Ecosystem Exchange
'fco2nee' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 83 ;
	}
#Flux of Carbon Dioxide Gross Primary Production
'fco2gpp' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 84 ;
	}
#Flux of Carbon Dioxide Ecosystem Respiration
'fco2rec' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 85 ;
	}
#Total column supercooled liquid water
'tcslw' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 88 ;
	}
#Total column rain water
'tcrw' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 89 ;
	}
#Total column snow water
'tcsw' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 90 ;
	}
#Canopy cover fraction
'ccf' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 91 ;
	}
#Soil texture fraction
'stf' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 92 ;
	}
#Volumetric soil moisture
'swv' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 93 ;
	}
#Ice temperature
'ist' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 94 ;
	}
#Surface solar radiation downward clear-sky
'ssrdc' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 129 ;
	}
#Surface thermal radiation downward clear-sky
'strdc' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 130 ;
	}
#Accumulated freezing rain
'fzra' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 216 ;
	}
#Instantaneous large-scale surface precipitation fraction
'ilspf' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 217 ;
	}
#Convective rain rate
'crr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 218 ;
	}
#Large scale rain rate
'lsrr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 219 ;
	}
#Convective snowfall rate water equivalent
'csfr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 220 ;
	}
#Large scale snowfall rate water equivalent
'lssfr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 221 ;
	}
#Maximum total precipitation rate in the last 3 hours
'mxtpr3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 222 ;
	}
#Minimum total precipitation rate in the last 3 hours
'mntpr3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 223 ;
	}
#Maximum total precipitation rate in the last 6 hours
'mxtpr6' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 224 ;
	}
#Minimum total precipitation rate in the last 6 hours
'mntpr6' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 225 ;
	}
#Maximum total precipitation rate since previous post-processing
'mxtpr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 226 ;
	}
#Minimum total precipitation rate since previous post-processing
'mntpr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 227 ;
	}
#SMOS first Brightness Temperature Bias Correction parameter
'smos_tb_cdfa' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 229 ;
	}
#SMOS second Brightness Temperature Bias Correction parameter
'smos_tb_cdfb' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 230 ;
	}
#200 metre U wind component
'200u' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 239 ;
	}
#200 metre V wind component
'200v' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 240 ;
	}
#200 metre wind speed
'200si' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 241 ;
	}
#Surface solar radiation diffuse total sky
'fdif' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 242 ;
	}
#Surface solar radiation diffuse clear-sky
'cdif' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 243 ;
	}
#Surface albedo of direct radiation
'aldr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 244 ;
	}
#Surface albedo of diffuse radiation
'aldf' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 245 ;
	}
#100 metre wind speed
'100si' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 249 ;
	}
#Irrigation fraction
'irrfr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 250 ;
	}
#Potential evaporation
'pev' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 251 ;
	}
#Irrigation
'irr' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 252 ;
	}
#Surface runoff (variable resolution)
'srovar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 8 ;
	}
#Sub-surface runoff (variable resolution)
'ssrovar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 9 ;
	}
#Clear sky surface photosynthetically active radiation (variable resolution)
'parcsvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 20 ;
	}
#Total sky direct solar radiation at surface (variable resolution)
'fdirvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 21 ;
	}
#Clear-sky direct solar radiation at surface (variable resolution)
'cdirvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 22 ;
	}
#Direct solar radiation (variable resolution)
'dsrpvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 47 ;
	}
#Large-scale precipitation fraction (variable resolution)
'lspfvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 50 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange (variable resolution)
'aco2neevar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 80 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production (variable resolution)
'aco2gppvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 81 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration (variable resolution)
'aco2recvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 82 ;
	}
#Surface solar radiation downward clear-sky (variable resolution)
'ssrdcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 129 ;
	}
#Surface thermal radiation downward clear-sky (variable resolution)
'strdcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 130 ;
	}
#Albedo (variable resolution)
'alvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 174 ;
	}
#Vertically integrated moisture divergence (variable resolution)
'vimdvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 213 ;
	}
#Accumulated freezing rain (variable resolution)
'fzravar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 216 ;
	}
#Total precipitation (variable resolution)
'tpvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 228 ;
	}
#Convective snowfall (variable resolution)
'csfvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 239 ;
	}
#Large-scale snowfall (variable resolution)
'lsfvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 240 ;
	}
#Potential evaporation (variable resolution)
'pevvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 251 ;
	}
#Mean surface runoff rate
'msror' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 20 ;
	}
#Mean sub-surface runoff rate
'mssror' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 21 ;
	}
#Mean surface photosynthetically active radiation flux, clear sky
'msparfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 22 ;
	}
#Mean snow evaporation rate
'mser' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 23 ;
	}
#Mean snowmelt rate
'msmr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 24 ;
	}
#Mean magnitude of turbulent surface stress
'mmtss' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 25 ;
	}
#Mean large-scale precipitation fraction
'mlspf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 26 ;
	}
#Mean surface downward UV radiation flux
'msdwuvrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 27 ;
	}
#Mean surface photosynthetically active radiation flux
'msparf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 28 ;
	}
#Mean large-scale precipitation rate
'mlspr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 29 ;
	}
#Mean convective precipitation rate
'mcpr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 30 ;
	}
#Mean snowfall rate
'msr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 31 ;
	}
#Mean boundary layer dissipation
'mbld' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 32 ;
	}
#Mean surface sensible heat flux
'msshf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 33 ;
	}
#Mean surface latent heat flux
'mslhf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 34 ;
	}
#Mean surface downward short-wave radiation flux
'msdwswrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 35 ;
	}
#Mean surface downward long-wave radiation flux
'msdwlwrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 36 ;
	}
#Mean surface net short-wave radiation flux
'msnswrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 37 ;
	}
#Mean surface net long-wave radiation flux
'msnlwrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 38 ;
	}
#Mean top net short-wave radiation flux
'mtnswrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 39 ;
	}
#Mean top net long-wave radiation flux
'mtnlwrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 40 ;
	}
#Mean eastward turbulent surface stress
'metss' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 41 ;
	}
#Mean northward turbulent surface stress
'mntss' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 42 ;
	}
#Mean evaporation rate
'mer' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 43 ;
	}
#Sunshine duration fraction
'sdf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 44 ;
	}
#Mean eastward gravity wave surface stress
'megwss' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 45 ;
	}
#Mean northward gravity wave surface stress
'mngwss' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 46 ;
	}
#Mean gravity wave dissipation
'mgwd' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 47 ;
	}
#Mean runoff rate
'mror' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 48 ;
	}
#Mean top net short-wave radiation flux, clear sky
'mtnswrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 49 ;
	}
#Mean top net long-wave radiation flux, clear sky
'mtnlwrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 50 ;
	}
#Mean surface net short-wave radiation flux, clear sky
'msnswrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 51 ;
	}
#Mean surface net long-wave radiation flux, clear sky
'msnlwrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 52 ;
	}
#Mean top downward short-wave radiation flux
'mtdwswrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 53 ;
	}
#Mean vertically integrated moisture divergence
'mvimd' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 54 ;
	}
#Mean total precipitation rate
'mtpr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 55 ;
	}
#Mean convective snowfall rate
'mcsr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 56 ;
	}
#Mean large-scale snowfall rate
'mlssr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 57 ;
	}
#Mean surface direct short-wave radiation flux
'msdrswrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 58 ;
	}
#Mean surface direct short-wave radiation flux, clear sky
'msdrswrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 59 ;
	}
#Mean surface diffuse short-wave radiation flux
'msdfswrf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 60 ;
	}
#Mean surface diffuse short-wave radiation flux, clear sky
'msdfswrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 61 ;
	}
#Mean carbon dioxide net ecosystem exchange flux
'mcdneef' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 62 ;
	}
#Mean carbon dioxide gross primary production flux
'mcdgppf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 63 ;
	}
#Mean carbon dioxide ecosystem respiration flux
'mcderf' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 64 ;
	}
#Mean rain rate
'mrr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 65 ;
	}
#Mean convective rain rate
'mcrr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 66 ;
	}
#Mean large-scale rain rate
'mlsrr' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 67 ;
	}
#Mean surface downward short-wave radiation flux, clear sky
'msdwswrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 68 ;
	}
#Mean surface downward long-wave radiation flux, clear sky
'msdwlwrfcs' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 69 ;
	}
#Mean potential evaporation rate
'mper' = {
	 table2Version = 235 ;
	 indicatorOfParameter = 70 ;
	}
#Total precipitation rate
'tprate' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 48 ;
	}
#Ceiling
'ceil' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 109 ;
	}
#K index
'kx' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 121 ;
	}
#Total totals index
'totalx' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 123 ;
	}
#Stream function gradient
'strfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 1 ;
	}
#Velocity potential gradient
'vpotgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 2 ;
	}
#Potential temperature gradient
'ptgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 3 ;
	}
#Equivalent potential temperature gradient
'eqptgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 4 ;
	}
#Saturated equivalent potential temperature gradient
'septgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 5 ;
	}
#U component of divergent wind gradient
'udvwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 11 ;
	}
#V component of divergent wind gradient
'vdvwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 12 ;
	}
#U component of rotational wind gradient
'urtwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 13 ;
	}
#V component of rotational wind gradient
'vrtwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 14 ;
	}
#Unbalanced component of temperature gradient
'uctpgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 21 ;
	}
#Unbalanced component of logarithm of surface pressure gradient
'uclngrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 22 ;
	}
#Unbalanced component of divergence gradient
'ucdvgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 23 ;
	}
#Reserved for future unbalanced components
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 24 ;
	}
#Reserved for future unbalanced components
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 25 ;
	}
#Lake cover gradient
'clgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 26 ;
	}
#Low vegetation cover gradient
'cvlgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 27 ;
	}
#High vegetation cover gradient
'cvhgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 28 ;
	}
#Type of low vegetation gradient
'tvlgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 29 ;
	}
#Type of high vegetation gradient
'tvhgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 30 ;
	}
#Sea-ice cover gradient
'sicgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 31 ;
	}
#Snow albedo gradient
'asngrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 32 ;
	}
#Snow density gradient
'rsngrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 33 ;
	}
#Sea surface temperature gradient
'sstkgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 34 ;
	}
#Ice surface temperature layer 1 gradient
'istl1grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 35 ;
	}
#Ice surface temperature layer 2 gradient
'istl2grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 36 ;
	}
#Ice surface temperature layer 3 gradient
'istl3grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 37 ;
	}
#Ice surface temperature layer 4 gradient
'istl4grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 38 ;
	}
#Volumetric soil water layer 1 gradient
'swvl1grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 39 ;
	}
#Volumetric soil water layer 2 gradient
'swvl2grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 40 ;
	}
#Volumetric soil water layer 3 gradient
'swvl3grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 41 ;
	}
#Volumetric soil water layer 4 gradient
'swvl4grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 42 ;
	}
#Soil type gradient
'sltgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 43 ;
	}
#Snow evaporation gradient
'esgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt gradient
'smltgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 45 ;
	}
#Solar duration gradient
'sdurgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 46 ;
	}
#Direct solar radiation gradient
'dsrpgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 47 ;
	}
#Magnitude of turbulent surface stress gradient
'magssgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 48 ;
	}
#10 metre wind gust gradient
'10fggrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 49 ;
	}
#Large-scale precipitation fraction gradient
'lspfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 50 ;
	}
#Maximum 2 metre temperature gradient
'mx2t24grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 51 ;
	}
#Minimum 2 metre temperature gradient
'mn2t24grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 52 ;
	}
#Montgomery potential gradient
'montgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 53 ;
	}
#Pressure gradient
'presgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 54 ;
	}
#Mean 2 metre temperature in the last 24 hours gradient
'mean2t24grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours gradient
'mn2d24grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 56 ;
	}
#Downward UV radiation at the surface gradient
'uvbgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 57 ;
	}
#Photosynthetically active radiation at the surface gradient
'pargrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 58 ;
	}
#Convective available potential energy gradient
'capegrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 59 ;
	}
#Potential vorticity gradient
'pvgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 60 ;
	}
#Total precipitation from observations gradient
'tpogrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 61 ;
	}
#Observation count gradient
'obctgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 62 ;
	}
#Start time for skin temperature difference
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 63 ;
	}
#Finish time for skin temperature difference
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 64 ;
	}
#Skin temperature difference
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 65 ;
	}
#Leaf area index, low vegetation
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 66 ;
	}
#Leaf area index, high vegetation
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 67 ;
	}
#Minimum stomatal resistance, low vegetation
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 68 ;
	}
#Minimum stomatal resistance, high vegetation
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 69 ;
	}
#Biome cover, low vegetation
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 70 ;
	}
#Biome cover, high vegetation
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 71 ;
	}
#Total column liquid water
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 78 ;
	}
#Total column ice water
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 79 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 80 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 81 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 82 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 83 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 84 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 85 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 86 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 87 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 88 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 89 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 90 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 91 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 92 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 93 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 94 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 95 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 96 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 97 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 98 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 99 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 100 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 101 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 102 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 103 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 104 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 105 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 106 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 107 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 108 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 109 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 110 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 111 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 112 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 113 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 114 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 115 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 116 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 117 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 118 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 119 ;
	}
#Experimental product
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 120 ;
	}
#Maximum temperature at 2 metres gradient
'mx2t6grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 121 ;
	}
#Minimum temperature at 2 metres gradient
'mn2t6grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 122 ;
	}
#10 metre wind gust in the last 6 hours gradient
'10fg6grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 123 ;
	}
#Vertically integrated total energy
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 125 ;
	}
#Generic parameter for sensitive area prediction
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 126 ;
	}
#Atmospheric tide gradient
'atgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 127 ;
	}
#Budget values gradient
'bvgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 128 ;
	}
#Geopotential gradient
'zgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 129 ;
	}
#Temperature gradient
'tgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 130 ;
	}
#U component of wind gradient
'ugrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 131 ;
	}
#V component of wind gradient
'vgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 132 ;
	}
#Specific humidity gradient
'qgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 133 ;
	}
#Surface pressure gradient
'spgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 134 ;
	}
#vertical velocity (pressure) gradient
'wgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 135 ;
	}
#Total column water gradient
'tcwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 136 ;
	}
#Total column water vapour gradient
'tcwvgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 137 ;
	}
#Vorticity (relative) gradient
'vogrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 138 ;
	}
#Soil temperature level 1 gradient
'stl1grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 139 ;
	}
#Soil wetness level 1 gradient
'swl1grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 140 ;
	}
#Snow depth gradient
'sdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 141 ;
	}
#Stratiform precipitation (Large-scale precipitation) gradient
'lspgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation gradient
'cpgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall (convective + stratiform) gradient
'sfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation gradient
'bldgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux gradient
'sshfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux gradient
'slhfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 147 ;
	}
#Charnock gradient
'chnkgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 148 ;
	}
#Surface net radiation gradient
'snrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 149 ;
	}
#Top net radiation gradient
'tnrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 150 ;
	}
#Mean sea level pressure gradient
'mslgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 151 ;
	}
#Logarithm of surface pressure gradient
'lnspgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 152 ;
	}
#Short-wave heating rate gradient
'swhrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 153 ;
	}
#Long-wave heating rate gradient
'lwhrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 154 ;
	}
#Divergence gradient
'dgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 155 ;
	}
#Height gradient
'ghgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 156 ;
	}
#Relative humidity gradient
'rgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 157 ;
	}
#Tendency of surface pressure gradient
'tspgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 158 ;
	}
#Boundary layer height gradient
'blhgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 159 ;
	}
#Standard deviation of orography gradient
'sdorgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 160 ;
	}
#Anisotropy of sub-gridscale orography gradient
'isorgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 161 ;
	}
#Angle of sub-gridscale orography gradient
'anorgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 162 ;
	}
#Slope of sub-gridscale orography gradient
'slorgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 163 ;
	}
#Total cloud cover gradient
'tccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 164 ;
	}
#10 metre U wind component gradient
'10ugrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component gradient
'10vgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature gradient
'2tgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre dewpoint temperature gradient
'2dgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 168 ;
	}
#Surface solar radiation downwards gradient
'ssrdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 169 ;
	}
#Soil temperature level 2 gradient
'stl2grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 170 ;
	}
#Soil wetness level 2 gradient
'swl2grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 171 ;
	}
#Land-sea mask gradient
'lsmgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 172 ;
	}
#Surface roughness gradient
'srgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 173 ;
	}
#Albedo gradient
'algrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 174 ;
	}
#Surface thermal radiation downwards gradient
'strdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 175 ;
	}
#Surface net solar radiation gradient
'ssrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation gradient
'strgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation gradient
'tsrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation gradient
'ttrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 179 ;
	}
#East-West surface stress gradient
'ewssgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress gradient
'nsssgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation gradient
'egrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 182 ;
	}
#Soil temperature level 3 gradient
'stl3grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 183 ;
	}
#Soil wetness level 3 gradient
'swl3grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 184 ;
	}
#Convective cloud cover gradient
'cccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 185 ;
	}
#Low cloud cover gradient
'lccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 186 ;
	}
#Medium cloud cover gradient
'mccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 187 ;
	}
#High cloud cover gradient
'hccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 188 ;
	}
#Sunshine duration gradient
'sundgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 189 ;
	}
#East-West component of sub-gridscale orographic variance gradient
'ewovgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 190 ;
	}
#North-South component of sub-gridscale orographic variance gradient
'nsovgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 191 ;
	}
#North-West/South-East component of sub-gridscale orographic variance gradient
'nwovgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 192 ;
	}
#North-East/South-West component of sub-gridscale orographic variance gradient
'neovgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 193 ;
	}
#Brightness temperature gradient
'btmpgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 194 ;
	}
#Longitudinal component of gravity wave stress gradient
'lgwsgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 195 ;
	}
#Meridional component of gravity wave stress gradient
'mgwsgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation gradient
'gwdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 197 ;
	}
#Skin reservoir content gradient
'srcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 198 ;
	}
#Vegetation fraction gradient
'veggrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 199 ;
	}
#Variance of sub-gridscale orography gradient
'vsogrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 200 ;
	}
#Maximum temperature at 2 metres since previous post-processing gradient
'mx2tgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres since previous post-processing gradient
'mn2tgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 202 ;
	}
#Ozone mass mixing ratio gradient
'o3grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 203 ;
	}
#Precipitation analysis weights gradient
'pawgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 204 ;
	}
#Runoff gradient
'rogrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 205 ;
	}
#Total column ozone gradient
'tco3grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 206 ;
	}
#10 metre wind speed gradient
'10sigrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 207 ;
	}
#Top net solar radiation, clear sky gradient
'tsrcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation, clear sky gradient
'ttrcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation, clear sky gradient
'ssrcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky gradient
'strcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 211 ;
	}
#TOA incident solar radiation gradient
'tisrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 212 ;
	}
#Diabatic heating by radiation gradient
'dhrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 214 ;
	}
#Diabatic heating by vertical diffusion gradient
'dhvdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 215 ;
	}
#Diabatic heating by cumulus convection gradient
'dhccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 216 ;
	}
#Diabatic heating large-scale condensation gradient
'dhlcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 217 ;
	}
#Vertical diffusion of zonal wind gradient
'vdzwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 218 ;
	}
#Vertical diffusion of meridional wind gradient
'vdmwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 219 ;
	}
#East-West gravity wave drag tendency gradient
'ewgdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 220 ;
	}
#North-South gravity wave drag tendency gradient
'nsgdgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 221 ;
	}
#Convective tendency of zonal wind gradient
'ctzwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 222 ;
	}
#Convective tendency of meridional wind gradient
'ctmwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 223 ;
	}
#Vertical diffusion of humidity gradient
'vdhgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 224 ;
	}
#Humidity tendency by cumulus convection gradient
'htccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 225 ;
	}
#Humidity tendency by large-scale condensation gradient
'htlcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 226 ;
	}
#Change from removal of negative humidity gradient
'crnhgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 227 ;
	}
#Total precipitation gradient
'tpgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 228 ;
	}
#Instantaneous X surface stress gradient
'iewsgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 229 ;
	}
#Instantaneous Y surface stress gradient
'inssgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 230 ;
	}
#Instantaneous surface heat flux gradient
'ishfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 231 ;
	}
#Instantaneous moisture flux gradient
'iegrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 232 ;
	}
#Apparent surface humidity gradient
'asqgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 233 ;
	}
#Logarithm of surface roughness length for heat gradient
'lsrhgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 234 ;
	}
#Skin temperature gradient
'sktgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 235 ;
	}
#Soil temperature level 4 gradient
'stl4grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 236 ;
	}
#Soil wetness level 4 gradient
'swl4grd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 237 ;
	}
#Temperature of snow layer gradient
'tsngrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 238 ;
	}
#Convective snowfall gradient
'csfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall gradient
'lsfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 240 ;
	}
#Accumulated cloud fraction tendency gradient
'acfgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 241 ;
	}
#Accumulated liquid water tendency gradient
'alwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 242 ;
	}
#Forecast albedo gradient
'falgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 243 ;
	}
#Forecast surface roughness gradient
'fsrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 244 ;
	}
#Forecast logarithm of surface roughness for heat gradient
'flsrgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 245 ;
	}
#Specific cloud liquid water content gradient
'clwcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 246 ;
	}
#Specific cloud ice water content gradient
'ciwcgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 247 ;
	}
#Cloud cover gradient
'ccgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 248 ;
	}
#Accumulated ice water tendency gradient
'aiwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 249 ;
	}
#Ice age gradient
'icegrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 250 ;
	}
#Adiabatic tendency of temperature gradient
'attegrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 251 ;
	}
#Adiabatic tendency of humidity gradient
'athegrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 252 ;
	}
#Adiabatic tendency of zonal wind gradient
'atzegrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 253 ;
	}
#Adiabatic tendency of meridional wind gradient
'atmwgrd' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 254 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 255 ;
	}
#Top solar radiation upward
'tsru' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 208 ;
	}
#Top thermal radiation upward
'ttru' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 209 ;
	}
#Top solar radiation upward, clear sky
'tsuc' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 210 ;
	}
#Top thermal radiation upward, clear sky
'ttuc' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 211 ;
	}
#Cloud liquid water
'clw' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 212 ;
	}
#Cloud fraction
'cf' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 213 ;
	}
#Diabatic heating by radiation
'dhr' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 214 ;
	}
#Diabatic heating by vertical diffusion
'dhvd' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 215 ;
	}
#Diabatic heating by cumulus convection
'dhcc' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 216 ;
	}
#Diabatic heating by large-scale condensation
'dhlc' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 217 ;
	}
#Vertical diffusion of zonal wind
'vdzw' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 218 ;
	}
#Vertical diffusion of meridional wind
'vdmw' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 219 ;
	}
#East-West gravity wave drag
'ewgd' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 220 ;
	}
#North-South gravity wave drag
'nsgd' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 221 ;
	}
#Vertical diffusion of humidity
'vdh' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 224 ;
	}
#Humidity tendency by cumulus convection
'htcc' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 225 ;
	}
#Humidity tendency by large-scale condensation
'htlc' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 226 ;
	}
#Adiabatic tendency of temperature
'att' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 228 ;
	}
#Adiabatic tendency of humidity
'ath' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 229 ;
	}
#Adiabatic tendency of zonal wind
'atzw' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 230 ;
	}
#Adiabatic tendency of meridional wind
'atmwax' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 231 ;
	}
#Mean vertical velocity
'mvv' = {
	 table2Version = 130 ;
	 indicatorOfParameter = 232 ;
	}
#2m temperature anomaly of at least +2K
'2tag2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 1 ;
	}
#2m temperature anomaly of at least +1K
'2tag1' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 2 ;
	}
#2m temperature anomaly of at least 0K
'2tag0' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 3 ;
	}
#2m temperature anomaly of at most -1K
'2talm1' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 4 ;
	}
#2m temperature anomaly of at most -2K
'2talm2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 5 ;
	}
#Total precipitation anomaly of at least 20 mm
'tpag20' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 6 ;
	}
#Total precipitation anomaly of at least 10 mm
'tpag10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 7 ;
	}
#Total precipitation anomaly of at least 0 mm
'tpag0' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 8 ;
	}
#Surface temperature anomaly of at least 0K
'stag0' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 9 ;
	}
#Mean sea level pressure anomaly of at least 0 Pa
'mslag0' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 10 ;
	}
#Height of 0 degree isotherm probability
'h0dip' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 15 ;
	}
#Height of snowfall limit probability
'hslp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 16 ;
	}
#Showalter index probability
'saip' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 17 ;
	}
#Whiting index probability
'whip' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 18 ;
	}
#Temperature anomaly less than -2 K
'talm2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 20 ;
	}
#Temperature anomaly of at least +2 K
'tag2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 21 ;
	}
#Temperature anomaly less than -8 K
'talm8' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 22 ;
	}
#Temperature anomaly less than -4 K
'talm4' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 23 ;
	}
#Temperature anomaly greater than +4 K
'tag4' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 24 ;
	}
#Temperature anomaly greater than +8 K
'tag8' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 25 ;
	}
#10 metre wind gust probability
'10gp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 49 ;
	}
#Convective available potential energy probability
'capep' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 59 ;
	}
#Total precipitation less than 0.1 mm
'tpl01' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 64 ;
	}
#Total precipitation rate less than 1 mm/day
'tprl1' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 65 ;
	}
#Total precipitation rate of at least 3 mm/day
'tprg3' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 66 ;
	}
#Total precipitation rate of at least 5 mm/day
'tprg5' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 67 ;
	}
#10 metre Wind speed of at least 10 m/s
'10spg10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 68 ;
	}
#10 metre Wind speed of at least 15 m/s
'10spg15' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 69 ;
	}
#10 metre wind gust of at least 15 m/s
'10fgg15' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 70 ;
	}
#10 metre wind gust of at least 20 m/s
'10fgg20' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 71 ;
	}
#10 metre wind gust of at least 25 m/s
'10fgg25' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 72 ;
	}
#2 metre temperature less than 273.15 K
'2tl273' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 73 ;
	}
#Significant wave height of at least 2 m
'swhg2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 74 ;
	}
#Significant wave height of at least 4 m
'swhg4' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 75 ;
	}
#Significant wave height of at least 6 m
'swhg6' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 76 ;
	}
#Significant wave height of at least 8 m
'swhg8' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 77 ;
	}
#Mean wave period of at least 8 s
'mwpg8' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 78 ;
	}
#Mean wave period of at least 10 s
'mwpg10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 79 ;
	}
#Mean wave period of at least 12 s
'mwpg12' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 80 ;
	}
#Mean wave period of at least 15 s
'mwpg15' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 81 ;
	}
#Geopotential probability
'zp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 129 ;
	}
#Temperature anomaly probability
'tap' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 130 ;
	}
#Soil temperature level 1 probability
'stl1p' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 139 ;
	}
#Snowfall (convective + stratiform) probability
'sfp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 144 ;
	}
#Mean sea level pressure probability
'mslpp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 151 ;
	}
#Total cloud cover probability
'tccp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 164 ;
	}
#10 metre speed probability
'10sp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 165 ;
	}
#2 metre temperature probability
'2tp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 167 ;
	}
#Maximum 2 metre temperature probability
'mx2tp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum 2 metre temperature probability
'mn2tp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 202 ;
	}
#Total precipitation probability
'tpp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 228 ;
	}
#Significant wave height probability
'swhp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 229 ;
	}
#Mean wave period probability
'mwpp' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 232 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 255 ;
	}
#10 metre wind gust index
'10fgi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 49 ;
	}
#Snowfall index
'sfi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 144 ;
	}
#10 metre speed index
'10wsi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 165 ;
	}
#2 metre temperature index
'2ti' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 167 ;
	}
#Maximum temperature at 2 metres index
'mx2ti' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres index
'mn2ti' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 202 ;
	}
#Total precipitation index
'tpi' = {
	 table2Version = 132 ;
	 indicatorOfParameter = 228 ;
	}
#2m temperature probability less than -10 C
'2tplm10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 1 ;
	}
#2m temperature probability less than -5 C
'2tplm5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 2 ;
	}
#2m temperature probability less than 0 C
'2tpl0' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 3 ;
	}
#2m temperature probability less than 5 C
'2tpl5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 4 ;
	}
#2m temperature probability less than 10 C
'2tpl10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 5 ;
	}
#2m temperature probability greater than 25 C
'2tpg25' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 6 ;
	}
#2m temperature probability greater than 30 C
'2tpg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 7 ;
	}
#2m temperature probability greater than 35 C
'2tpg35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 8 ;
	}
#2m temperature probability greater than 40 C
'2tpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 9 ;
	}
#2m temperature probability greater than 45 C
'2tpg45' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 10 ;
	}
#Minimum 2 metre temperature probability less than -10 C
'mn2tplm10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 11 ;
	}
#Minimum 2 metre temperature probability less than -5 C
'mn2tplm5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 12 ;
	}
#Minimum 2 metre temperature probability less than 0 C
'mn2tpl0' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 13 ;
	}
#Minimum 2 metre temperature probability less than 5 C
'mn2tpl5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 14 ;
	}
#Minimum 2 metre temperature probability less than 10 C
'mn2tpl10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 15 ;
	}
#Maximum 2 metre temperature probability greater than 25 C
'mx2tpg25' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 16 ;
	}
#Maximum 2 metre temperature probability greater than 30 C
'mx2tpg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 17 ;
	}
#Maximum 2 metre temperature probability greater than 35 C
'mx2tpg35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 18 ;
	}
#Maximum 2 metre temperature probability greater than 40 C
'mx2tpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 19 ;
	}
#Maximum 2 metre temperature probability greater than 45 C
'mx2tpg45' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 20 ;
	}
#10 metre wind speed probability of at least 10 m/s
'10spg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 21 ;
	}
#10 metre wind speed probability of at least 15 m/s
'10spg15' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 22 ;
	}
#10 metre wind speed probability of at least 20 m/s
'10spg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 23 ;
	}
#10 metre wind speed probability of at least 35 m/s
'10spg35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 24 ;
	}
#10 metre wind speed probability of at least 50 m/s
'10spg50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 25 ;
	}
#10 metre wind gust probability of at least 20 m/s
'10gpg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 26 ;
	}
#10 metre wind gust probability of at least 35 m/s
'10gpg35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 27 ;
	}
#10 metre wind gust probability of at least 50 m/s
'10gpg50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 28 ;
	}
#10 metre wind gust probability of at least 75 m/s
'10gpg75' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 29 ;
	}
#10 metre wind gust probability of at least 100 m/s
'10gpg100' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 30 ;
	}
#Total precipitation probability of at least 1 mm
'tppg1' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 31 ;
	}
#Total precipitation probability of at least 5 mm
'tppg5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 32 ;
	}
#Total precipitation probability of at least 10 mm
'tppg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 33 ;
	}
#Total precipitation probability of at least 20 mm
'tppg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 34 ;
	}
#Total precipitation probability of at least 40 mm
'tppg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 35 ;
	}
#Total precipitation probability of at least 60 mm
'tppg60' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 36 ;
	}
#Total precipitation probability of at least 80 mm
'tppg80' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 37 ;
	}
#Total precipitation probability of at least 100 mm
'tppg100' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 38 ;
	}
#Total precipitation probability of at least 150 mm
'tppg150' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 39 ;
	}
#Total precipitation probability of at least 200 mm
'tppg200' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 40 ;
	}
#Total precipitation probability of at least 300 mm
'tppg300' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 41 ;
	}
#Snowfall probability of at least 1 mm
'sfpg1' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 42 ;
	}
#Snowfall probability of at least 5 mm
'sfpg5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 43 ;
	}
#Snowfall probability of at least 10 mm
'sfpg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 44 ;
	}
#Snowfall probability of at least 20 mm
'sfpg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 45 ;
	}
#Snowfall probability of at least 40 mm
'sfpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 46 ;
	}
#Snowfall probability of at least 60 mm
'sfpg60' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 47 ;
	}
#Snowfall probability of at least 80 mm
'sfpg80' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 48 ;
	}
#Snowfall probability of at least 100 mm
'sfpg100' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 49 ;
	}
#Snowfall probability of at least 150 mm
'sfpg150' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 50 ;
	}
#Snowfall probability of at least 200 mm
'sfpg200' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 51 ;
	}
#Snowfall probability of at least 300 mm
'sfpg300' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 52 ;
	}
#Total Cloud Cover probability greater than 10%
'tccpg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 53 ;
	}
#Total Cloud Cover probability greater than 20%
'tccpg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 54 ;
	}
#Total Cloud Cover probability greater than 30%
'tccpg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 55 ;
	}
#Total Cloud Cover probability greater than 40%
'tccpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 56 ;
	}
#Total Cloud Cover probability greater than 50%
'tccpg50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 57 ;
	}
#Total Cloud Cover probability greater than 60%
'tccpg60' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 58 ;
	}
#Total Cloud Cover probability greater than 70%
'tccpg70' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 59 ;
	}
#Total Cloud Cover probability greater than 80%
'tccpg80' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 60 ;
	}
#Total Cloud Cover probability greater than 90%
'tccpg90' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 61 ;
	}
#Total Cloud Cover probability greater than 99%
'tccpg99' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 62 ;
	}
#High Cloud Cover probability greater than 10%
'hccpg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 63 ;
	}
#High Cloud Cover probability greater than 20%
'hccpg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 64 ;
	}
#High Cloud Cover probability greater than 30%
'hccpg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 65 ;
	}
#High Cloud Cover probability greater than 40%
'hccpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 66 ;
	}
#High Cloud Cover probability greater than 50%
'hccpg50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 67 ;
	}
#High Cloud Cover probability greater than 60%
'hccpg60' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 68 ;
	}
#High Cloud Cover probability greater than 70%
'hccpg70' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 69 ;
	}
#High Cloud Cover probability greater than 80%
'hccpg80' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 70 ;
	}
#High Cloud Cover probability greater than 90%
'hccpg90' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 71 ;
	}
#High Cloud Cover probability greater than 99%
'hccpg99' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 72 ;
	}
#Medium Cloud Cover probability greater than 10%
'mccpg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 73 ;
	}
#Medium Cloud Cover probability greater than 20%
'mccpg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 74 ;
	}
#Medium Cloud Cover probability greater than 30%
'mccpg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 75 ;
	}
#Medium Cloud Cover probability greater than 40%
'mccpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 76 ;
	}
#Medium Cloud Cover probability greater than 50%
'mccpg50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 77 ;
	}
#Medium Cloud Cover probability greater than 60%
'mccpg60' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 78 ;
	}
#Medium Cloud Cover probability greater than 70%
'mccpg70' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 79 ;
	}
#Medium Cloud Cover probability greater than 80%
'mccpg80' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 80 ;
	}
#Medium Cloud Cover probability greater than 90%
'mccpg90' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 81 ;
	}
#Medium Cloud Cover probability greater than 99%
'mccpg99' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 82 ;
	}
#Low Cloud Cover probability greater than 10%
'lccpg10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 83 ;
	}
#Low Cloud Cover probability greater than 20%
'lccpg20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 84 ;
	}
#Low Cloud Cover probability greater than 30%
'lccpg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 85 ;
	}
#Low Cloud Cover probability greater than 40%
'lccpg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 86 ;
	}
#Low Cloud Cover probability greater than 50%
'lccpg50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 87 ;
	}
#Low Cloud Cover probability greater than 60%
'lccpg60' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 88 ;
	}
#Low Cloud Cover probability greater than 70%
'lccpg70' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 89 ;
	}
#Low Cloud Cover probability greater than 80%
'lccpg80' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 90 ;
	}
#Low Cloud Cover probability greater than 90%
'lccpg90' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 91 ;
	}
#Low Cloud Cover probability greater than 99%
'lccpg99' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 92 ;
	}
#Maximum of significant wave height
'maxswh' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 200 ;
	}
#Period corresponding to maximum individual wave height
'tmax' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 217 ;
	}
#Maximum individual wave height
'hmax' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 218 ;
	}
#Model bathymetry
'wmb' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 219 ;
	}
#Mean wave period based on first moment
'mp1' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 220 ;
	}
#Mean zero-crossing wave period
'mp2' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 221 ;
	}
#Wave spectral directional width
'wdw' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 222 ;
	}
#Mean wave period based on first moment for wind waves
'p1ww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 223 ;
	}
#Mean wave period based on second moment for wind waves
'p2ww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 224 ;
	}
#Wave spectral directional width for wind waves
'dwww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 225 ;
	}
#Mean wave period based on first moment for swell
'p1ps' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 226 ;
	}
#Mean wave period based on second moment for swell
'p2ps' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 227 ;
	}
#Wave spectral directional width for swell
'dwps' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 228 ;
	}
#Significant height of combined wind waves and swell
'swh' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 229 ;
	}
#Mean wave direction
'mwd' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 230 ;
	}
#Peak wave period
'pp1d' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 231 ;
	}
#Mean wave period
'mwp' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 232 ;
	}
#Coefficient of drag with waves
'cdww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 233 ;
	}
#Significant height of wind waves
'shww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 234 ;
	}
#Mean direction of wind waves
'mdww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 235 ;
	}
#Mean period of wind waves
'mpww' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 236 ;
	}
#Significant height of total swell
'shts' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 237 ;
	}
#Mean direction of total swell
'mdts' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 238 ;
	}
#Mean period of total swell
'mpts' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 239 ;
	}
#Standard deviation wave height
'sdhs' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 240 ;
	}
#Mean of 10 metre wind speed
'mu10' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 241 ;
	}
#Mean wind direction
'mdwi' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 242 ;
	}
#Standard deviation of 10 metre wind speed
'sdu' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 243 ;
	}
#Mean square slope of waves
'msqs' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 244 ;
	}
#10 metre wind speed
'wind' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 245 ;
	}
#Altimeter wave height
'awh' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 246 ;
	}
#Altimeter corrected wave height
'acwh' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 247 ;
	}
#Altimeter range relative correction
'arrc' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 248 ;
	}
#10 metre wind direction
'dwi' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 249 ;
	}
#2D wave spectra (multiple)
'2dsp' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 250 ;
	}
#2D wave spectra (single)
'2dfd' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 251 ;
	}
#Wave spectral kurtosis
'wsk' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 252 ;
	}
#Benjamin-Feir index
'bfi' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 253 ;
	}
#Wave spectral peakedness
'wsp' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 254 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 255 ;
	}
#Ocean potential temperature
'ocpt' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 129 ;
	}
#Ocean salinity
'ocs' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 130 ;
	}
#Ocean potential density
'ocpd' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 131 ;
	}
#Ocean U wind component
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 133 ;
	}
#Ocean V wind component
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 134 ;
	}
#Ocean W wind component
'ocw' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 135 ;
	}
#Richardson number
'rn' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 137 ;
	}
#U*V product
'uv' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 139 ;
	}
#U*T product
'ut' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 140 ;
	}
#V*T product
'vt' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 141 ;
	}
#U*U product
'uu' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 142 ;
	}
#V*V product
'vv' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 143 ;
	}
#UV - U~V~
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 144 ;
	}
#UT - U~T~
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 145 ;
	}
#VT - V~T~
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 146 ;
	}
#UU - U~U~
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 147 ;
	}
#VV - V~V~
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 148 ;
	}
#Sea level
'sl' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 152 ;
	}
#Barotropic stream function
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 153 ;
	}
#Mixed layer depth
'mld' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 154 ;
	}
#Depth
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 155 ;
	}
#U stress
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 168 ;
	}
#V stress
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 169 ;
	}
#Turbulent kinetic energy input
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 170 ;
	}
#Net surface heat flux
'nsf' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 171 ;
	}
#Surface solar radiation
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 172 ;
	}
#P-E
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 173 ;
	}
#Diagnosed sea surface temperature error
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 180 ;
	}
#Heat flux correction
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 181 ;
	}
#Observed sea surface temperature
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 182 ;
	}
#Observed heat flux
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 183 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 150 ;
	 indicatorOfParameter = 255 ;
	}
#In situ Temperature
'~' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 128 ;
	}
#Sea water potential temperature
'thetao' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 129 ;
	}
#Sea water practical salinity
'so' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 130 ;
	}
#Eastward sea water velocity
'ocu' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 131 ;
	}
#Northward sea water velocity
'ocv' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 132 ;
	}
#Upward sea water velocity
'wo' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 133 ;
	}
#Modulus of strain rate tensor
'mst' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 134 ;
	}
#Vertical viscosity
'vvs' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 135 ;
	}
#Vertical diffusivity
'vdf' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 136 ;
	}
#Bottom level Depth
'dep' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 137 ;
	}
#Sea water sigma theta
'sigmat' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 138 ;
	}
#Richardson number
'rn' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 139 ;
	}
#UV product
'uv' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 140 ;
	}
#UT product
'ut' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 141 ;
	}
#VT product
'vt' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 142 ;
	}
#UU product
'uu' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 143 ;
	}
#VV product
'vv' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 144 ;
	}
#Sea surface height
'zos' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 145 ;
	}
#Sea level previous timestep
'sl_1' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 146 ;
	}
#Ocean barotropic stream function
'stfbarot' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 147 ;
	}
#Mixed layer depth
'mld' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 148 ;
	}
#Bottom Pressure (equivalent height)
'btp' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 149 ;
	}
#Steric height
'sh' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 150 ;
	}
#Curl of Wind Stress
'crl' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 151 ;
	}
#Divergence of wind stress
'~' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 152 ;
	}
#Surface downward eastward stress
'taueo' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 153 ;
	}
#Surface downward northward stress
'tauno' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 154 ;
	}
#Turbulent kinetic energy input
'tki' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 155 ;
	}
#Net surface heat flux
'nsf' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 156 ;
	}
#Absorbed solar radiation
'asr' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 157 ;
	}
#Precipitation - evaporation
'pme' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 158 ;
	}
#Specified sea surface temperature
'sst' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 159 ;
	}
#Specified surface heat flux
'shf' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 160 ;
	}
#Diagnosed sea surface temperature error
'dte' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 161 ;
	}
#Heat flux correction
'hfc' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 162 ;
	}
#Depth of 20C isotherm
't20d' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 163 ;
	}
#Average potential temperature in the upper 300m
'tav300' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 164 ;
	}
#Vertically integrated zonal velocity (previous time step)
'uba1' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 165 ;
	}
#Vertically Integrated meridional velocity (previous time step)
'vba1' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 166 ;
	}
#Vertically integrated zonal volume transport
'ztr' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 167 ;
	}
#Vertically integrated meridional volume transport
'mtr' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 168 ;
	}
#Vertically integrated zonal heat transport
'zht' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 169 ;
	}
#Vertically integrated meridional heat transport
'mht' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 170 ;
	}
#U velocity maximum
'umax' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 171 ;
	}
#Depth of the velocity maximum
'dumax' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 172 ;
	}
#Salinity maximum
'smax' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 173 ;
	}
#Depth of salinity maximum
'dsmax' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 174 ;
	}
#Average salinity in the upper 300m
'sav300' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 175 ;
	}
#Layer Thickness at scalar points
'ldp' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 176 ;
	}
#Layer Thickness at vector points
'ldu' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 177 ;
	}
#Potential temperature increment
'pti' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 178 ;
	}
#Potential temperature analysis error
'ptae' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 179 ;
	}
#Background potential temperature
'bpt' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 180 ;
	}
#Analysed potential temperature
'apt' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 181 ;
	}
#Potential temperature background error
'ptbe' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 182 ;
	}
#Analysed salinity
'as' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 183 ;
	}
#Salinity increment
'sali' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 184 ;
	}
#Estimated Bias in Temperature
'ebt' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 185 ;
	}
#Estimated Bias in Salinity
'ebs' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 186 ;
	}
#Zonal Velocity increment (from balance operator)
'uvi' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 187 ;
	}
#Meridional Velocity increment (from balance operator)
'vvi' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 188 ;
	}
#Salinity increment (from salinity data)
'subi' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 190 ;
	}
#Salinity analysis error
'sale' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 191 ;
	}
#Background Salinity
'bsal' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 192 ;
	}
#Salinity background error
'salbe' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 194 ;
	}
#Estimated temperature bias from assimilation
'ebta' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 199 ;
	}
#Estimated salinity bias from assimilation
'ebsa' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 200 ;
	}
#Temperature increment from relaxation term
'lti' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 201 ;
	}
#Salinity increment from relaxation term
'lsi' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 202 ;
	}
#Bias in the zonal pressure gradient (applied)
'bzpga' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 203 ;
	}
#Bias in the meridional pressure gradient (applied)
'bmpga' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 204 ;
	}
#Estimated temperature bias from relaxation
'ebtl' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 205 ;
	}
#Estimated salinity bias from relaxation
'ebsl' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 206 ;
	}
#First guess bias in temperature
'fgbt' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 207 ;
	}
#First guess bias in salinity
'fgbs' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 208 ;
	}
#Applied bias in pressure
'bpa' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 209 ;
	}
#FG bias in pressure
'fgbp' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 210 ;
	}
#Bias in temperature(applied)
'pta' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 211 ;
	}
#Bias in salinity (applied)
'psa' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 212 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 255 ;
	}
#10 metre wind gust during averaging time
'10fgrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 49 ;
	}
#vertical velocity (pressure)
'wrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 135 ;
	}
#Precipitable water content
'pwcrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 137 ;
	}
#Soil wetness level 1
'swl1rea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 140 ;
	}
#Snow depth
'sdrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 141 ;
	}
#Large-scale precipitation
'lsprea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation
'cprea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall
'sfrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 144 ;
	}
#Height
'ghrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 156 ;
	}
#Relative humidity
'rrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 157 ;
	}
#Soil wetness level 2
'swl2rea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 171 ;
	}
#East-West surface stress
'ewssrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress
'nsssrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation
'erea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 182 ;
	}
#Soil wetness level 3
'swl3rea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 184 ;
	}
#Skin reservoir content
'srcrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 198 ;
	}
#Percentage of vegetation
'vegrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 199 ;
	}
#Maximum temperature at 2 metres during averaging time
'mx2trea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres during averaging time
'mn2trea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 202 ;
	}
#Runoff
'rorea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 205 ;
	}
#Standard deviation of geopotential
'zzrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 206 ;
	}
#Covariance of temperature and geopotential
'tzrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 207 ;
	}
#Standard deviation of temperature
'ttrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 208 ;
	}
#Covariance of specific humidity and geopotential
'qzrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 209 ;
	}
#Covariance of specific humidity and temperature
'qtrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 210 ;
	}
#Standard deviation of specific humidity
'qqrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 211 ;
	}
#Covariance of U component and geopotential
'uzrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 212 ;
	}
#Covariance of U component and temperature
'utrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 213 ;
	}
#Covariance of U component and specific humidity
'uqrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 214 ;
	}
#Standard deviation of U velocity
'uurea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 215 ;
	}
#Covariance of V component and geopotential
'vzrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 216 ;
	}
#Covariance of V component and temperature
'vtrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 217 ;
	}
#Covariance of V component and specific humidity
'vqrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 218 ;
	}
#Covariance of V component and U component
'vurea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 219 ;
	}
#Standard deviation of V component
'vvrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 220 ;
	}
#Covariance of W component and geopotential
'wzrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 221 ;
	}
#Covariance of W component and temperature
'wtrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 222 ;
	}
#Covariance of W component and specific humidity
'wqrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 223 ;
	}
#Covariance of W component and U component
'wurea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 224 ;
	}
#Covariance of W component and V component
'wvrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 225 ;
	}
#Standard deviation of vertical velocity
'wwrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 226 ;
	}
#Instantaneous surface heat flux
'ishfrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 231 ;
	}
#Convective snowfall
'csfrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall
'lsfrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 240 ;
	}
#Cloud liquid water content
'clwcerrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 241 ;
	}
#Cloud cover
'ccrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 242 ;
	}
#Forecast albedo
'falrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 243 ;
	}
#10 metre wind speed
'10wsrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 246 ;
	}
#Momentum flux
'moflrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 247 ;
	}
#Gravity wave dissipation flux
'~' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 249 ;
	}
#Heaviside beta function
'hsdrea' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 254 ;
	}
#Surface geopotential
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 51 ;
	}
#Vertical integral of mass of atmosphere
'vima' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 53 ;
	}
#Vertical integral of temperature
'vit' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 54 ;
	}
#Vertical integral of water vapour
'viwv' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 55 ;
	}
#Vertical integral of cloud liquid water
'vilw' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 56 ;
	}
#Vertical integral of cloud frozen water
'viiw' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 57 ;
	}
#Vertical integral of ozone
'vioz' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 58 ;
	}
#Vertical integral of kinetic energy
'vike' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 59 ;
	}
#Vertical integral of thermal energy
'vithe' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 60 ;
	}
#Vertical integral of potential+internal energy
'vipie' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 61 ;
	}
#Vertical integral of potential+internal+latent energy
'vipile' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 62 ;
	}
#Vertical integral of total energy
'vitoe' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 63 ;
	}
#Vertical integral of energy conversion
'viec' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 64 ;
	}
#Vertical integral of eastward mass flux
'vimae' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 65 ;
	}
#Vertical integral of northward mass flux
'viman' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 66 ;
	}
#Vertical integral of eastward kinetic energy flux
'vikee' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 67 ;
	}
#Vertical integral of northward kinetic energy flux
'viken' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 68 ;
	}
#Vertical integral of eastward heat flux
'vithee' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 69 ;
	}
#Vertical integral of northward heat flux
'vithen' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 70 ;
	}
#Vertical integral of eastward water vapour flux
'viwve' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 71 ;
	}
#Vertical integral of northward water vapour flux
'viwvn' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 72 ;
	}
#Vertical integral of eastward geopotential flux
'vige' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 73 ;
	}
#Vertical integral of northward geopotential flux
'vign' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 74 ;
	}
#Vertical integral of eastward total energy flux
'vitoee' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 75 ;
	}
#Vertical integral of northward total energy flux
'vitoen' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 76 ;
	}
#Vertical integral of eastward ozone flux
'vioze' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 77 ;
	}
#Vertical integral of northward ozone flux
'viozn' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 78 ;
	}
#Vertical integral of divergence of mass flux
'vimad' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 81 ;
	}
#Vertical integral of divergence of kinetic energy flux
'viked' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 82 ;
	}
#Vertical integral of divergence of thermal energy flux
'vithed' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 83 ;
	}
#Vertical integral of divergence of moisture flux
'viwvd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 84 ;
	}
#Vertical integral of divergence of geopotential flux
'vigd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 85 ;
	}
#Vertical integral of divergence of total energy flux
'vitoed' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 86 ;
	}
#Vertical integral of divergence of ozone flux
'viozd' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 87 ;
	}
#Tendency of short wave radiation
'srta' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 100 ;
	}
#Tendency of long wave radiation
'trta' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 101 ;
	}
#Tendency of clear sky short wave radiation
'srtca' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 102 ;
	}
#Tendency of clear sky long wave radiation
'trtca' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 103 ;
	}
#Updraught mass flux
'umfa' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 104 ;
	}
#Downdraught mass flux
'dmfa' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 105 ;
	}
#Updraught detrainment rate
'udra' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 106 ;
	}
#Downdraught detrainment rate
'ddra' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 107 ;
	}
#Total precipitation flux
'tpfa' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 108 ;
	}
#Turbulent diffusion coefficient for heat
'tdcha' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 109 ;
	}
#Tendency of temperature due to physics
'ttpha' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 110 ;
	}
#Tendency of specific humidity due to physics
'qtpha' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 111 ;
	}
#Tendency of u component due to physics
'utpha' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 112 ;
	}
#Tendency of v component due to physics
'vtpha' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 113 ;
	}
#Variance of geopotential
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 206 ;
	}
#Covariance of geopotential/temperature
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 207 ;
	}
#Variance of temperature
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 208 ;
	}
#Covariance of geopotential/specific humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 209 ;
	}
#Covariance of temperature/specific humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 210 ;
	}
#Variance of specific humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 211 ;
	}
#Covariance of u component/geopotential
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 212 ;
	}
#Covariance of u component/temperature
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 213 ;
	}
#Covariance of u component/specific humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 214 ;
	}
#Variance of u component
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 215 ;
	}
#Covariance of v component/geopotential
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 216 ;
	}
#Covariance of v component/temperature
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 217 ;
	}
#Covariance of v component/specific humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 218 ;
	}
#Covariance of v component/u component
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 219 ;
	}
#Variance of v component
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 220 ;
	}
#Covariance of omega/geopotential
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 221 ;
	}
#Covariance of omega/temperature
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 222 ;
	}
#Covariance of omega/specific humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 223 ;
	}
#Covariance of omega/u component
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 224 ;
	}
#Covariance of omega/v component
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 225 ;
	}
#Variance of omega
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 226 ;
	}
#Variance of surface pressure
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 227 ;
	}
#Variance of relative humidity
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 229 ;
	}
#Covariance of u component/ozone
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 230 ;
	}
#Covariance of v component/ozone
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 231 ;
	}
#Covariance of omega/ozone
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 232 ;
	}
#Variance of ozone
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 233 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 255 ;
	}
#Total soil moisture
'tsw' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 149 ;
	}
#Soil wetness level 2
'swl2' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 171 ;
	}
#Top net thermal radiation
'ttr' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 179 ;
	}
#Stream function anomaly
'strfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 1 ;
	}
#Velocity potential anomaly
'vpota' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 2 ;
	}
#Potential temperature anomaly
'pta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 3 ;
	}
#Equivalent potential temperature anomaly
'epta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 4 ;
	}
#Saturated equivalent potential temperature anomaly
'septa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 5 ;
	}
#U component of divergent wind anomaly
'udwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 11 ;
	}
#V component of divergent wind anomaly
'vdwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 12 ;
	}
#U component of rotational wind anomaly
'urwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 13 ;
	}
#V component of rotational wind anomaly
'vrwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 14 ;
	}
#Unbalanced component of temperature anomaly
'uctpa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 21 ;
	}
#Unbalanced component of logarithm of surface pressure anomaly
'uclna' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 22 ;
	}
#Unbalanced component of divergence anomaly
'ucdva' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 23 ;
	}
#Lake cover anomaly
'cla' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 26 ;
	}
#Low vegetation cover anomaly
'cvla' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 27 ;
	}
#High vegetation cover anomaly
'cvha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 28 ;
	}
#Type of low vegetation anomaly
'tvla' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 29 ;
	}
#Type of high vegetation anomaly
'tvha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 30 ;
	}
#Sea-ice cover anomaly
'sica' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 31 ;
	}
#Snow albedo anomaly
'asna' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 32 ;
	}
#Snow density anomaly
'rsna' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 33 ;
	}
#Sea surface temperature anomaly
'ssta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 34 ;
	}
#Ice surface temperature anomaly layer 1
'istal1' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 35 ;
	}
#Ice surface temperature anomaly layer 2
'istal2' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 36 ;
	}
#Ice surface temperature anomaly layer 3
'istal3' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 37 ;
	}
#Ice surface temperature anomaly layer 4
'istal4' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 38 ;
	}
#Volumetric soil water anomaly layer 1
'swval1' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 39 ;
	}
#Volumetric soil water anomaly layer 2
'swval2' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 40 ;
	}
#Volumetric soil water anomaly layer 3
'swval3' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 41 ;
	}
#Volumetric soil water anomaly layer 4
'swval4' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 42 ;
	}
#Soil type anomaly
'slta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 43 ;
	}
#Snow evaporation anomaly
'esa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt anomaly
'smlta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 45 ;
	}
#Solar duration anomaly
'sdura' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 46 ;
	}
#Direct solar radiation anomaly
'dsrpa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 47 ;
	}
#Magnitude of turbulent surface stress anomaly
'magssa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 48 ;
	}
#10 metre wind gust anomaly
'10fga' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 49 ;
	}
#Large-scale precipitation fraction anomaly
'lspfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 50 ;
	}
#Maximum 2 metre temperature in the last 24 hours anomaly
'mx2t24a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 51 ;
	}
#Minimum 2 metre temperature in the last 24 hours anomaly
'mn2t24a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 52 ;
	}
#Montgomery potential anomaly
'monta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 53 ;
	}
#Pressure anomaly
'pa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 54 ;
	}
#Mean 2 metre temperature in the last 24 hours anomaly
'mean2t24a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours anomaly
'mn2d24a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 56 ;
	}
#Downward UV radiation at the surface anomaly
'uvba' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 57 ;
	}
#Photosynthetically active radiation at the surface anomaly
'para' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 58 ;
	}
#Convective available potential energy anomaly
'capea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 59 ;
	}
#Potential vorticity anomaly
'pva' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 60 ;
	}
#Total precipitation from observations anomaly
'tpoa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 61 ;
	}
#Observation count anomaly
'obcta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 62 ;
	}
#Start time for skin temperature difference anomaly
'stsktda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 63 ;
	}
#Finish time for skin temperature difference anomaly
'ftsktda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 64 ;
	}
#Skin temperature difference anomaly
'sktda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 65 ;
	}
#Total column liquid water anomaly
'tclwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 78 ;
	}
#Total column ice water anomaly
'tciwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 79 ;
	}
#Vertically integrated total energy anomaly
'vitea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 125 ;
	}
#Generic parameter for sensitive area prediction
'~' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 126 ;
	}
#Atmospheric tide anomaly
'ata' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 127 ;
	}
#Budget values anomaly
'bva' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 128 ;
	}
#Geopotential anomaly
'za' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 129 ;
	}
#Temperature anomaly
'ta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 130 ;
	}
#U component of wind anomaly
'ua' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 131 ;
	}
#V component of wind anomaly
'va' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 132 ;
	}
#Specific humidity anomaly
'qa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 133 ;
	}
#Surface pressure anomaly
'spa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 134 ;
	}
#Vertical velocity (pressure) anomaly
'wa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 135 ;
	}
#Total column water anomaly
'tcwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 136 ;
	}
#Total column water vapour anomaly
'tcwva' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 137 ;
	}
#Relative vorticity anomaly
'voa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 138 ;
	}
#Soil temperature anomaly level 1
'stal1' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 139 ;
	}
#Soil wetness anomaly level 1
'swal1' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 140 ;
	}
#Snow depth anomaly
'sda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 141 ;
	}
#Stratiform precipitation (Large-scale precipitation) anomaly
'lspa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation anomaly
'cpa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall (convective + stratiform) anomaly
'sfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation anomaly
'blda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux anomaly
'sshfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux anomaly
'slhfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 147 ;
	}
#Charnock anomaly
'chnka' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 148 ;
	}
#Surface net radiation anomaly
'snra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 149 ;
	}
#Top net radiation anomaly
'tnra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 150 ;
	}
#Mean sea level pressure anomaly
'msla' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 151 ;
	}
#Logarithm of surface pressure anomaly
'lspa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 152 ;
	}
#Short-wave heating rate anomaly
'swhra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 153 ;
	}
#Long-wave heating rate anomaly
'lwhra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 154 ;
	}
#Relative divergence anomaly
'da' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 155 ;
	}
#Height anomaly
'gha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 156 ;
	}
#Relative humidity anomaly
'ra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 157 ;
	}
#Tendency of surface pressure anomaly
'tspa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 158 ;
	}
#Boundary layer height anomaly
'blha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 159 ;
	}
#Standard deviation of orography anomaly
'sdora' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 160 ;
	}
#Anisotropy of sub-gridscale orography anomaly
'isora' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 161 ;
	}
#Angle of sub-gridscale orography anomaly
'anora' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 162 ;
	}
#Slope of sub-gridscale orography anomaly
'slora' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 163 ;
	}
#Total cloud cover anomaly
'tcca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 164 ;
	}
#10 metre U wind component anomaly
'10ua' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component anomaly
'10va' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature anomaly
'2ta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre dewpoint temperature anomaly
'2da' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 168 ;
	}
#Surface solar radiation downwards anomaly
'ssrda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 169 ;
	}
#Soil temperature anomaly level 2
'stal2' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 170 ;
	}
#Soil wetness anomaly level 2
'swal2' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 171 ;
	}
#Surface roughness anomaly
'sra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 173 ;
	}
#Albedo anomaly
'ala' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 174 ;
	}
#Surface thermal radiation downwards anomaly
'strda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 175 ;
	}
#Surface net solar radiation anomaly
'ssra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation anomaly
'stra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation anomaly
'tsra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation anomaly
'ttra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 179 ;
	}
#East-West surface stress anomaly
'eqssa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress anomaly
'nsssa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation anomaly
'ea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 182 ;
	}
#Soil temperature anomaly level 3
'stal3' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 183 ;
	}
#Soil wetness anomaly level 3
'swal3' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 184 ;
	}
#Convective cloud cover anomaly
'ccca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 185 ;
	}
#Low cloud cover anomaly
'lcca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 186 ;
	}
#Medium cloud cover anomaly
'mcca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 187 ;
	}
#High cloud cover anomaly
'hcca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 188 ;
	}
#Sunshine duration anomaly
'sunda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 189 ;
	}
#East-West component of sub-gridscale orographic variance anomaly
'ewova' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 190 ;
	}
#North-South component of sub-gridscale orographic variance anomaly
'nsova' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 191 ;
	}
#North-West/South-East component of sub-gridscale orographic variance anomaly
'nwova' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 192 ;
	}
#North-East/South-West component of sub-gridscale orographic variance anomaly
'neova' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 193 ;
	}
#Brightness temperature anomaly
'btmpa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 194 ;
	}
#Longitudinal component of gravity wave stress anomaly
'lgwsa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 195 ;
	}
#Meridional component of gravity wave stress anomaly
'mgwsa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation anomaly
'gwda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 197 ;
	}
#Skin reservoir content anomaly
'srca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 198 ;
	}
#Vegetation fraction anomaly
'vfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 199 ;
	}
#Variance of sub-gridscale orography anomaly
'vsoa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 200 ;
	}
#Maximum temperature at 2 metres anomaly
'mx2ta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres anomaly
'mn2ta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 202 ;
	}
#Ozone mass mixing ratio anomaly
'o3a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 203 ;
	}
#Precipitation analysis weights anomaly
'pawa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 204 ;
	}
#Runoff anomaly
'roa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 205 ;
	}
#Total column ozone anomaly
'tco3a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 206 ;
	}
#10 metre wind speed anomaly
'10sia' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 207 ;
	}
#Top net solar radiation clear sky anomaly
'tsrca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation clear sky anomaly
'ttrca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation clear sky anomaly
'ssrca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky anomaly
'strca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 211 ;
	}
#Solar insolation anomaly
'sia' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 212 ;
	}
#Diabatic heating by radiation anomaly
'dhra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 214 ;
	}
#Diabatic heating by vertical diffusion anomaly
'dhvda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 215 ;
	}
#Diabatic heating by cumulus convection anomaly
'dhcca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 216 ;
	}
#Diabatic heating by large-scale condensation anomaly
'dhlca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 217 ;
	}
#Vertical diffusion of zonal wind anomaly
'vdzwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 218 ;
	}
#Vertical diffusion of meridional wind anomaly
'vdmwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 219 ;
	}
#East-West gravity wave drag tendency anomaly
'ewgda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 220 ;
	}
#North-South gravity wave drag tendency anomaly
'nsgda' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 221 ;
	}
#Convective tendency of zonal wind anomaly
'ctzwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 222 ;
	}
#Convective tendency of meridional wind anomaly
'ctmwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 223 ;
	}
#Vertical diffusion of humidity anomaly
'vdha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 224 ;
	}
#Humidity tendency by cumulus convection anomaly
'htcca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 225 ;
	}
#Humidity tendency by large-scale condensation anomaly
'htlca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 226 ;
	}
#Change from removal of negative humidity anomaly
'crnha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 227 ;
	}
#Total precipitation anomaly
'tpa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 228 ;
	}
#Instantaneous X surface stress anomaly
'iewsa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 229 ;
	}
#Instantaneous Y surface stress anomaly
'inssa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 230 ;
	}
#Instantaneous surface heat flux anomaly
'ishfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 231 ;
	}
#Instantaneous moisture flux anomaly
'iea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 232 ;
	}
#Apparent surface humidity anomaly
'asqa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 233 ;
	}
#Logarithm of surface roughness length for heat anomaly
'lsrha' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 234 ;
	}
#Skin temperature anomaly
'skta' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 235 ;
	}
#Soil temperature level 4 anomaly
'stal4' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 236 ;
	}
#Soil wetness level 4 anomaly
'swal4' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 237 ;
	}
#Temperature of snow layer anomaly
'tsna' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 238 ;
	}
#Convective snowfall anomaly
'csfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall anomaly
'lsfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 240 ;
	}
#Accumulated cloud fraction tendency anomaly
'acfa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 241 ;
	}
#Accumulated liquid water tendency anomaly
'alwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 242 ;
	}
#Forecast albedo anomaly
'fala' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 243 ;
	}
#Forecast surface roughness anomaly
'fsra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 244 ;
	}
#Forecast logarithm of surface roughness for heat anomaly
'flsra' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 245 ;
	}
#Cloud liquid water content anomaly
'clwca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 246 ;
	}
#Cloud ice water content anomaly
'ciwca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 247 ;
	}
#Cloud cover anomaly
'cca' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 248 ;
	}
#Accumulated ice water tendency anomaly
'aiwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 249 ;
	}
#Ice age anomaly
'iaa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 250 ;
	}
#Adiabatic tendency of temperature anomaly
'attea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 251 ;
	}
#Adiabatic tendency of humidity anomaly
'athea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 252 ;
	}
#Adiabatic tendency of zonal wind anomaly
'atzea' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 253 ;
	}
#Adiabatic tendency of meridional wind anomaly
'atmwa' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 254 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 255 ;
	}
#Snow evaporation
'esrate' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 45 ;
	}
#Magnitude of turbulent surface stress
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 48 ;
	}
#Mean large-scale precipitation fraction
'mlspfr' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 50 ;
	}
#Mean large-scale precipitation rate
'mlsprt' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 142 ;
	}
#Mean convective precipitation rate
'cprate' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 143 ;
	}
#Mean total snowfall rate
'mtsfr' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation
'bldrate' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 145 ;
	}
#Mean surface sensible heat flux
'msshfl' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 146 ;
	}
#Mean surface latent heat flux
'mslhfl' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 147 ;
	}
#Mean surface net radiation flux
'msnrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 149 ;
	}
#Mean short-wave heating rate
'mswhr' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 153 ;
	}
#Mean long-wave heating rate
'mlwhr' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 154 ;
	}
#Mean surface downward solar radiation flux
'msdsrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 169 ;
	}
#Mean surface downward thermal radiation flux
'msdtrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 175 ;
	}
#Mean surface net solar radiation flux
'msnsrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 176 ;
	}
#Mean surface net thermal radiation flux
'msntrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 177 ;
	}
#Mean top net solar radiation flux
'mtnsrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 178 ;
	}
#Mean top net thermal radiation flux
'mtntrf' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 179 ;
	}
#East-West surface stress rate of accumulation
'ewssra' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress rate of accumulation
'nsssra' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation
'erate' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 182 ;
	}
#Mean sunshine duration rate
'msdr' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 189 ;
	}
#Longitudinal component of gravity wave stress
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 195 ;
	}
#Meridional component of gravity wave stress
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation
'gwdrate' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 197 ;
	}
#Mean runoff rate
'mrort' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 205 ;
	}
#Top net solar radiation, clear sky
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation, clear sky
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation, clear sky
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 211 ;
	}
#Solar insolation rate of accumulation
'soira' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 212 ;
	}
#Mean total precipitation rate
'tprate' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 228 ;
	}
#Convective snowfall
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 240 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 172 ;
	 indicatorOfParameter = 255 ;
	}
#Snow evaporation anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 45 ;
	}
#Magnitude of turbulent surface stress anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 48 ;
	}
#Large-scale precipitation fraction anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 50 ;
	}
#Stratiform precipitation (Large-scale precipitation) anomalous rate of accumulation
'lspara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 142 ;
	}
#Mean convective precipitation rate anomaly
'mcpra' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall (convective + stratiform) anomalous rate of accumulation
'sfara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux anomalous rate of accumulation
'sshfara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux anomalous rate of accumulation
'slhfara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 147 ;
	}
#Surface net radiation anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 149 ;
	}
#Short-wave heating rate anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 153 ;
	}
#Long-wave heating rate anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 154 ;
	}
#Surface solar radiation downwards anomalous rate of accumulation
'ssrdara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 169 ;
	}
#Surface thermal radiation downwards anomalous rate of accumulation
'strdara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 175 ;
	}
#Surface solar radiation anomalous rate of accumulation
'ssrara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 176 ;
	}
#Surface thermal radiation anomalous rate of accumulation
'strara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 177 ;
	}
#Top solar radiation anomalous rate of accumulation
'tsrara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 178 ;
	}
#Top thermal radiation anomalous rate of accumulation
'ttrara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 179 ;
	}
#East-West surface stress anomalous rate of accumulation
'ewssara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress anomalous rate of accumulation
'nsssara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation anomalous rate of accumulation
'evara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 182 ;
	}
#Sunshine duration anomalous rate of accumulation
'sundara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 189 ;
	}
#Longitudinal component of gravity wave stress anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 195 ;
	}
#Meridional component of gravity wave stress anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 197 ;
	}
#Runoff anomalous rate of accumulation
'roara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 205 ;
	}
#Top net solar radiation, clear sky anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation, clear sky anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation, clear sky anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 211 ;
	}
#Solar insolation anomalous rate of accumulation
'soiara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 212 ;
	}
#Total precipitation anomalous rate of accumulation
'tpara' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 228 ;
	}
#Convective snowfall anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 239 ;
	}
#Large scale snowfall anomaly
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 240 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 173 ;
	 indicatorOfParameter = 255 ;
	}
#Total soil moisture
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 6 ;
	}
#Surface runoff
'sro' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 8 ;
	}
#Sub-surface runoff
'ssro' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 9 ;
	}
#Fraction of sea-ice in sea
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 31 ;
	}
#Open-sea surface temperature
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 34 ;
	}
#Volumetric soil water layer 1
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 39 ;
	}
#Volumetric soil water layer 2
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 40 ;
	}
#Volumetric soil water layer 3
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 41 ;
	}
#Volumetric soil water layer 4
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 42 ;
	}
#10 metre wind gust in the last 24 hours
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 49 ;
	}
#1.5m temperature - mean in the last 24 hours
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 55 ;
	}
#Net primary productivity
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 83 ;
	}
#10m U wind over land
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 85 ;
	}
#10m V wind over land
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 86 ;
	}
#1.5m temperature over land
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 87 ;
	}
#1.5m dewpoint temperature over land
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 88 ;
	}
#Top incoming solar radiation
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 89 ;
	}
#Top outgoing solar radiation
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 90 ;
	}
#Mean sea surface temperature
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 94 ;
	}
#1.5m specific humidity
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 95 ;
	}
#Sea-ice thickness
'sithick' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 98 ;
	}
#Liquid water potential temperature
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 99 ;
	}
#Ocean ice concentration
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 110 ;
	}
#Ocean mean ice depth
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 111 ;
	}
#Soil temperature layer 1
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 139 ;
	}
#Average potential temperature in upper 293.4m
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 164 ;
	}
#1.5m temperature
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 167 ;
	}
#1.5m dewpoint temperature
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 168 ;
	}
#Soil temperature layer 2
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 170 ;
	}
#Average salinity in upper 293.4m
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 175 ;
	}
#Soil temperature layer 3
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 183 ;
	}
#1.5m temperature - maximum in the last 24 hours
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 201 ;
	}
#1.5m temperature - minimum in the last 24 hours
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 202 ;
	}
#Soil temperature layer 4
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 236 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 255 ;
	}
#Total soil moisture
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 6 ;
	}
#Fraction of sea-ice in sea
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 31 ;
	}
#Open-sea surface temperature
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 34 ;
	}
#Volumetric soil water layer 1
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 39 ;
	}
#Volumetric soil water layer 2
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 40 ;
	}
#Volumetric soil water layer 3
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 41 ;
	}
#Volumetric soil water layer 4
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 42 ;
	}
#10m wind gust in the last 24 hours
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 49 ;
	}
#1.5m temperature - mean in the last 24 hours
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 55 ;
	}
#Net primary productivity
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 83 ;
	}
#10m U wind over land
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 85 ;
	}
#10m V wind over land
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 86 ;
	}
#1.5m temperature over land
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 87 ;
	}
#1.5m dewpoint temperature over land
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 88 ;
	}
#Top incoming solar radiation
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 89 ;
	}
#Top outgoing solar radiation
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 90 ;
	}
#Ocean ice concentration
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 110 ;
	}
#Ocean mean ice depth
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 111 ;
	}
#Soil temperature layer 1
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 139 ;
	}
#Average potential temperature in upper 293.4m
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 164 ;
	}
#1.5m temperature
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 167 ;
	}
#1.5m dewpoint temperature
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 168 ;
	}
#Soil temperature layer 2
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 170 ;
	}
#Average salinity in upper 293.4m
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 175 ;
	}
#Soil temperature layer 3
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 183 ;
	}
#1.5m temperature - maximum in the last 24 hours
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 201 ;
	}
#1.5m temperature - minimum in the last 24 hours
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 202 ;
	}
#Soil temperature layer 4
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 236 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 255 ;
	}
#Total soil wetness
'tsw' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 149 ;
	}
#Surface net solar radiation
'ssr' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation
'str' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation
'tsr' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation
'ttr' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 179 ;
	}
#Snow depth
'sdsien' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 141 ;
	}
#Field capacity
'cap' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 170 ;
	}
#Wilting point
'wiltsien' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 171 ;
	}
#Roughness length
'sr' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 173 ;
	}
#Total soil moisture
'tsm' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 229 ;
	}
#2 metre dewpoint temperature difference
'2ddiff' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 168 ;
	}
#downward shortwave radiant flux density
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 1 ;
	}
#upward shortwave radiant flux density
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 2 ;
	}
#downward longwave radiant flux density
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 3 ;
	}
#upward longwave radiant flux density
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 4 ;
	}
#downwd photosynthetic active radiant flux density
'apab_s' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	}
#net shortwave flux
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 6 ;
	}
#net longwave flux
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 7 ;
	}
#total net radiative flux density
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 8 ;
	}
#downw shortw radiant flux density, cloudfree part
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 9 ;
	}
#upw shortw radiant flux density, cloudy part
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 10 ;
	}
#downw longw radiant flux density, cloudfree part
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 11 ;
	}
#upw longw radiant flux density, cloudy part
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 12 ;
	}
#shortwave radiative heating rate
'sohr_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 13 ;
	}
#longwave radiative heating rate
'thhr_rad' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 14 ;
	}
#total radiative heating rate
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 15 ;
	}
#soil heat flux, surface
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 16 ;
	}
#soil heat flux, bottom of layer
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 17 ;
	}
#fractional cloud cover
'clc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 29 ;
	}
#cloud cover, grid scale
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 30 ;
	}
#specific cloud water content
'qc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 31 ;
	}
#cloud water content, grid scale, vert integrated
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 32 ;
	}
#specific cloud ice content, grid scale
'qi' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 33 ;
	}
#cloud ice content, grid scale, vert integrated
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 34 ;
	}
#specific rainwater content, grid scale
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 35 ;
	}
#specific snow content, grid scale
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 36 ;
	}
#specific rainwater content, gs, vert. integrated
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 37 ;
	}
#specific snow content, gs, vert. integrated
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 38 ;
	}
#total column water
'twater' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 41 ;
	}
#vert. integral of divergence of tot. water content
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	}
#cloud covers CH_CM_CL (000...888)
'ch_cm_cl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 50 ;
	}
#cloud cover CH (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 51 ;
	}
#cloud cover CM (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 52 ;
	}
#cloud cover CL (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 53 ;
	}
#total cloud cover (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 54 ;
	}
#fog (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 55 ;
	}
#fog
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 56 ;
	}
#cloud cover, convective cirrus
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 60 ;
	}
#specific cloud water content, convective clouds
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 61 ;
	}
#cloud water content, conv clouds, vert integrated
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 62 ;
	}
#specific cloud ice content, convective clouds
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 63 ;
	}
#cloud ice content, conv clouds, vert integrated
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 64 ;
	}
#convective mass flux
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 65 ;
	}
#Updraft velocity, convection
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 66 ;
	}
#entrainment parameter, convection
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 67 ;
	}
#cloud base, convective clouds (above msl)
'hbas_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 68 ;
	}
#cloud top, convective clouds (above msl)
'htop_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 69 ;
	}
#convective layers (00...77)  (BKE)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 70 ;
	}
#KO-index
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 71 ;
	}
#convection base index
'bas_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 72 ;
	}
#convection top index
'top_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 73 ;
	}
#convective temperature tendency
'dt_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 74 ;
	}
#convective tendency of specific humidity
'dqv_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 75 ;
	}
#convective tendency of total heat
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 76 ;
	}
#convective tendency of total water
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 77 ;
	}
#convective momentum tendency (X-component)
'du_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 78 ;
	}
#convective momentum tendency (Y-component)
'dv_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 79 ;
	}
#convective vorticity tendency
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 80 ;
	}
#convective divergence tendency
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 81 ;
	}
#top of dry convection (above msl)
'htop_dc' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 82 ;
	}
#dry convection top index
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 83 ;
	}
#height of 0 degree Celsius isotherm above msl
'hzerocl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 84 ;
	}
#height of snow-fall limit
'snowlmt' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 85 ;
	}
#spec. content of precip. particles
'qrs_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 99 ;
	}
#surface precipitation rate, rain, grid scale
'prr_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 100 ;
	}
#surface precipitation rate, snow, grid scale
'prs_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 101 ;
	}
#surface precipitation amount, rain, grid scale
'rain_gsp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	}
#surface precipitation rate, rain, convective
'prr_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 111 ;
	}
#surface precipitation rate, snow, convective
'prs_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 112 ;
	}
#surface precipitation amount, rain, convective
'rain_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	}
#deviation of pressure from reference value
'pp' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 139 ;
	}
#coefficient of horizontal diffusion
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 150 ;
	}
#Maximum wind velocity
'vmax_10m' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	}
#water content of interception store
'w_i' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 200 ;
	}
#snow temperature
't_snow' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 203 ;
	}
#ice surface temperature
't_ice' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 215 ;
	}
#convective available potential energy
'cape_con' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 241 ;
	}
#Indicates a missing value
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 255 ;
	}
#Sea Salt Aerosol (0.03 - 0.5 um) Mixing Ratio
'aermr01' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 1 ;
	}
#Sea Salt Aerosol (0.5 - 5 um) Mixing Ratio
'aermr02' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 2 ;
	}
#Sea Salt Aerosol (5 - 20 um) Mixing Ratio
'aermr03' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 3 ;
	}
#Dust Aerosol (0.03 - 0.55 um) Mixing Ratio
'aermr04' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 4 ;
	}
#Dust Aerosol (0.55 - 0.9 um) Mixing Ratio
'aermr05' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 5 ;
	}
#Dust Aerosol (0.9 - 20 um) Mixing Ratio
'aermr06' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 6 ;
	}
#Hydrophilic Organic Matter Aerosol Mixing Ratio
'aermr07' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 7 ;
	}
#Hydrophobic Organic Matter Aerosol Mixing Ratio
'aermr08' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 8 ;
	}
#Hydrophilic Black Carbon Aerosol Mixing Ratio
'aermr09' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 9 ;
	}
#Hydrophobic Black Carbon Aerosol Mixing Ratio
'aermr10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 10 ;
	}
#Sulphate Aerosol Mixing Ratio
'aermr11' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 11 ;
	}
#SO2 precursor mixing ratio
'aermr12' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 12 ;
	}
#Aerosol type 1 source/gain accumulated
'aergn01' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 16 ;
	}
#Aerosol type 2 source/gain accumulated
'aergn02' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 17 ;
	}
#Aerosol type 3 source/gain accumulated
'aergn03' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 18 ;
	}
#Aerosol type 4 source/gain accumulated
'aergn04' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 19 ;
	}
#Aerosol type 5 source/gain accumulated
'aergn05' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 20 ;
	}
#Aerosol type 6 source/gain accumulated
'aergn06' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 21 ;
	}
#Aerosol type 7 source/gain accumulated
'aergn07' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 22 ;
	}
#Aerosol type 8 source/gain accumulated
'aergn08' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 23 ;
	}
#Aerosol type 9 source/gain accumulated
'aergn09' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 24 ;
	}
#Aerosol type 10 source/gain accumulated
'aergn10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 25 ;
	}
#Aerosol type 11 source/gain accumulated
'aergn11' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 26 ;
	}
#Aerosol type 12 source/gain accumulated
'aergn12' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 27 ;
	}
#Aerosol type 1 sink/loss accumulated
'aerls01' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 31 ;
	}
#Aerosol type 2 sink/loss accumulated
'aerls02' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 32 ;
	}
#Aerosol type 3 sink/loss accumulated
'aerls03' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 33 ;
	}
#Aerosol type 4 sink/loss accumulated
'aerls04' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 34 ;
	}
#Aerosol type 5 sink/loss accumulated
'aerls05' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 35 ;
	}
#Aerosol type 6 sink/loss accumulated
'aerls06' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 36 ;
	}
#Aerosol type 7 sink/loss accumulated
'aerls07' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 37 ;
	}
#Aerosol type 8 sink/loss accumulated
'aerls08' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 38 ;
	}
#Aerosol type 9 sink/loss accumulated
'aerls09' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 39 ;
	}
#Aerosol type 10 sink/loss accumulated
'aerls10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 40 ;
	}
#Aerosol type 11 sink/loss accumulated
'aerls11' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 41 ;
	}
#Aerosol type 12 sink/loss accumulated
'aerls12' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 42 ;
	}
#Aerosol precursor mixing ratio
'aerpr' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 46 ;
	}
#Aerosol small mode mixing ratio
'aersm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 47 ;
	}
#Aerosol large mode mixing ratio
'aerlg' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 48 ;
	}
#Aerosol precursor optical depth
'aodpr' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 49 ;
	}
#Aerosol small mode optical depth
'aodsm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 50 ;
	}
#Aerosol large mode optical depth
'aodlg' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 51 ;
	}
#Dust emission potential
'aerdep' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 52 ;
	}
#Lifting threshold speed
'aerlts' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 53 ;
	}
#Soil clay content
'aerscc' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 54 ;
	}
#Carbon Dioxide
'co2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 61 ;
	}
#Methane
'ch4' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 62 ;
	}
#Nitrous oxide
'n2o' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 63 ;
	}
#CO2 column-mean molar fraction
'tcco2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 64 ;
	}
#CH4 column-mean molar fraction
'tcch4' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 65 ;
	}
#Total column Nitrous oxide
'tcn2o' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 66 ;
	}
#Ocean flux of Carbon Dioxide
'co2of' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 67 ;
	}
#Natural biosphere flux of Carbon Dioxide
'co2nbf' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 68 ;
	}
#Anthropogenic emissions of Carbon Dioxide
'co2apf' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 69 ;
	}
#Methane Surface Fluxes
'ch4f' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 70 ;
	}
#Methane loss rate due to radical hydroxyl (OH)
'kch4' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 71 ;
	}
#Wildfire flux of Carbon Dioxide
'co2fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 80 ;
	}
#Wildfire flux of Carbon Monoxide
'cofire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 81 ;
	}
#Wildfire flux of Methane
'ch4fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 82 ;
	}
#Wildfire flux of Non-Methane Hydro-Carbons
'nmhcfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 83 ;
	}
#Wildfire flux of Hydrogen
'h2fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 84 ;
	}
#Wildfire flux of Nitrogen Oxides NOx
'noxfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 85 ;
	}
#Wildfire flux of Nitrous Oxide
'n2ofire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 86 ;
	}
#Wildfire flux of Particulate Matter PM2.5
'pm2p5fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 87 ;
	}
#Wildfire flux of Total Particulate Matter
'tpmfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 88 ;
	}
#Wildfire flux of Total Carbon in Aerosols
'tcfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 89 ;
	}
#Wildfire flux of Organic Carbon
'ocfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 90 ;
	}
#Wildfire flux of Black Carbon
'bcfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 91 ;
	}
#Wildfire overall flux of burnt Carbon
'cfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 92 ;
	}
#Wildfire fraction of C4 plants
'c4ffire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 93 ;
	}
#Wildfire vegetation map index
'vegfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 94 ;
	}
#Wildfire Combustion Completeness
'ccfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 95 ;
	}
#Wildfire Fuel Load: Carbon per unit area
'flfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 96 ;
	}
#Wildfire fraction of area observed
'offire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 97 ;
	}
#Number of positive FRP pixels per grid cell
'nofrp' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 98 ;
	}
#Wildfire radiative power
'frpfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 99 ;
	}
#Wildfire combustion rate
'crfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 100 ;
	}
#Nitrogen dioxide
'no2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 121 ;
	}
#Sulphur dioxide
'so2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 122 ;
	}
#Carbon monoxide
'co' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 123 ;
	}
#Formaldehyde
'hcho' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 124 ;
	}
#Total column Nitrogen dioxide
'tcno2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 125 ;
	}
#Total column Sulphur dioxide
'tcso2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 126 ;
	}
#Total column Carbon monoxide
'tcco' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 127 ;
	}
#Total column Formaldehyde
'tchcho' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 128 ;
	}
#Nitrogen Oxides
'nox' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 129 ;
	}
#Total Column Nitrogen Oxides
'tcnox' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 130 ;
	}
#Reactive tracer 1 mass mixing ratio
'grg1' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 131 ;
	}
#Total column GRG tracer 1
'tcgrg1' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 132 ;
	}
#Reactive tracer 2 mass mixing ratio
'grg2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 133 ;
	}
#Total column GRG tracer 2
'tcgrg2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 134 ;
	}
#Reactive tracer 3 mass mixing ratio
'grg3' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 135 ;
	}
#Total column GRG tracer 3
'tcgrg3' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 136 ;
	}
#Reactive tracer 4 mass mixing ratio
'grg4' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 137 ;
	}
#Total column GRG tracer 4
'tcgrg4' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 138 ;
	}
#Reactive tracer 5 mass mixing ratio
'grg5' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 139 ;
	}
#Total column GRG tracer 5
'tcgrg5' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 140 ;
	}
#Reactive tracer 6 mass mixing ratio
'grg6' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 141 ;
	}
#Total column GRG tracer 6
'tcgrg6' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 142 ;
	}
#Reactive tracer 7 mass mixing ratio
'grg7' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 143 ;
	}
#Total column GRG tracer 7
'tcgrg7' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 144 ;
	}
#Reactive tracer 8 mass mixing ratio
'grg8' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 145 ;
	}
#Total column GRG tracer 8
'tcgrg8' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 146 ;
	}
#Reactive tracer 9 mass mixing ratio
'grg9' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 147 ;
	}
#Total column GRG tracer 9
'tcgrg9' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 148 ;
	}
#Reactive tracer 10 mass mixing ratio
'grg10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 149 ;
	}
#Total column GRG tracer 10
'tcgrg10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 150 ;
	}
#Surface flux Nitrogen oxides
'sfnox' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 151 ;
	}
#Surface flux Nitrogen dioxide
'sfno2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 152 ;
	}
#Surface flux Sulphur dioxide
'sfso2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 153 ;
	}
#Surface flux Carbon monoxide
'sfco2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 154 ;
	}
#Surface flux Formaldehyde
'sfhcho' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 155 ;
	}
#Surface flux GEMS Ozone
'sfgo3' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 156 ;
	}
#Surface flux reactive tracer 1
'sfgr1' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 157 ;
	}
#Surface flux reactive tracer 2
'sfgr2' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 158 ;
	}
#Surface flux reactive tracer 3
'sfgr3' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 159 ;
	}
#Surface flux reactive tracer 4
'sfgr4' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 160 ;
	}
#Surface flux reactive tracer 5
'sfgr5' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 161 ;
	}
#Surface flux reactive tracer 6
'sfgr6' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 162 ;
	}
#Surface flux reactive tracer 7
'sfgr7' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 163 ;
	}
#Surface flux reactive tracer 8
'sfgr8' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 164 ;
	}
#Surface flux reactive tracer 9
'sfgr9' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 165 ;
	}
#Surface flux reactive tracer 10
'sfgr10' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 166 ;
	}
#Radon
'ra' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 181 ;
	}
#Sulphur Hexafluoride
'sf6' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 182 ;
	}
#Total column Radon
'tcra' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 183 ;
	}
#Total column Sulphur Hexafluoride
'tcsf6' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 184 ;
	}
#Anthropogenic Emissions of Sulphur Hexafluoride
'sf6apf' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 185 ;
	}
#GEMS Ozone
'go3' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 203 ;
	}
#GEMS Total column ozone
'gtco3' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 206 ;
	}
#Total Aerosol Optical Depth at 550nm
'aod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 207 ;
	}
#Sea Salt Aerosol Optical Depth at 550nm
'ssaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 208 ;
	}
#Dust Aerosol Optical Depth at 550nm
'duaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 209 ;
	}
#Organic Matter Aerosol Optical Depth at 550nm
'omaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 210 ;
	}
#Black Carbon Aerosol Optical Depth at 550nm
'bcaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 211 ;
	}
#Sulphate Aerosol Optical Depth at 550nm
'suaod550' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 212 ;
	}
#Total Aerosol Optical Depth at 469nm
'aod469' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 213 ;
	}
#Total Aerosol Optical Depth at 670nm
'aod670' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 214 ;
	}
#Total Aerosol Optical Depth at 865nm
'aod865' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 215 ;
	}
#Total Aerosol Optical Depth at 1240nm
'aod1240' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 216 ;
	}
#Sea Salt Aerosol (0.03 - 0.5 um) Mixing Ratio
'aermr01diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 1 ;
	}
#Sea Salt Aerosol (0.5 - 5 um) Mixing Ratio
'aermr02diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 2 ;
	}
#Sea Salt Aerosol (5 - 20 um) Mixing Ratio
'aermr03diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 3 ;
	}
#Dust Aerosol (0.03 - 0.55 um) Mixing Ratio
'aermr04diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 4 ;
	}
#Dust Aerosol (0.55 - 0.9 um) Mixing Ratio
'aermr05diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 5 ;
	}
#Dust Aerosol (0.9 - 20 um) Mixing Ratio
'aermr06diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 6 ;
	}
#Hydrophilic Organic Matter Aerosol Mixing Ratio
'aermr07diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 7 ;
	}
#Hydrophobic Organic Matter Aerosol Mixing Ratio
'aermr08diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 8 ;
	}
#Hydrophilic Black Carbon Aerosol Mixing Ratio
'aermr09diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 9 ;
	}
#Hydrophobic Black Carbon Aerosol Mixing Ratio
'aermr10diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 10 ;
	}
#Sulphate Aerosol Mixing Ratio
'aermr11diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 11 ;
	}
#Aerosol type 12 mixing ratio
'aermr12diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 12 ;
	}
#Aerosol type 1 source/gain accumulated
'aergn01diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 16 ;
	}
#Aerosol type 2 source/gain accumulated
'aergn02diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 17 ;
	}
#Aerosol type 3 source/gain accumulated
'aergn03diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 18 ;
	}
#Aerosol type 4 source/gain accumulated
'aergn04diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 19 ;
	}
#Aerosol type 5 source/gain accumulated
'aergn05diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 20 ;
	}
#Aerosol type 6 source/gain accumulated
'aergn06diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 21 ;
	}
#Aerosol type 7 source/gain accumulated
'aergn07diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 22 ;
	}
#Aerosol type 8 source/gain accumulated
'aergn08diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 23 ;
	}
#Aerosol type 9 source/gain accumulated
'aergn09diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 24 ;
	}
#Aerosol type 10 source/gain accumulated
'aergn10diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 25 ;
	}
#Aerosol type 11 source/gain accumulated
'aergn11diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 26 ;
	}
#Aerosol type 12 source/gain accumulated
'aergn12diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 27 ;
	}
#Aerosol type 1 sink/loss accumulated
'aerls01diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 31 ;
	}
#Aerosol type 2 sink/loss accumulated
'aerls02diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 32 ;
	}
#Aerosol type 3 sink/loss accumulated
'aerls03diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 33 ;
	}
#Aerosol type 4 sink/loss accumulated
'aerls04diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 34 ;
	}
#Aerosol type 5 sink/loss accumulated
'aerls05diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 35 ;
	}
#Aerosol type 6 sink/loss accumulated
'aerls06diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 36 ;
	}
#Aerosol type 7 sink/loss accumulated
'aerls07diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 37 ;
	}
#Aerosol type 8 sink/loss accumulated
'aerls08diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 38 ;
	}
#Aerosol type 9 sink/loss accumulated
'aerls09diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 39 ;
	}
#Aerosol type 10 sink/loss accumulated
'aerls10diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 40 ;
	}
#Aerosol type 11 sink/loss accumulated
'aerls11diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 41 ;
	}
#Aerosol type 12 sink/loss accumulated
'aerls12diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 42 ;
	}
#Aerosol precursor mixing ratio
'aerprdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 46 ;
	}
#Aerosol small mode mixing ratio
'aersmdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 47 ;
	}
#Aerosol large mode mixing ratio
'aerlgdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 48 ;
	}
#Aerosol precursor optical depth
'aodprdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 49 ;
	}
#Aerosol small mode optical depth
'aodsmdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 50 ;
	}
#Aerosol large mode optical depth
'aodlgdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 51 ;
	}
#Dust emission potential
'aerdepdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 52 ;
	}
#Lifting threshold speed
'aerltsdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 53 ;
	}
#Soil clay content
'aersccdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 54 ;
	}
#Carbon Dioxide
'co2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 61 ;
	}
#Methane
'ch4diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 62 ;
	}
#Nitrous oxide
'n2odiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 63 ;
	}
#Total column Carbon Dioxide
'tcco2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 64 ;
	}
#Total column Methane
'tcch4diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 65 ;
	}
#Total column Nitrous oxide
'tcn2odiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 66 ;
	}
#Ocean flux of Carbon Dioxide
'co2ofdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 67 ;
	}
#Natural biosphere flux of Carbon Dioxide
'co2nbfdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 68 ;
	}
#Anthropogenic emissions of Carbon Dioxide
'co2apfdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 69 ;
	}
#Methane Surface Fluxes
'ch4fdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 70 ;
	}
#Methane loss rate due to radical hydroxyl (OH)
'kch4diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 71 ;
	}
#Wildfire flux of Carbon Dioxide
'co2firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 80 ;
	}
#Wildfire flux of Carbon Monoxide
'cofirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 81 ;
	}
#Wildfire flux of Methane
'ch4firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 82 ;
	}
#Wildfire flux of Non-Methane Hydro-Carbons
'nmhcfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 83 ;
	}
#Wildfire flux of Hydrogen
'h2firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 84 ;
	}
#Wildfire flux of Nitrogen Oxides NOx
'noxfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 85 ;
	}
#Wildfire flux of Nitrous Oxide
'n2ofirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 86 ;
	}
#Wildfire flux of Particulate Matter PM2.5
'pm2p5firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 87 ;
	}
#Wildfire flux of Total Particulate Matter
'tpmfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 88 ;
	}
#Wildfire flux of Total Carbon in Aerosols
'tcfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 89 ;
	}
#Wildfire flux of Organic Carbon
'ocfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 90 ;
	}
#Wildfire flux of Black Carbon
'bcfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 91 ;
	}
#Wildfire overall flux of burnt Carbon
'cfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 92 ;
	}
#Wildfire fraction of C4 plants
'c4ffirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 93 ;
	}
#Wildfire vegetation map index
'vegfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 94 ;
	}
#Wildfire Combustion Completeness
'ccfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 95 ;
	}
#Wildfire Fuel Load: Carbon per unit area
'flfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 96 ;
	}
#Wildfire fraction of area observed
'offirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 97 ;
	}
#Wildfire observed area
'oafirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 98 ;
	}
#Wildfire radiative power
'frpfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 99 ;
	}
#Wildfire combustion rate
'crfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 100 ;
	}
#Nitrogen dioxide
'no2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 121 ;
	}
#Sulphur dioxide
'so2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 122 ;
	}
#Carbon monoxide
'codiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 123 ;
	}
#Formaldehyde
'hchodiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 124 ;
	}
#Total column Nitrogen dioxide
'tcno2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 125 ;
	}
#Total column Sulphur dioxide
'tcso2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 126 ;
	}
#Total column Carbon monoxide
'tccodiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 127 ;
	}
#Total column Formaldehyde
'tchchodiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 128 ;
	}
#Nitrogen Oxides
'noxdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 129 ;
	}
#Total Column Nitrogen Oxides
'tcnoxdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 130 ;
	}
#Reactive tracer 1 mass mixing ratio
'grg1diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 131 ;
	}
#Total column GRG tracer 1
'tcgrg1diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 132 ;
	}
#Reactive tracer 2 mass mixing ratio
'grg2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 133 ;
	}
#Total column GRG tracer 2
'tcgrg2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 134 ;
	}
#Reactive tracer 3 mass mixing ratio
'grg3diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 135 ;
	}
#Total column GRG tracer 3
'tcgrg3diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 136 ;
	}
#Reactive tracer 4 mass mixing ratio
'grg4diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 137 ;
	}
#Total column GRG tracer 4
'tcgrg4diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 138 ;
	}
#Reactive tracer 5 mass mixing ratio
'grg5diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 139 ;
	}
#Total column GRG tracer 5
'tcgrg5diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 140 ;
	}
#Reactive tracer 6 mass mixing ratio
'grg6diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 141 ;
	}
#Total column GRG tracer 6
'tcgrg6diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 142 ;
	}
#Reactive tracer 7 mass mixing ratio
'grg7diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 143 ;
	}
#Total column GRG tracer 7
'tcgrg7diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 144 ;
	}
#Reactive tracer 8 mass mixing ratio
'grg8diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 145 ;
	}
#Total column GRG tracer 8
'tcgrg8diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 146 ;
	}
#Reactive tracer 9 mass mixing ratio
'grg9diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 147 ;
	}
#Total column GRG tracer 9
'tcgrg9diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 148 ;
	}
#Reactive tracer 10 mass mixing ratio
'grg10diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 149 ;
	}
#Total column GRG tracer 10
'tcgrg10diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 150 ;
	}
#Surface flux Nitrogen oxides
'sfnoxdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 151 ;
	}
#Surface flux Nitrogen dioxide
'sfno2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 152 ;
	}
#Surface flux Sulphur dioxide
'sfso2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 153 ;
	}
#Surface flux Carbon monoxide
'sfco2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 154 ;
	}
#Surface flux Formaldehyde
'sfhchodiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 155 ;
	}
#Surface flux GEMS Ozone
'sfgo3diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 156 ;
	}
#Surface flux reactive tracer 1
'sfgr1diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 157 ;
	}
#Surface flux reactive tracer 2
'sfgr2diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 158 ;
	}
#Surface flux reactive tracer 3
'sfgr3diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 159 ;
	}
#Surface flux reactive tracer 4
'sfgr4diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 160 ;
	}
#Surface flux reactive tracer 5
'sfgr5diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 161 ;
	}
#Surface flux reactive tracer 6
'sfgr6diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 162 ;
	}
#Surface flux reactive tracer 7
'sfgr7diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 163 ;
	}
#Surface flux reactive tracer 8
'sfgr8diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 164 ;
	}
#Surface flux reactive tracer 9
'sfgr9diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 165 ;
	}
#Surface flux reactive tracer 10
'sfgr10diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 166 ;
	}
#Radon
'radiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 181 ;
	}
#Sulphur Hexafluoride
'sf6diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 182 ;
	}
#Total column Radon
'tcradiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 183 ;
	}
#Total column Sulphur Hexafluoride
'tcsf6diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 184 ;
	}
#Anthropogenic Emissions of Sulphur Hexafluoride
'sf6apfdiff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 185 ;
	}
#GEMS Ozone
'go3diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 203 ;
	}
#GEMS Total column ozone
'gtco3diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 206 ;
	}
#Total Aerosol Optical Depth at 550nm
'aod550diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 207 ;
	}
#Sea Salt Aerosol Optical Depth at 550nm
'ssaod550diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 208 ;
	}
#Dust Aerosol Optical Depth at 550nm
'duaod550diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 209 ;
	}
#Organic Matter Aerosol Optical Depth at 550nm
'omaod550diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 210 ;
	}
#Black Carbon Aerosol Optical Depth at 550nm
'bcaod550diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 211 ;
	}
#Sulphate Aerosol Optical Depth at 550nm
'suaod550diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 212 ;
	}
#Total Aerosol Optical Depth at 469nm
'aod469diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 213 ;
	}
#Total Aerosol Optical Depth at 670nm
'aod670diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 214 ;
	}
#Total Aerosol Optical Depth at 865nm
'aod865diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 215 ;
	}
#Total Aerosol Optical Depth at 1240nm
'aod1240diff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 216 ;
	}
#Total precipitation observation count
'tpoc' = {
	 table2Version = 220 ;
	 indicatorOfParameter = 228 ;
	}
#Convective inhibition
'cin' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 1 ;
	}
#Orography
'orog' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 2 ;
	}
#Friction velocity
'zust' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 3 ;
	}
#Mean temperature at 2 metres
'mean2t' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 4 ;
	}
#Mean of 10 metre wind speed
'mean10ws' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 5 ;
	}
#Mean total cloud cover
'meantcc' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 6 ;
	}
#Lake total depth
'dl' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 7 ;
	}
#Lake mix-layer temperature
'lmlt' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 8 ;
	}
#Lake mix-layer depth
'lmld' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 9 ;
	}
#Lake bottom temperature
'lblt' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 10 ;
	}
#Lake total layer temperature
'ltlt' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 11 ;
	}
#Lake shape factor
'lshf' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 12 ;
	}
#Lake ice surface temperature
'lict' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 13 ;
	}
#Lake ice total depth
'licd' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 14 ;
	}
#Minimum vertical gradient of refractivity inside trapping layer
'dndzn' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 15 ;
	}
#Mean vertical gradient of refractivity inside trapping layer
'dndza' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 16 ;
	}
#Duct base height
'dctb' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 17 ;
	}
#Trapping layer base height
'tplb' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 18 ;
	}
#Trapping layer top height
'tplt' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 19 ;
	}
#Soil Moisture
'sm' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 39 ;
	}
#Neutral wind at 10 m u-component
'u10n' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 131 ;
	}
#Neutral wind at 10 m v-component
'v10n' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 132 ;
	}
#Soil Temperature
'st' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 139 ;
	}
#Snow depth water equivalent
'sd' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 141 ;
	}
#Snow Fall water equivalent
'sf' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 144 ;
	}
#Total Cloud Cover
'tcc' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 164 ;
	}
#Field capacity
'cap' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 170 ;
	}
#Wilting point
'wilt' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 171 ;
	}
#Total Precipitation
'tp' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 228 ;
	}
#Snow evaporation (variable resolution)
'esvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 44 ;
	}
#Snowmelt (variable resolution)
'smltvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 45 ;
	}
#Solar duration (variable resolution)
'sdurvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 46 ;
	}
#Downward UV radiation at the surface (variable resolution)
'uvbvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 57 ;
	}
#Photosynthetically active radiation at the surface (variable resolution)
'parvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 58 ;
	}
#Stratiform precipitation (Large-scale precipitation) (variable resolution)
'lspvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation (variable resolution)
'cpvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall (convective + stratiform) (variable resolution)
'sfvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation (variable resolution)
'bldvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux (variable resolution)
'sshfvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux (variable resolution)
'slhfvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 147 ;
	}
#Surface solar radiation downwards (variable resolution)
'ssrdvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 169 ;
	}
#Surface thermal radiation downwards (variable resolution)
'strdvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 175 ;
	}
#Surface net solar radiation (variable resolution)
'ssrvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation (variable resolution)
'strvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation (variable resolution)
'tsrvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation (variable resolution)
'ttrvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 179 ;
	}
#East-West surface stress (variable resolution)
'ewssvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 180 ;
	}
#North-South surface stress (variable resolution)
'nsssvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation (variable resolution)
'evar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 182 ;
	}
#Sunshine duration (variable resolution)
'sundvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 189 ;
	}
#Longitudinal component of gravity wave stress (variable resolution)
'lgwsvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 195 ;
	}
#Meridional component of gravity wave stress (variable resolution)
'mgwsvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 196 ;
	}
#Gravity wave dissipation (variable resolution)
'gwdvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 197 ;
	}
#Skin reservoir content (variable resolution)
'srcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 198 ;
	}
#Runoff (variable resolution)
'rovar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 205 ;
	}
#Top net solar radiation, clear sky (variable resolution)
'tsrcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 208 ;
	}
#Top net thermal radiation, clear sky (variable resolution)
'ttrcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 209 ;
	}
#Surface net solar radiation, clear sky (variable resolution)
'ssrcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky (variable resolution)
'strcvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 211 ;
	}
#TOA incident solar radiation (variable resolution)
'tisrvar' = {
	 table2Version = 230 ;
	 indicatorOfParameter = 212 ;
	}
#Surface temperature significance
'sts' = {
	 table2Version = 234 ;
	 indicatorOfParameter = 139 ;
	}
#Mean sea level pressure significance
'msls' = {
	 table2Version = 234 ;
	 indicatorOfParameter = 151 ;
	}
#2 metre temperature significance
'2ts' = {
	 table2Version = 234 ;
	 indicatorOfParameter = 167 ;
	}
#Total precipitation significance
'tps' = {
	 table2Version = 234 ;
	 indicatorOfParameter = 228 ;
	}
#U-component stokes drift
'ust' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 215 ;
	}
#V-component stokes drift
'vst' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 216 ;
	}
#Wildfire radiative power maximum
'maxfrpfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 101 ;
	}
#Wildfire flux of Sulfur Dioxide
'so2fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 102 ;
	}
#Wildfire Flux of Methanol (CH3OH)
'ch3ohfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 103 ;
	}
#Wildfire Flux of Ethanol (C2H5OH)
'c2h5ohfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 104 ;
	}
#Wildfire Flux of Propane (C3H8)
'c3h8fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 105 ;
	}
#Wildfire Flux of Ethene (C2H4)
'c2h4fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 106 ;
	}
#Wildfire Flux of Propene (C3H6)
'c3h6fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 107 ;
	}
#Wildfire Flux of Isoprene (C5H8)
'c5h8fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 108 ;
	}
#Wildfire Flux of Terpenes (C5H8)n
'terpenesfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 109 ;
	}
#Wildfire Flux of Toluene_lump (C7H8+ C6H6 + C8H10)
'toluenefire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 110 ;
	}
#Wildfire Flux of Higher Alkenes (CnH2n, C>=4)
'hialkenesfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 111 ;
	}
#Wildfire Flux of Higher Alkanes (CnH2n+2, C>=4)
'hialkanesfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 112 ;
	}
#Wildfire Flux of Formaldehyde (CH2O)
'ch2ofire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 113 ;
	}
#Wildfire Flux of Acetaldehyde (C2H4O)
'c2h4ofire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 114 ;
	}
#Wildfire Flux of Acetone (C3H6O)
'c3h6ofire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 115 ;
	}
#Wildfire Flux of Ammonia (NH3)
'nh3fire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 116 ;
	}
#Wildfire Flux of Dimethyl Sulfide (DMS) (C2H6S)
'c2h6sfire' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 117 ;
	}
#Wildfire radiative power maximum
'maxfrpfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 101 ;
	}
#Wildfire flux of Sulfur Dioxide
'so2firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 102 ;
	}
#Wildfire Flux of Methanol (CH3OH)
'ch3ohfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 103 ;
	}
#Wildfire Flux of Ethanol (C2H5OH)
'c2h5ohfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 104 ;
	}
#Wildfire Flux of Propane (C3H8)
'c3h8firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 105 ;
	}
#Wildfire Flux of Ethene (C2H4)
'c2h4firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 106 ;
	}
#Wildfire Flux of Propene (C3H6)
'c3h6firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 107 ;
	}
#Wildfire Flux of Isoprene (C5H8)
'c5h8firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 108 ;
	}
#Wildfire Flux of Terpenes (C5H8)n
'terpenesfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 109 ;
	}
#Wildfire Flux of Toluene_lump (C7H8+ C6H6 + C8H10)
'toluenefirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 110 ;
	}
#Wildfire Flux of Higher Alkenes (CnH2n, C>=4)
'hialkenesfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 111 ;
	}
#Wildfire Flux of Higher Alkanes (CnH2n+2, C>=4)
'hialkanesfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 112 ;
	}
#Wildfire Flux of Formaldehyde (CH2O)
'ch2ofirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 113 ;
	}
#Wildfire Flux of Acetaldehyde (C2H4O)
'c2h4ofirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 114 ;
	}
#Wildfire Flux of Acetone (C3H6O)
'c3h6ofirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 115 ;
	}
#Wildfire Flux of Ammonia (NH3)
'nh3firediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 116 ;
	}
#Wildfire Flux of Dimethyl Sulfide (DMS) (C2H6S)
'c2h6sfirediff' = {
	 table2Version = 211 ;
	 indicatorOfParameter = 117 ;
	}
#V-tendency from non-orographic wave drag
'vtnowd' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 134 ;
	}
#U-tendency from non-orographic wave drag
'utnowd' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 136 ;
	}
#100 metre U wind component
'100u' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 246 ;
	}
#100 metre V wind component
'100v' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 247 ;
	}
#ASCAT first soil moisture CDF matching parameter
'ascat_sm_cdfa' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 253 ;
	}
#ASCAT second soil moisture CDF matching parameter
'ascat_sm_cdfb' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 254 ;
}
